!******************************************************************************!
!                                                                              !
!    class_vertices.f90                                                        !
!    is part of RECOLA2 (REcursive Computation of One Loop Amplitudes)2        !
!                                                                              !
!    Copyright (C) 2016-2018 Ansgar Denner, Jean-Nicolas Lang and              !
!                            Sandro Uccirati                                   !
!                                                                              !
!    RECOLA2 is licenced under the GNU GPL version 3,                          !
!    see COPYING for details.                                                  !
!                                                                              !
!******************************************************************************!
!                                                           .---.              !
!                                                          /  .  \             !
!                                                         |\_/|   |            !
!                                                         |   |  /|            !
!          .----------------------------------------------------' |            !
!         /  .-.   class_vertices.f90                             |            !
!        |  /   \  This code was generated with REPT1L.           |            !
!        | |\_.  | Change this file and you get what you deserve. |            !
!        |\|  | /| Author: J.N. Lang                              |            !
!        | `---' | UFO date: 07/2017                              |            !
!        |       | UFO version: 1.0                               |            !
!        |       | Generation date: 2018-11-30 19:11             /             !
!        |       |----------------------------------------------'              !
!        \       |                                                             !
!         \     /                                                              !
!          `---'                                                               !
!******************************************************************************!
module class_vertices
  use fill_couplings
  use class_particles
  use class_ctparameters
  use fill_ctparameters, only: init_CTparameters_mdl
  use particle_keys, only: createParticleConfig
  use dictionary, only: dict,dict_get_value,dict_init
  use constants_mdl, only: Nc
  implicit none
  save

  interface get_vertex_mdl
    module procedure get_vertex3_mdl, get_vertex4_mdl, get_vertexN_mdl
  end interface

  type Branch
    integer :: lorentz_id
    integer :: perm
    integer, allocatable :: couplings(:)
    integer, dimension(n_orders) :: coupling_order
    integer :: color_id
    integer :: colorfac_id
    ! Propagator extension (only supported for massive vectors)
    ! 0: Usual propagator
    ! 1: Rxi-propagator part with pole @ M_V^2
    ! 2: Rxi-propagator part with pole @ \xi*M_V^2
    integer :: pext
  end type

  type Vertex
    type(Branch), allocatable :: branch(:)
    type(Branch), allocatable :: branchCT(:)
    type(Branch), allocatable :: branchR2(:)
  end type

  logical :: vertices_init = .false.
  logical :: vertices_filled = .false.
    interface createCurrent
      module procedure createCurrent2, createCurrent3, createCurrent4,         &
      createCurrent5, createCurrent6, createCurrent7, createCurrent8
    end interface 
  integer, parameter :: n_vertices = 3888
  type(Vertex) :: vertices(0:n_vertices-1)

  ! Defines the maximum allowed number of legs participating at a vertex
  integer, parameter :: max_leg_multiplicity = 4

  integer, parameter :: FFaS0 = 1
  integer, parameter :: FFaS1 = 2
  integer, parameter :: FFaS2 = 3
  integer, parameter :: FFaV0 = 4
  integer, parameter :: FFaV1 = 5
  integer, parameter :: SVVS0 = 6
  integer, parameter :: VVS0 = 7
  integer, parameter :: UUaS0 = 8
  integer, parameter :: UUaV0 = 9
  integer, parameter :: USUa0 = 10
  integer, parameter :: SUUa0 = 11
  integer, parameter :: VVSS0 = 12
  integer, parameter :: UVUa0 = 13
  integer, parameter :: FaF0 = 14
  integer, parameter :: FaF1 = 15
  integer, parameter :: FaF2 = 16
  integer, parameter :: VFaF0 = 17
  integer, parameter :: VFaF1 = 18
  integer, parameter :: VVV0 = 19
  integer, parameter :: FSFa0 = 20
  integer, parameter :: FSFa1 = 21
  integer, parameter :: FSFa2 = 22
  integer, parameter :: VVVV0 = 23
  integer, parameter :: FaVF0 = 24
  integer, parameter :: FaVF1 = 25
  integer, parameter :: UaVU0 = 26
  integer, parameter :: VSVS0 = 27
  integer, parameter :: FVFa0 = 28
  integer, parameter :: FVFa1 = 29
  integer, parameter :: FaFS0 = 30
  integer, parameter :: FaFS1 = 31
  integer, parameter :: FaFS2 = 32
  integer, parameter :: VV0 = 33
  integer, parameter :: VV1 = 34
  integer, parameter :: VV2 = 35
  integer, parameter :: VV3 = 36
  integer, parameter :: SVSV0 = 37
  integer, parameter :: UaSU0 = 38
  integer, parameter :: FaFV0 = 39
  integer, parameter :: FaFV1 = 40
  integer, parameter :: SSSS0 = 41
  integer, parameter :: VS0 = 42
  integer, parameter :: VS1 = 43
  integer, parameter :: SFFa0 = 44
  integer, parameter :: SFFa1 = 45
  integer, parameter :: SFFa2 = 46
  integer, parameter :: VUUa0 = 47
  integer, parameter :: SFaF0 = 48
  integer, parameter :: SFaF1 = 49
  integer, parameter :: SFaF2 = 50
  integer, parameter :: SVV0 = 51
  integer, parameter :: FaSF0 = 52
  integer, parameter :: FaSF1 = 53
  integer, parameter :: FaSF2 = 54
  integer, parameter :: SVS0 = 55
  integer, parameter :: FFa0 = 56
  integer, parameter :: FFa1 = 57
  integer, parameter :: FFa2 = 58
  integer, parameter :: VSS0 = 59
  integer, parameter :: VSV0 = 60
  integer, parameter :: SS0 = 61
  integer, parameter :: SS1 = 62
  integer, parameter :: SS2 = 63
  integer, parameter :: SS3 = 64
  integer, parameter :: SS4 = 65
  integer, parameter :: SS5 = 66
  integer, parameter :: SSVV0 = 67
  integer, parameter :: SSV0 = 68
  integer, parameter :: SV0 = 69
  integer, parameter :: SV1 = 70
  integer, parameter :: SSS0 = 71
  integer, parameter :: VUaU0 = 72
  integer, parameter :: VSSV0 = 73
  integer, parameter :: UaUS0 = 74
  integer, parameter :: VFFa0 = 75
  integer, parameter :: VFFa1 = 76
  integer, parameter :: SUaU0 = 77
  integer, parameter :: UaUV0 = 78
  complex(dp), parameter :: c1 = cmplx(1d0, 0d0, kind=dp)
  character(len=20), parameter :: c1f = "1"
  complex(dp), parameter :: c2 = cmplx(sq2/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c2f = "sq2/2"
  complex(dp), parameter :: c3 = cmplx(-sq2/(2d0*Nc), 0d0, kind=dp)
  character(len=20), parameter :: c3f = "-sq2/(2*Nc)"
  complex(dp), parameter :: c4 = cmplx(0d0, sq2/2d0, kind=dp)
  character(len=20), parameter :: c4f = "i_*sq2/2"
  complex(dp), parameter :: c5 = cmplx(0d0, -sq2/2d0, kind=dp)
  character(len=20), parameter :: c5f = "-i_*sq2/2"
  complex(dp), parameter :: c6 = cmplx(-1d0/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c6f = "-1/2"
  complex(dp), parameter :: c7 = cmplx(1d0/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c7f = "1/2"
  complex(dp), parameter :: c8 = cmplx(-1d0/Nc, 0d0, kind=dp)
  character(len=20), parameter :: c8f = "-1/Nc"
  complex(dp), dimension(1:8) :: colorcoeffs = (/c1, c2, c3, c4, c5, c6, c7, c8&
                                               /)
  character(len=20), dimension(1:8) :: colorcoeffs_form = (/c1f, c2f, c3f, c4f &
                 , c5f, c6f, c7f, c8f/)
  integer, dimension(1:78) :: lorentz_rank = (/0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0 &
                                             , 0, 1, -1, -1, -1, 1, 1, 1, 1, 1 &
                                             , 1, 0, 1, 1, 1, 0, 1, 1, 0, 0, 0 &
                                             , -1, -1, -1, -1, 0, 0, 0, 0, 0, -&
                                             1, -1, 1, 1, 1, 1, 1, 1, 1, 0, 1, &
                                             1, 1, 1, -1, -1, -1, 1, 0, -1, -1 &
                                             , -1, -1, -1, -1, 0, 1, -1, -1, 0 &
                                             , 1, 0, 0, 1, 1, 0, 1/)
  integer, dimension(1:78) :: recola_base = (/9, 5, 7, 15, 17, -2, 2, 1, 161, 1&
                                            , 1, -4, 165, 0, 0, 0, 53, 58, 12, &
                                            21, 27, 25, -11, 57, 51, 166, -3,  &
                                            31, 35, 10, 6, 8, 0, 0, 0, 0, -14, &
                                            1, 18, 16, -1, 0, 0, 28, 23, 26,   &
                                            163, 43, 48, 46, 13, 41, 45, 47, 3 &
                                            , 0, 0, 0, 4, 14, 0, 0, 0, 0, 0, 0 &
                                            , -12, 11, 0, 0, 1, 162, -13, 1, 36&
                                            , 33, 1, 164/)
  integer, dimension(1:78) :: propagator_extension = (/0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                                     , 0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                                     , 0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                                     , 0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                                     , 0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0/)
  character(len=*), parameter :: model_timestamp = "Fri Nov 30 19:06:35 2018"

  contains
    function get_timestamp_mdl() result(ret_timestamp)
      character(len=len(model_timestamp)) :: ret_timestamp
      ret_timestamp = model_timestamp
    end function get_timestamp_mdl

    function get_lorentz_rank_mdl(l_id) result(ret_lorentz_rank)
      integer, intent(in) :: l_id
      integer :: ret_lorentz_rank
      ret_lorentz_rank = lorentz_rank(l_id)
    end function get_lorentz_rank_mdl

    function get_propagator_extension_mdl(l_id) result(ret_pext)
      integer, intent(in) :: l_id
      integer :: ret_pext
      ret_pext = propagator_extension(l_id)
    end function get_propagator_extension_mdl

    function get_max_leg_multiplicity_mdl() result(ret_max_leg_multiplicity)
      integer :: ret_max_leg_multiplicity
      ret_max_leg_multiplicity = max_leg_multiplicity
    end function get_max_leg_multiplicity_mdl

    function is_model_init_mdl() result(ret_init)
      logical :: ret_init
      ret_init = vertices_init
    end function is_model_init_mdl

    function is_model_filled_mdl() result(ret_init)
      logical :: ret_init
      ret_init = vertices_filled
    end function is_model_filled_mdl

    subroutine get_vertex3_mdl(p1, p2, p3, vertex_ret)
      integer, intent(out) :: vertex_ret
      integer, intent(in)  :: p1, p2, p3
      integer(kind=8)      :: config
      integer              :: address
      logical              :: found_vertex

      call createParticleConfig(p1, p2, p3, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if

    end subroutine get_vertex3_mdl

    subroutine get_vertex4_mdl(p1, p2, p3, p4, vertex_ret)
      integer, intent(out) :: vertex_ret
      integer, intent(in)  :: p1, p2, p3, p4
      integer(kind=8)      :: config
      integer              :: address
      logical              :: found_vertex

      call createParticleConfig(p1, p2, p3, p4, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if
    end subroutine get_vertex4_mdl

    subroutine get_vertexN_mdl(particles, particleOut, vertex_ret)
      integer, intent(out)              :: vertex_ret
      integer, dimension(:), intent(in) :: particles
      integer, intent(in)               :: particleOut
      integer(kind=8)                   :: config
      integer                           :: address
      logical                           :: found_vertex

      call createParticleConfig(particles, particleOut, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if

    end subroutine get_vertexN_mdl

    subroutine av(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branch(bid)%color_id = cid
      vertices(vid)%branch(bid)%colorfac_id = cfid
      vertices(vid)%branch(bid)%pext = pext
      vertices(vid)%branch(bid)%lorentz_id = lid
      vertices(vid)%branch(bid)%perm = perm
      vertices(vid)%branch(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branch(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branch(bid)%couplings(i) = cop(i)
      end do
    end subroutine av

    subroutine avCT(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branchCT(bid)%color_id = cid
      vertices(vid)%branchCT(bid)%colorfac_id = cfid
      vertices(vid)%branchCT(bid)%pext = pext
      vertices(vid)%branchCT(bid)%lorentz_id = lid
      vertices(vid)%branchCT(bid)%perm = perm
      vertices(vid)%branchCT(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branchCT(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branchCT(bid)%couplings(i) = cop(i)
      end do
    end subroutine avCT

    subroutine avR2(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branchR2(bid)%color_id = cid
      vertices(vid)%branchR2(bid)%colorfac_id = cfid
      vertices(vid)%branchR2(bid)%pext = pext
      vertices(vid)%branchR2(bid)%lorentz_id = lid
      vertices(vid)%branchR2(bid)%perm = perm
      vertices(vid)%branchR2(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branchR2(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branchR2(bid)%couplings(i) = cop(i)
      end do
    end subroutine avR2

    function get_colourfac_mdl(cfid)
      integer, intent(in) :: cfid
      complex(dp) :: get_colourfac_mdl
      get_colourfac_mdl = colorcoeffs(cfid)
    end function get_colourfac_mdl

    function get_colourfac_form_mdl(cfid)
      integer, intent(in) :: cfid
      character(len=20) :: get_colourfac_form_mdl
      get_colourfac_form_mdl = colorcoeffs_form(cfid)
    end function get_colourfac_form_mdl

  function get_recola_base_mdl(l_id) result(ret_rb)
      integer, intent(in) :: l_id
      integer :: ret_rb
      ret_rb = recola_base(l_id)
    end function get_recola_base_mdl

  subroutine get_vertex_branch_status_mdl(vx,xlp,branch_exists)
    integer, intent(in)  :: vx,xlp
    logical, intent(out) ::branch_exists
    select case (xlp)
    case(TreeBranch:LoopBranch)
      branch_exists = allocated(vertices(vx)%branch)
    case(CTBranch)
      branch_exists = allocated(vertices(vx)%branchCT)
    case(R2Branch)
      branch_exists = allocated(vertices(vx)%branchR2)
    end select
  end subroutine get_vertex_branch_status_mdl

  subroutine get_vertex_colour_branches_mdl(vx,xlp,cfids,nbranches)
    integer, allocatable, intent(out) :: cfids(:)
    integer, intent(out) :: nbranches
    integer, intent(in)  :: vx,xlp
    select case (xlp)
    case (TreeBranch:LoopBranch)
      allocate(cfids(size(vertices(vx)%branch)))
      cfids(:) = vertices(vx)%branch(0:)%color_id
      nbranches = size(vertices(vx)%branch)
    case(CTBranch)
      allocate(cfids(size(vertices(vx)%branchCT)))
      cfids(:) = vertices(vx)%branchCT(0:)%color_id
      nbranches = size(vertices(vx)%branchCT)
    case(R2Branch)
      allocate(cfids(size(vertices(vx)%branchR2)))
      cfids(:) = vertices(vx)%branchR2(0:)%color_id
      nbranches = size(vertices(vx)%branchR2)
    end select
  end subroutine get_vertex_colour_branches_mdl

  subroutine get_vertex_pext_mdl(vx,xlp,br,pext)
    integer, intent(in) :: vx,xlp,br
    integer, intent(out) :: pext
    select case (xlp)
    case (TreeBranch:LoopBranch)
      pext = vertices(vx)%branch(br)%pext
    case(CTBranch)
      pext = vertices(vx)%branchCT(br)%pext
    case(R2Branch)
      pext = vertices(vx)%branchR2(br)%pext
    end select
  end subroutine get_vertex_pext_mdl

  subroutine get_vertex_order_increase_mdl(vx,xlp,br,orderInc)
    integer, intent(in) :: vx,xlp,br
    integer, dimension(:), intent(out) :: orderInc
    select case (xlp)
    case (TreeBranch:LoopBranch)
      orderInc = vertices(vx)%branch(br)%coupling_order
    case(CTBranch)
      orderInc = vertices(vx)%branchCT(br)%coupling_order
    case(R2Branch)
      orderInc = vertices(vx)%branchR2(br)%coupling_order
    end select
  end subroutine get_vertex_order_increase_mdl

  subroutine get_vertex_lorentz_type_mdl(vx,xlp,br,lid)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: lid
    select case (xlp)
    case (TreeBranch:LoopBranch)
      lid = vertices(vx)%branch(br)%lorentz_id
    case(CTBranch)
      lid = vertices(vx)%branchCT(br)%lorentz_id
    case(R2Branch)
      lid = vertices(vx)%branchR2(br)%lorentz_id
    end select
  end subroutine get_vertex_lorentz_type_mdl

  subroutine get_vertex_perm_mdl(vx,xlp,br,perm)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: perm
    select case (xlp)
    case (TreeBranch:LoopBranch)
      perm = vertices(vx)%branch(br)%perm
    case(CTBranch)
      perm = vertices(vx)%branchCT(br)%perm
    case(R2Branch)
      perm = vertices(vx)%branchR2(br)%perm
    end select
  end subroutine get_vertex_perm_mdl

  subroutine get_vertex_colour_id_mdl(vx,xlp,br,cid)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: cid
    select case (xlp)
    case (TreeBranch:LoopBranch)
      cid = vertices(vx)%branch(br)%colorfac_id
    case(CTBranch)
      cid = vertices(vx)%branchCT(br)%colorfac_id
    case(R2Branch)
      cid = vertices(vx)%branchR2(br)%colorfac_id
    end select
  end subroutine get_vertex_colour_id_mdl

  function is_zero_coupling_vertex_mdl(vx,xlp,br) result(zero)
    use class_couplings, only: get_coupling_value_mdl
    use input_mdl, only: zerocut
    integer, intent(in)  :: vx,xlp,br
    logical              :: zero
    real(dp)             :: maxvalue
    integer              :: i

    zero = .false.
    select case (xlp)
    case (TreeBranch:LoopBranch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branch(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branch(br)%couplings(i-&
                1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    case(CTBranch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branchCT(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branchCT(br)%couplings(&
                i-1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    case(R2Branch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branchR2(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branchR2(br)%couplings(&
                i-1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    end select
  end function is_zero_coupling_vertex_mdl

  subroutine get_vertex_ncouplings_mdl(vx,xlp,br,ncouplings)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: ncouplings
    select case(xlp)
    case(TreeBranch, LoopBranch)
      ncouplings = size(vertices(vx)%branch(br)%couplings)
    case (CTBranch)
      ncouplings = size(vertices(vx)%branchCT(br)%couplings)
    case (R2Branch)
      ncouplings = size(vertices(vx)%branchR2(br)%couplings)
    end select
  end subroutine get_vertex_ncouplings_mdl

  subroutine get_vertex_coupling_ids_mdl(vx,xlp,br,cids)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: cids(:)
    select case(xlp)
    case(TreeBranch, LoopBranch)
      cids(:) = vertices(vx)%branch(br)%couplings(:)
    case (CTBranch)
      cids(:) = vertices(vx)%branchCT(br)%couplings(:)
    case (R2Branch)
      cids(:) = vertices(vx)%branchR2(br)%couplings(:)
    end select
  end subroutine get_vertex_coupling_ids_mdl

    subroutine createCurrent2(P1, P2, id, check)
      integer, intent(in) :: P1, P2, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent2

    subroutine createCurrent3(P1, P2, P3, id, check)
      integer, intent(in) :: P1, P2, P3, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent3

    subroutine createCurrent4(P1, P2, P3, P4, id, check)
      integer, intent(in) :: P1, P2, P3, P4, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent4

    subroutine createCurrent5(P1, P2, P3, P4, P5, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent5

    subroutine createCurrent6(P1, P2, P3, P4, P5, P6, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent6

    subroutine createCurrent7(P1, P2, P3, P4, P5, P6, P7, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, P7, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, P7, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent7

    subroutine createCurrent8(P1, P2, P3, P4, P5, P6, P7, P8, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, P7, P8, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, P7, P8, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent8

    subroutine init_vertices_mdl()
      use constants_mdl
      use input_mdl, only: nx, error_mdl

      ! check if modelfile is compatible to drivers
      if (model_timestamp .ne. driver_timestamp) then
        call error_mdl("Model corrupted. Driver timestamp mismatch.", &
                      where='init_vertices')
      end if

      vertices_init = .true.
      call fill_couplings_mdl
      call init_CTparameters_mdl(.true.)
      call fill_CTcouplings_mdl
      call dict_init(7759)
      call createCurrents(.false.)

    end subroutine init_vertices_mdl

    subroutine createCurrents(check)
      logical, intent(in) :: check
      call createCurrent(P_Hh, P_GMinus, P_HPlus, 524, check)
      call createCurrent(P_Ha, P_WPlus, P_HMinus, P_A, 237, check)
      call createCurrent(P_GMinus, P_G0, P_A, P_WPlus, 2216, check)
      call createCurrent(P_WPlus, P_GPlus, P_GMinus, P_WMinus, 1585, check)
      call createCurrent(P_GPlus, P_b, P_tAnti, 2588, check)
      call createCurrent(P_HPlus, P_A, P_G0, P_WMinus, 2953, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_HMinus, 2906, check)
      call createCurrent(P_Hh, P_Hh, P_Ha, P_Hh, 3858, check)
      call createCurrent(P_HPlus, P_GMinus, P_GPlus, P_HMinus, 864, check)
      call createCurrent(P_Hh, P_HPlus, P_Hh, P_GMinus, 121, check)
      call createCurrent(P_GPlus, P_A, P_Z, P_GMinus, 1737, check)
      call createCurrent(P_HMinus, P_G0, P_HPlus, P_G0, 1012, check)
      call createCurrent(P_GPlus, P_Hh, P_G0, P_HMinus, 2422, check)
      call createCurrent(P_Z, P_Hl, P_GPlus, P_WMinus, 2429, check)
      call createCurrent(P_GPlus, P_Hl, P_GMinus, 2199, check)
      call createCurrent(P_GPlus, P_Hh, P_Hh, P_HMinus, 1539, check)
      call createCurrent(P_Hl, P_WMinus, P_A, P_GPlus, 2384, check)
      call createCurrent(P_HMinus, P_Ha, P_GPlus, 364, check)
      call createCurrent(P_G0, P_HMinus, P_Ha, P_GPlus, 1259, check)
      call createCurrent(P_GMinus, P_G0, P_G0, P_HPlus, 1103, check)
      call createCurrent(P_GPlus, P_A, P_HMinus, P_Z, 3447, check)
      call createCurrent(P_Z, P_Z, P_GPlus, P_HMinus, 3566, check)
      call createCurrent(P_A, P_HMinus, P_Z, P_GPlus, 3053, check)
      call createCurrent(P_G0, P_HPlus, P_GMinus, P_Hl, 1020, check)
      call createCurrent(P_Hh, P_G0, P_Ha, 2400, check)
      call createCurrent(P_b, P_bAnti, P_Ha, 454, check)
      call createCurrent(P_Hh, P_cAnti, P_c, 49, check)
      call createCurrent(P_Hh, P_Hl, P_Hh, P_Hh, 1715, check)
      call createCurrent(P_WPlus, P_Hh, P_HMinus, P_Z, 436, check)
      call createCurrent(P_G0, P_uAnti, P_u, 773, check)
      call createCurrent(P_HPlus, P_G0, P_Ha, P_GMinus, 2665, check)
      call createCurrent(P_GPlus, P_Hh, P_WMinus, P_Z, 355, check)
      call createCurrent(P_GPlus, P_GMinus, P_Ha, P_G0, 2645, check)
      call createCurrent(P_WMinus, P_GMinus, P_HPlus, P_WPlus, 3561, check)
      call createCurrent(P_WMinus, P_Z, P_Hl, P_HPlus, 1610, check)
      call createCurrent(P_WMinus, P_HPlus, P_WPlus, P_HMinus, 678, check)
      call createCurrent(P_GPlus, P_Hl, P_GMinus, P_Hl, 2009, check)
      call createCurrent(P_g, P_cAnti, P_c, 1074, check)
      call createCurrent(P_G0, P_A, P_G0, P_A, 3743, check)
      call createCurrent(P_WMinus, P_G0, P_G0, P_WPlus, 621, check)
      call createCurrent(P_Hl, P_Z, P_Z, 2344, check)
      call createCurrent(P_HPlus, P_GMinus, P_Hh, P_Hh, 520, check)
      call createCurrent(P_Hh, P_ghWm, P_ghWmAnti, 2503, check)
      call createCurrent(P_A, P_Hh, P_WMinus, P_HPlus, 1329, check)
      call createCurrent(P_Hh, P_GPlus, P_GMinus, P_Hl, 2662, check)
      call createCurrent(P_Hl, P_G0, P_G0, P_Hh, 1844, check)
      call createCurrent(P_HPlus, P_HPlus, P_HMinus, P_HMinus, 1199, check)
      call createCurrent(P_Z, P_GPlus, P_GMinus, P_A, 2287, check)
      call createCurrent(P_Hl, P_HPlus, P_Ha, P_GMinus, 921, check)
      call createCurrent(P_HMinus, P_Hh, P_Hh, P_HPlus, 1493, check)
      call createCurrent(P_ghWp, P_Hh, P_ghWpAnti, 529, check)
      call createCurrent(P_Z, P_Hh, P_A, P_Hh, 3103, check)
      call createCurrent(P_GMinus, P_Hh, P_Hl, P_HPlus, 1137, check)
      call createCurrent(P_Z, P_A, P_Z, P_Z, 3599, check)
      call createCurrent(P_A, P_ePlus, P_eMinus, 1353, check)
      call createCurrent(P_Hh, P_HMinus, P_HPlus, P_Hh, 1434, check)
      call createCurrent(P_HMinus, P_G0, P_Ha, P_GPlus, 665, check)
      call createCurrent(P_A, P_GPlus, P_HMinus, P_Z, 3147, check)
      call createCurrent(P_WMinus, P_Ha, P_WPlus, P_Ha, 829, check)
      call createCurrent(P_WPlus, P_HMinus, P_Hl, 227, check)
      call createCurrent(P_A, P_Ha, P_WPlus, P_HMinus, 29, check)
      call createCurrent(P_A, P_GMinus, P_A, P_HPlus, 3573, check)
      call createCurrent(P_Hh, P_HMinus, P_A, P_WPlus, 1923, check)
      call createCurrent(P_A, P_WMinus, P_HPlus, P_Hl, 1689, check)
      call createCurrent(P_Ha, P_Hl, P_Hh, P_G0, 2574, check)
      call createCurrent(P_WPlus, P_Z, P_Hl, P_HMinus, 323, check)
      call createCurrent(P_Ha, P_Z, P_WPlus, P_GMinus, 2870, check)
      call createCurrent(P_G0, P_u, P_uAnti, 1316, check)
      call createCurrent(P_Ha, P_HMinus, P_HPlus, 2935, check)
      call createCurrent(P_A, P_Ha, P_G0, P_A, 3631, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, P_Ha, 3519, check)
      call createCurrent(P_Hl, P_Hh, P_Z, P_Z, 2983, check)
      call createCurrent(P_GMinus, P_Hl, P_GPlus, P_Hh, 2544, check)
      call createCurrent(P_G0, P_GPlus, P_WMinus, P_A, 395, check)
      call createCurrent(P_tauMinus, P_tauPlus, 3134, check)
      call createCurrent(P_A, P_HMinus, P_HPlus, P_Z, 606, check)
      call createCurrent(P_nu_eAnti, P_eMinus, P_GPlus, 2697, check)
      call createCurrent(P_GPlus, P_Hl, P_Z, P_WMinus, 52, check)
      call createCurrent(P_Z, P_tauPlus, P_tauMinus, 535, check)
      call createCurrent(P_A, P_WMinus, P_HPlus, P_Hh, 2150, check)
      call createCurrent(P_G0, P_Hl, P_HMinus, P_HPlus, 3492, check)
      call createCurrent(P_WMinus, P_dAnti, P_u, 2499, check)
      call createCurrent(P_WMinus, P_G0, P_Ha, P_WPlus, 3273, check)
      call createCurrent(P_G0, P_HPlus, P_HMinus, 2762, check)
      call createCurrent(P_muPlus, P_muMinus, P_Hh, 440, check)
      call createCurrent(P_G0, P_g, P_G0, P_g, 3609, check)
      call createCurrent(P_WPlus, P_G0, P_G0, P_WMinus, 1934, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghA, 2011, check)
      call createCurrent(P_HPlus, P_HMinus, P_Hh, P_Hh, 2174, check)
      call createCurrent(P_Z, P_WPlus, P_A, P_WMinus, 1437, check)
      call createCurrent(P_WMinus, P_Z, P_Ha, P_GPlus, 3042, check)
      call createCurrent(P_HMinus, P_Hh, P_G0, P_HPlus, 3075, check)
      call createCurrent(P_HMinus, P_Z, P_HPlus, P_Z, 186, check)
      call createCurrent(P_GMinus, P_GPlus, 3424, check)
      call createCurrent(P_Hh, P_HMinus, P_Hh, P_GPlus, 2330, check)
      call createCurrent(P_Z, P_GMinus, P_HPlus, P_A, 3444, check)
      call createCurrent(P_Z, P_Hh, P_WPlus, P_GMinus, 1308, check)
      call createCurrent(P_G0, P_GPlus, P_Z, P_WMinus, 1179, check)
      call createCurrent(P_G0, P_Hh, P_GMinus, P_GPlus, 3197, check)
      call createCurrent(P_HMinus, P_A, P_GPlus, P_A, 2886, check)
      call createCurrent(P_GMinus, P_Hh, P_WPlus, 1777, check)
      call createCurrent(P_Hl, P_A, P_WPlus, P_HMinus, 289, check)
      call createCurrent(P_WMinus, P_A, P_HPlus, 754, check)
      call createCurrent(P_Hl, P_HPlus, P_Hl, P_GMinus, 2034, check)
      call createCurrent(P_G0, P_G0, P_GMinus, P_HPlus, 1605, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, P_Hl, 2355, check)
      call createCurrent(P_GPlus, P_Z, P_Hh, P_WMinus, 1397, check)
      call createCurrent(P_ghWm, P_Hl, P_ghWmAnti, 541, check)
      call createCurrent(P_A, P_Hl, P_A, P_Hl, 3792, check)
      call createCurrent(P_Z, P_WPlus, P_Z, P_WMinus, 1846, check)
      call createCurrent(P_Hh, P_G0, P_Hl, P_Ha, 2509, check)
      call createCurrent(P_G0, P_HMinus, P_WPlus, P_Z, 2996, check)
      call createCurrent(P_HMinus, P_muPlus, P_nu_mu, 2657, check)
      call createCurrent(P_G0, P_HPlus, P_GMinus, 1129, check)
      call createCurrent(P_A, P_Hl, P_Hh, P_Z, 3608, check)
      call createCurrent(P_s, P_cAnti, P_HPlus, 1587, check)
      call createCurrent(P_GMinus, P_GPlus, P_Hl, P_Hl, 899, check)
      call createCurrent(P_HMinus, P_HPlus, P_Hh, P_G0, 2724, check)
      call createCurrent(P_Hl, P_HMinus, P_Ha, P_HPlus, 2769, check)
      call createCurrent(P_A, P_ghWm, P_ghWmAnti, 729, check)
      call createCurrent(P_dAnti, P_d, P_Hl, 1909, check)
      call createCurrent(P_Hh, P_HPlus, P_Hl, P_HMinus, 2461, check)
      call createCurrent(P_HPlus, P_G0, P_GMinus, P_G0, 235, check)
      call createCurrent(P_WMinus, P_HPlus, P_A, P_Ha, 949, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, P_Hh, 1690, check)
      call createCurrent(P_G0, P_G0, P_HPlus, P_GMinus, 463, check)
      call createCurrent(P_WMinus, P_HPlus, P_Z, 2676, check)
      call createCurrent(P_bAnti, P_b, P_g, 1619, check)
      call createCurrent(P_cAnti, P_Z, P_c, 148, check)
      call createCurrent(P_A, P_Ha, P_WMinus, P_HPlus, 1551, check)
      call createCurrent(P_eMinus, P_WPlus, P_nu_eAnti, 1676, check)
      call createCurrent(P_HMinus, P_Ha, P_HPlus, P_Hh, 3027, check)
      call createCurrent(P_Ha, P_G0, P_Hh, 291, check)
      call createCurrent(P_G0, P_Hl, P_Hh, P_Ha, 1251, check)
      call createCurrent(P_G0, P_Z, P_G0, P_Z, 1408, check)
      call createCurrent(P_uAnti, P_u, P_Hl, 1236, check)
      call createCurrent(P_A, P_HMinus, P_WPlus, P_Hl, 1214, check)
      call createCurrent(P_GPlus, P_GMinus, P_WPlus, P_WMinus, 1968, check)
      call createCurrent(P_Z, P_ePlus, P_eMinus, 1006, check)
      call createCurrent(P_t, P_tAnti, 3514, check)
      call createCurrent(P_G0, P_Hl, P_Ha, P_Hh, 1703, check)
      call createCurrent(P_G0, P_HMinus, P_Hl, P_GPlus, 1069, check)
      call createCurrent(P_Ha, P_Z, P_Z, P_Ha, 2660, check)
      call createCurrent(P_Hl, P_GMinus, P_G0, P_GPlus, 2966, check)
      call createCurrent(P_A, P_Hh, P_A, 3748, check)
      call createCurrent(P_Z, P_WPlus, P_WMinus, P_Z, 1483, check)
      call createCurrent(P_HMinus, P_Hl, P_GPlus, P_Ha, 2656, check)
      call createCurrent(P_Z, P_Ha, P_GMinus, P_WPlus, 3090, check)
      call createCurrent(P_HPlus, P_Hh, P_Ha, P_HMinus, 2781, check)
      call createCurrent(P_HMinus, P_A, P_Ha, P_WPlus, 2117, check)
      call createCurrent(P_t, P_Z, P_tAnti, 783, check)
      call createCurrent(P_ghWpAnti, P_HPlus, P_ghA, 3062, check)
      call createCurrent(P_G0, P_dAnti, P_d, 969, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghWp, 2058, check)
      call createCurrent(P_GPlus, P_Hl, P_A, P_WMinus, 2558, check)
      call createCurrent(P_Ha, P_GPlus, P_GMinus, 3349, check)
      call createCurrent(P_Hl, P_GPlus, P_A, P_WMinus, 161, check)
      call createCurrent(P_Hl, P_HPlus, P_HMinus, P_G0, 3330, check)
      call createCurrent(P_s, P_Z, P_sAnti, 796, check)
      call createCurrent(P_GMinus, P_A, P_GPlus, P_Z, 695, check)
      call createCurrent(P_Hl, P_muMinus, P_muPlus, 1699, check)
      call createCurrent(P_HMinus, P_HPlus, P_GPlus, P_GMinus, 1325, check)
      call createCurrent(P_nu_e, P_WMinus, P_ePlus, 2663, check)
      call createCurrent(P_A, P_Ha, P_Ha, P_A, 3794, check)
      call createCurrent(P_Hl, P_GMinus, P_Hl, P_GPlus, 2149, check)
      call createCurrent(P_eMinus, P_Hh, P_ePlus, 504, check)
      call createCurrent(P_Hh, P_GPlus, P_HMinus, 1779, check)
      call createCurrent(P_Hl, P_Ha, P_GPlus, P_HMinus, 1287, check)
      call createCurrent(P_GPlus, P_HPlus, P_GMinus, P_HMinus, 105, check)
      call createCurrent(P_GMinus, P_Ha, P_HPlus, P_G0, 2366, check)
      call createCurrent(P_WMinus, P_HPlus, P_G0, P_Z, 3243, check)
      call createCurrent(P_GMinus, P_WPlus, P_G0, P_Z, 1171, check)
      call createCurrent(P_A, P_Ha, P_HPlus, P_WMinus, 1571, check)
      call createCurrent(P_G0, P_G0, P_G0, P_G0, 1533, check)
      call createCurrent(P_Ha, P_Hh, P_G0, P_Hl, 1245, check)
      call createCurrent(P_t, P_Hl, P_tAnti, 1866, check)
      call createCurrent(P_g, P_g, P_Hh, P_Hh, 3651, check)
      call createCurrent(P_G0, P_HPlus, P_GMinus, P_G0, 1523, check)
      call createCurrent(P_A, P_WMinus, P_HPlus, P_G0, 2800, check)
      call createCurrent(P_A, P_muPlus, P_muMinus, 2649, check)
      call createCurrent(P_HPlus, P_Z, P_WMinus, 1456, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_G0, 1881, check)
      call createCurrent(P_Hh, P_Hl, P_Hh, P_Hl, 2181, check)
      call createCurrent(P_Hh, P_Hh, P_Hl, 2408, check)
      call createCurrent(P_G0, P_GPlus, P_HMinus, P_Ha, 1949, check)
      call createCurrent(P_G0, P_c, P_cAnti, 287, check)
      call createCurrent(P_Ha, P_Hl, P_HPlus, P_HMinus, 3002, check)
      call createCurrent(P_GPlus, P_Hh, P_WMinus, P_A, 2350, check)
      call createCurrent(P_HPlus, P_Hh, P_Hl, P_GMinus, 2536, check)
      call createCurrent(P_HMinus, P_A, P_G0, P_WPlus, 3381, check)
      call createCurrent(P_A, P_Hl, P_WMinus, P_HPlus, 1042, check)
      call createCurrent(P_A, P_g, P_g, P_Z, 3667, check)
      call createCurrent(P_GMinus, P_WPlus, P_G0, 551, check)
      call createCurrent(P_nu_mu, P_nu_muAnti, P_Z, 2433, check)
      call createCurrent(P_Z, P_HPlus, P_WMinus, P_G0, 3440, check)
      call createCurrent(P_Ha, P_b, P_bAnti, 2370, check)
      call createCurrent(P_Ha, P_Ha, P_Ha, P_G0, 273, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, P_G0, 1435, check)
      call createCurrent(P_Hh, P_Hl, P_Hl, P_Hl, 924, check)
      call createCurrent(P_GPlus, P_Hh, P_A, P_WMinus, 1167, check)
      call createCurrent(P_nu_tau, P_nu_tauAnti, P_A, 3385, check)
      call createCurrent(P_HMinus, P_Z, P_WPlus, 1241, check)
      call createCurrent(P_Hh, P_Hl, P_Hl, 936, check)
      call createCurrent(P_Hh, P_Hh, P_Hl, P_Hh, 602, check)
      call createCurrent(P_A, P_A, P_Hh, 3772, check)
      call createCurrent(P_HPlus, P_GMinus, P_Hh, P_Ha, 506, check)
      call createCurrent(P_HMinus, P_WPlus, P_Hh, 62, check)
      call createCurrent(P_WMinus, P_g, P_WPlus, P_g, 3621, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, P_Hh, 231, check)
      call createCurrent(P_Hl, P_G0, P_Z, 2042, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, P_Hh, 685, check)
      call createCurrent(P_A, P_G0, P_Hh, 2716, check)
      call createCurrent(P_muMinus, P_nu_muAnti, P_WPlus, 1457, check)
      call createCurrent(P_g, P_A, P_g, P_Z, 3873, check)
      call createCurrent(P_u, P_uAnti, P_Hh, 1444, check)
      call createCurrent(P_Hl, P_G0, P_Ha, P_Hh, 1901, check)
      call createCurrent(P_Hh, P_ghWp, P_ghWpAnti, 1431, check)
      call createCurrent(P_GMinus, P_GMinus, P_GPlus, P_GPlus, 228, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, P_G0, 1147, check)
      call createCurrent(P_GPlus, P_G0, P_GMinus, P_Hl, 3077, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_Ha, 1819, check)
      call createCurrent(P_Ha, P_Ha, P_HPlus, P_HMinus, 1641, check)
      call createCurrent(P_A, P_G0, P_WPlus, P_GMinus, 1477, check)
      call createCurrent(P_Z, P_HMinus, P_Z, P_GPlus, 2758, check)
      call createCurrent(P_Ha, P_WPlus, P_HMinus, 1636, check)
      call createCurrent(P_g, P_g, P_Z, P_Z, 3840, check)
      call createCurrent(P_WMinus, P_HPlus, P_Ha, P_Z, 1974, check)
      call createCurrent(P_Z, P_uAnti, P_u, 288, check)
      call createCurrent(P_GPlus, P_GMinus, P_A, P_Z, 19, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_Hh, 2101, check)
      call createCurrent(P_Z, P_WMinus, P_G0, P_GPlus, 930, check)
      call createCurrent(P_muMinus, P_GPlus, P_nu_muAnti, 753, check)
      call createCurrent(P_G0, P_A, P_Ha, P_Z, 3752, check)
      call createCurrent(P_HMinus, P_HPlus, P_A, 1800, check)
      call createCurrent(P_HPlus, P_A, P_WMinus, P_G0, 3265, check)
      call createCurrent(P_Ha, P_HPlus, P_G0, P_HMinus, 548, check)
      call createCurrent(P_Hh, P_A, P_WPlus, P_GMinus, 252, check)
      call createCurrent(P_Ha, P_GMinus, P_GPlus, 3466, check)
      call createCurrent(P_G0, P_HMinus, P_HPlus, P_Hh, 2714, check)
      call createCurrent(P_Hl, P_A, P_WPlus, P_GMinus, 95, check)
      call createCurrent(P_GPlus, P_Hh, P_HMinus, 232, check)
      call createCurrent(P_dAnti, P_g, P_d, 2698, check)
      call createCurrent(P_G0, P_Ha, P_WMinus, P_WPlus, 2910, check)
      call createCurrent(P_Ha, P_dAnti, P_d, 888, check)
      call createCurrent(P_Z, P_HMinus, P_HPlus, P_A, 5, check)
      call createCurrent(P_HMinus, P_Ha, P_Hh, P_GPlus, 1067, check)
      call createCurrent(P_HPlus, P_nu_tauAnti, P_tauMinus, 1288, check)
      call createCurrent(P_nu_e, P_A, P_nu_eAnti, 3495, check)
      call createCurrent(P_c, P_cAnti, P_A, 30, check)
      call createCurrent(P_G0, P_GMinus, P_HPlus, P_Hh, 2502, check)
      call createCurrent(P_WMinus, P_HPlus, P_HMinus, P_WPlus, 1289, check)
      call createCurrent(P_Hl, P_HPlus, P_Z, P_WMinus, 348, check)
      call createCurrent(P_G0, P_A, P_Hh, 3167, check)
      call createCurrent(P_WPlus, P_Hl, P_Hl, P_WMinus, 264, check)
      call createCurrent(P_HMinus, P_HPlus, P_Hh, P_Ha, 3544, check)
      call createCurrent(P_Hl, P_Hl, P_G0, P_Ha, 860, check)
      call createCurrent(P_HPlus, P_GMinus, P_Ha, P_Ha, 1812, check)
      call createCurrent(P_nu_e, P_HMinus, P_ePlus, 558, check)
      call createCurrent(P_HMinus, P_GPlus, P_Hl, 78, check)
      call createCurrent(P_GMinus, P_HMinus, P_GPlus, P_GPlus, 1447, check)
      call createCurrent(P_GMinus, P_Ha, P_Hh, P_GPlus, 3414, check)
      call createCurrent(P_Ha, P_sAnti, P_s, 1151, check)
      call createCurrent(P_nu_mu, P_HMinus, P_muPlus, 2367, check)
      call createCurrent(P_Z, P_HPlus, P_Ha, P_WMinus, 842, check)
      call createCurrent(P_Z, P_Ha, P_GPlus, P_WMinus, 3244, check)
      call createCurrent(P_Hh, P_Ha, P_G0, P_G0, 3668, check)
      call createCurrent(P_tAnti, P_t, P_A, 426, check)
      call createCurrent(P_Hl, P_Z, P_A, P_Hl, 3549, check)
      call createCurrent(P_WMinus, P_WPlus, P_Hl, 964, check)
      call createCurrent(P_HMinus, P_G0, P_GPlus, P_Ha, 1567, check)
      call createCurrent(P_HMinus, P_ghWmAnti, P_ghZ, 3256, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_GPlus, 84, check)
      call createCurrent(P_HPlus, P_Hh, P_A, P_WMinus, 640, check)
      call createCurrent(P_Ha, P_HPlus, P_GMinus, P_G0, 1345, check)
      call createCurrent(P_Z, P_WMinus, P_Ha, P_GPlus, 3473, check)
      call createCurrent(P_Z, P_WMinus, P_WPlus, 1673, check)
      call createCurrent(P_HMinus, P_dAnti, P_u, 2390, check)
      call createCurrent(P_Z, P_WMinus, P_HPlus, P_Hl, 1491, check)
      call createCurrent(P_WMinus, P_Hl, P_WPlus, P_Hl, 1712, check)
      call createCurrent(P_c, P_sAnti, P_WMinus, 567, check)
      call createCurrent(P_WPlus, P_HPlus, P_HMinus, P_WMinus, 667, check)
      call createCurrent(P_A, P_d, P_dAnti, 496, check)
      call createCurrent(P_Ha, P_Hl, P_HMinus, P_GPlus, 1001, check)
      call createCurrent(P_GPlus, P_HMinus, P_G0, 943, check)
      call createCurrent(P_GPlus, P_tauMinus, P_nu_tauAnti, 2242, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_HPlus, 3482, check)
      call createCurrent(P_ePlus, P_Hh, P_eMinus, 554, check)
      call createCurrent(P_GMinus, P_HPlus, P_Hl, P_Hh, 1829, check)
      call createCurrent(P_Ha, P_GMinus, P_HPlus, 2206, check)
      call createCurrent(P_WPlus, P_ghZ, P_ghWpAnti, 784, check)
      call createCurrent(P_sAnti, P_s, 3060, check)
      call createCurrent(P_muPlus, P_nu_mu, P_WMinus, 800, check)
      call createCurrent(P_Z, P_A, 3300, check)
      call createCurrent(P_GPlus, P_HMinus, P_HPlus, P_HMinus, 173, check)
      call createCurrent(P_HPlus, P_A, P_HMinus, P_A, 867, check)
      call createCurrent(P_HMinus, P_WMinus, P_GPlus, P_WPlus, 3146, check)
      call createCurrent(P_A, P_Hl, P_Z, P_Hh, 3590, check)
      call createCurrent(P_Hl, P_Z, P_G0, 2387, check)
      call createCurrent(P_HMinus, P_Hl, P_G0, P_HPlus, 3180, check)
      call createCurrent(P_Z, P_A, P_Hl, P_Hh, 3611, check)
      call createCurrent(P_HPlus, P_Ha, P_Hl, P_HMinus, 2816, check)
      call createCurrent(P_Z, P_GPlus, P_HMinus, 3141, check)
      call createCurrent(P_Hl, P_GPlus, P_WMinus, P_Z, 2143, check)
      call createCurrent(P_G0, P_Hl, P_HPlus, P_HMinus, 3306, check)
      call createCurrent(P_HMinus, P_A, P_HPlus, P_A, 675, check)
      call createCurrent(P_ePlus, P_eMinus, P_Ha, 642, check)
      call createCurrent(P_HMinus, P_Hl, P_Hl, P_HPlus, 1121, check)
      call createCurrent(P_Hh, P_Hh, P_GMinus, P_HPlus, 1279, check)
      call createCurrent(P_G0, P_Ha, P_GMinus, P_HPlus, 518, check)
      call createCurrent(P_sAnti, P_A, P_s, 1955, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, P_G0, 1799, check)
      call createCurrent(P_nu_muAnti, P_muMinus, P_GPlus, 2177, check)
      call createCurrent(P_HPlus, P_G0, P_GMinus, P_Hl, 646, check)
      call createCurrent(P_GPlus, P_Hl, P_HMinus, 1772, check)
      call createCurrent(P_WMinus, P_GPlus, P_WPlus, P_GMinus, 1915, check)
      call createCurrent(P_A, P_Hl, P_Z, P_Hl, 3533, check)
      call createCurrent(P_GMinus, P_Ha, P_GPlus, 3269, check)
      call createCurrent(P_Hh, P_Hl, P_WPlus, P_WMinus, 3553, check)
      call createCurrent(P_HMinus, P_Hl, P_HPlus, P_G0, 3450, check)
      call createCurrent(P_WPlus, P_Hh, P_A, P_GMinus, 221, check)
      call createCurrent(P_Ha, P_Ha, P_G0, P_Ha, 2120, check)
      call createCurrent(P_GPlus, P_Hh, P_GMinus, 2230, check)
      call createCurrent(P_Z, P_A, P_HPlus, P_HMinus, 2426, check)
      call createCurrent(P_WPlus, P_WMinus, P_G0, P_Ha, 3285, check)
      call createCurrent(P_HPlus, P_HMinus, P_GPlus, P_HMinus, 2237, check)
      call createCurrent(P_Hh, P_Ha, P_Hl, P_Ha, 317, check)
      call createCurrent(P_HMinus, P_WPlus, P_GPlus, P_WMinus, 2957, check)
      call createCurrent(P_Hh, P_Hl, 3303, check)
      call createCurrent(P_Ha, P_G0, P_Hl, P_G0, 3764, check)
      call createCurrent(P_Hh, P_A, P_A, P_Hh, 3887, check)
      call createCurrent(P_Z, P_Hh, P_Z, P_Hl, 3366, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, P_Hh, 827, check)
      call createCurrent(P_HPlus, P_HMinus, P_Hl, 2480, check)
      call createCurrent(P_A, P_G0, P_HPlus, P_WMinus, 3052, check)
      call createCurrent(P_G0, P_A, P_A, P_G0, 3769, check)
      call createCurrent(P_Ha, P_GPlus, P_Hl, P_GMinus, 3035, check)
      call createCurrent(P_GPlus, P_GMinus, P_Hh, P_Ha, 2989, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, P_Ha, 3565, check)
      call createCurrent(P_A, P_A, P_Ha, P_G0, 3696, check)
      call createCurrent(P_WPlus, P_WMinus, P_Z, P_Z, 2414, check)
      call createCurrent(P_Hh, P_Z, P_WPlus, P_HMinus, 801, check)
      call createCurrent(P_HMinus, P_HPlus, P_Ha, P_Hh, 3438, check)
      call createCurrent(P_Ha, P_HPlus, P_WMinus, P_A, 531, check)
      call createCurrent(P_Z, P_WPlus, P_HMinus, P_Ha, 1324, check)
      call createCurrent(P_G0, P_WMinus, P_GPlus, P_A, 840, check)
      call createCurrent(P_Hl, P_G0, P_HPlus, P_HMinus, 2814, check)
      call createCurrent(P_Ha, P_Hh, P_Hl, P_Ha, 1723, check)
      call createCurrent(P_Z, P_nu_mu, P_nu_muAnti, 2438, check)
      call createCurrent(P_HMinus, P_GPlus, P_HPlus, P_HMinus, 1352, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, P_G0, 1164, check)
      call createCurrent(P_G0, P_GPlus, P_HMinus, P_Hh, 1505, check)
      call createCurrent(P_uAnti, P_u, P_g, 1563, check)
      call createCurrent(P_WMinus, P_Hh, P_HPlus, P_A, 1990, check)
      call createCurrent(P_Z, P_A, P_Hl, 3247, check)
      call createCurrent(P_WMinus, P_HPlus, P_Hl, P_Z, 2070, check)
      call createCurrent(P_G0, P_G0, P_Ha, P_Hl, 3799, check)
      call createCurrent(P_Hh, P_Ha, P_GMinus, P_HPlus, 637, check)
      call createCurrent(P_ghWp, P_A, P_ghWpAnti, 203, check)
      call createCurrent(P_Z, P_HPlus, P_A, P_GMinus, 3513, check)
      call createCurrent(P_Hh, P_Hh, P_GPlus, P_HMinus, 2501, check)
      call createCurrent(P_Hh, P_Hl, P_Hh, 1572, check)
      call createCurrent(P_Hh, P_A, P_Z, P_Hh, 3403, check)
      call createCurrent(P_g, P_HPlus, P_HMinus, P_g, 3722, check)
      call createCurrent(P_g, P_Ha, P_g, P_Ha, 3833, check)
      call createCurrent(P_u, P_uAnti, 3162, check)
      call createCurrent(P_u, P_uAnti, P_Ha, 1115, check)
      call createCurrent(P_G0, P_G0, P_HMinus, P_GPlus, 979, check)
      call createCurrent(P_HMinus, P_Hl, P_Z, P_WPlus, 1156, check)
      call createCurrent(P_A, P_A, P_GPlus, P_HMinus, 2933, check)
      call createCurrent(P_Z, P_HMinus, P_A, P_GPlus, 2902, check)
      call createCurrent(P_Z, P_Hh, P_GPlus, P_WMinus, 427, check)
      call createCurrent(P_ghWpAnti, P_Hh, P_ghWp, 927, check)
      call createCurrent(P_Ha, P_GMinus, P_Z, P_WPlus, 3078, check)
      call createCurrent(P_A, P_Z, P_G0, P_Ha, 3654, check)
      call createCurrent(P_Hl, P_Hl, P_Hl, P_Ha, 3624, check)
      call createCurrent(P_HMinus, P_WPlus, P_Hl, P_Z, 166, check)
      call createCurrent(P_GMinus, P_Hl, P_G0, P_GPlus, 3237, check)
      call createCurrent(P_Ha, P_G0, P_G0, P_Ha, 1722, check)
      call createCurrent(P_GPlus, P_HMinus, P_GPlus, P_HMinus, 2505, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_Hh, 1099, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, P_Ha, 3204, check)
      call createCurrent(P_ghZ, P_Hl, P_ghZAnti, 2525, check)
      call createCurrent(P_GPlus, P_Hl, P_Hl, P_GMinus, 569, check)
      call createCurrent(P_HPlus, P_G0, P_HMinus, P_Hl, 3404, check)
      call createCurrent(P_tauPlus, P_HMinus, P_nu_tau, 2404, check)
      call createCurrent(P_WMinus, P_Z, P_HPlus, P_Hl, 955, check)
      call createCurrent(P_Hh, P_muPlus, P_muMinus, 2584, check)
      call createCurrent(P_tAnti, P_t, P_Z, 405, check)
      call createCurrent(P_A, P_HPlus, P_A, P_GMinus, 3054, check)
      call createCurrent(P_A, P_HMinus, P_A, P_HPlus, 2423, check)
      call createCurrent(P_WPlus, P_GMinus, P_WMinus, P_GPlus, 908, check)
      call createCurrent(P_Hl, P_HMinus, P_HPlus, P_Ha, 2940, check)
      call createCurrent(P_GMinus, P_HPlus, P_Hh, 971, check)
      call createCurrent(P_GMinus, P_A, P_Hl, P_WPlus, 2527, check)
      call createCurrent(P_Hl, P_A, P_Hh, P_Z, 3865, check)
      call createCurrent(P_GPlus, P_WPlus, P_HMinus, P_WMinus, 2755, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, P_Hl, 481, check)
      call createCurrent(P_WMinus, P_G0, P_Z, P_GPlus, 2238, check)
      call createCurrent(P_Hl, P_Ha, P_Ha, 2301, check)
      call createCurrent(P_Ha, P_HPlus, P_GMinus, P_Ha, 34, check)
      call createCurrent(P_HMinus, P_WPlus, P_A, P_Hl, 709, check)
      call createCurrent(P_ghWmAnti, P_Z, P_ghWm, 219, check)
      call createCurrent(P_Hl, P_Ha, P_GMinus, P_HPlus, 1859, check)
      call createCurrent(P_Ha, P_HPlus, P_Hh, P_HMinus, 2718, check)
      call createCurrent(P_A, P_Hh, P_A, P_Hh, 3782, check)
      call createCurrent(P_Z, P_Hl, P_Z, P_Hh, 3390, check)
      call createCurrent(P_Hl, P_Hl, P_GPlus, P_GMinus, 1511, check)
      call createCurrent(P_GMinus, P_HPlus, P_Ha, P_G0, 1838, check)
      call createCurrent(P_HPlus, P_Hl, P_Ha, P_HMinus, 2952, check)
      call createCurrent(P_WMinus, P_A, P_HPlus, P_Ha, 823, check)
      call createCurrent(P_Z, P_Ha, P_Z, P_Ha, 556, check)
      call createCurrent(P_A, P_WPlus, P_HMinus, 2506, check)
      call createCurrent(P_HPlus, P_G0, P_Hh, P_GMinus, 1840, check)
      call createCurrent(P_HPlus, P_Hh, P_WMinus, 377, check)
      call createCurrent(P_GMinus, P_GMinus, P_HPlus, P_HPlus, 1884, check)
      call createCurrent(P_HMinus, P_ghZ, P_ghWmAnti, 3059, check)
      call createCurrent(P_Hl, P_HPlus, P_WMinus, P_Z, 967, check)
      call createCurrent(P_Hh, P_ghZAnti, P_ghZ, 1230, check)
      call createCurrent(P_WPlus, P_Z, P_HMinus, P_Hh, 835, check)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_HPlus, 304, check)
      call createCurrent(P_HPlus, P_GMinus, P_G0, P_G0, 580, check)
      call createCurrent(P_Hh, P_Hh, P_WPlus, P_WMinus, 1597, check)
      call createCurrent(P_G0, P_Z, P_WPlus, P_GMinus, 1774, check)
      call createCurrent(P_GMinus, P_G0, P_HPlus, P_Hl, 1366, check)
      call createCurrent(P_WPlus, P_A, P_HMinus, P_Hh, 1141, check)
      call createCurrent(P_Z, P_Z, P_GMinus, P_GPlus, 498, check)
      call createCurrent(P_Hh, P_Ha, P_GPlus, P_HMinus, 1182, check)
      call createCurrent(P_Ha, P_Hl, P_Hl, P_Ha, 1339, check)
      call createCurrent(P_d, P_uAnti, P_HPlus, 1155, check)
      call createCurrent(P_GPlus, P_eMinus, P_nu_eAnti, 1985, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Z, 1691, check)
      call createCurrent(P_GPlus, P_Ha, P_GMinus, P_Hl, 3399, check)
      call createCurrent(P_Hh, P_GMinus, P_Ha, P_HPlus, 1515, check)
      call createCurrent(P_Hh, P_Ha, P_A, 3207, check)
      call createCurrent(P_HPlus, P_GMinus, P_Hh, 2637, check)
      call createCurrent(P_G0, P_tAnti, P_t, 294, check)
      call createCurrent(P_HPlus, P_Z, P_Z, P_HMinus, 1268, check)
      call createCurrent(P_Z, P_G0, P_Z, P_G0, 2231, check)
      call createCurrent(P_Ha, P_Ha, P_HPlus, P_GMinus, 2040, check)
      call createCurrent(P_GPlus, P_A, P_G0, P_WMinus, 1862, check)
      call createCurrent(P_s, P_GPlus, P_cAnti, 2378, check)
      call createCurrent(P_HMinus, P_G0, P_GPlus, P_Hh, 1117, check)
      call createCurrent(P_Hl, P_Z, P_GMinus, P_WPlus, 2229, check)
      call createCurrent(P_HMinus, P_Z, P_GPlus, P_A, 2752, check)
      call createCurrent(P_dAnti, P_d, P_g, 1932, check)
      call createCurrent(P_WMinus, P_HPlus, P_G0, P_A, 2912, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Hh, 635, check)
      call createCurrent(P_GPlus, P_HMinus, P_Ha, P_Hl, 1086, check)
      call createCurrent(P_WMinus, P_G0, P_A, P_GPlus, 1193, check)
      call createCurrent(P_Z, P_Hl, P_Z, 209, check)
      call createCurrent(P_G0, P_Ha, P_Hl, P_Hh, 372, check)
      call createCurrent(P_sAnti, P_s, P_Z, 2122, check)
      call createCurrent(P_Hl, P_A, P_A, P_Hh, 3671, check)
      call createCurrent(P_GPlus, P_Hh, P_HMinus, P_Hh, 1542, check)
      call createCurrent(P_Hh, P_HMinus, P_Hh, P_HPlus, 845, check)
      call createCurrent(P_ePlus, P_eMinus, P_Hh, 961, check)
      call createCurrent(P_Hh, P_GPlus, P_WMinus, P_A, 2416, check)
      call createCurrent(P_HPlus, P_Z, P_WMinus, P_G0, 3375, check)
      call createCurrent(P_Hh, P_A, P_WPlus, P_HMinus, 278, check)
      call createCurrent(P_GMinus, P_A, P_A, P_GPlus, 843, check)
      call createCurrent(P_GPlus, P_s, P_cAnti, 1070, check)
      call createCurrent(P_GPlus, P_HMinus, P_A, P_Z, 3157, check)
      call createCurrent(P_HPlus, P_Z, P_Z, P_GMinus, 3535, check)
      call createCurrent(P_WMinus, P_HMinus, P_HPlus, P_WPlus, 1005, check)
      call createCurrent(P_A, P_HPlus, P_WMinus, P_G0, 3442, check)
      call createCurrent(P_uAnti, P_GPlus, P_d, 610, check)
      call createCurrent(P_A, P_WMinus, P_Hl, P_GPlus, 1440, check)
      call createCurrent(P_GPlus, P_HMinus, P_HMinus, P_HPlus, 2348, check)
      call createCurrent(P_s, P_sAnti, P_g, 1879, check)
      call createCurrent(P_uAnti, P_Z, P_u, 1256, check)
      call createCurrent(P_Ha, P_GPlus, P_Hh, P_HMinus, 1693, check)
      call createCurrent(P_GMinus, P_Hl, P_Z, P_WPlus, 1867, check)
      call createCurrent(P_Hh, P_GMinus, P_HPlus, P_Ha, 1035, check)
      call createCurrent(P_Ha, P_Ha, P_GPlus, P_HMinus, 700, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_WPlus, 1888, check)
      call createCurrent(P_Hh, P_tAnti, P_t, 2153, check)
      call createCurrent(P_Ha, P_Z, P_GPlus, P_WMinus, 2847, check)
      call createCurrent(P_A, P_Hl, P_HMinus, P_WPlus, 2393, check)
      call createCurrent(P_GPlus, P_Ha, P_Z, P_WMinus, 2955, check)
      call createCurrent(P_GPlus, P_Hh, P_Hl, P_HMinus, 1883, check)
      call createCurrent(P_d, P_dAnti, 3004, check)
      call createCurrent(P_HMinus, P_HPlus, P_Z, P_Z, 205, check)
      call createCurrent(P_G0, P_GPlus, P_Ha, P_HMinus, 975, check)
      call createCurrent(P_nu_e, P_ePlus, P_WMinus, 1900, check)
      call createCurrent(P_Hl, P_HPlus, P_GMinus, P_Hh, 992, check)
      call createCurrent(P_GPlus, P_Z, P_Ha, P_WMinus, 2707, check)
      call createCurrent(P_G0, P_Hh, P_Ha, P_Hl, 624, check)
      call createCurrent(P_A, P_Ha, P_GPlus, P_WMinus, 3190, check)
      call createCurrent(P_Z, P_nu_e, P_nu_eAnti, 2329, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghZAnti, 1744, check)
      call createCurrent(P_WPlus, P_Hh, P_HMinus, P_A, 8, check)
      call createCurrent(P_sAnti, P_s, P_Hl, 2666, check)
      call createCurrent(P_WMinus, P_WPlus, P_Hl, P_Hl, 451, check)
      call createCurrent(P_GMinus, P_HPlus, P_Hh, P_Hl, 1746, check)
      call createCurrent(P_Hl, P_HPlus, P_Ha, P_HMinus, 2804, check)
      call createCurrent(P_GPlus, P_HMinus, P_GMinus, P_GPlus, 1631, check)
      call createCurrent(P_WMinus, P_A, P_Hh, P_HPlus, 941, check)
      call createCurrent(P_Hl, P_Hl, P_Ha, P_G0, 2678, check)
      call createCurrent(P_GPlus, P_g, P_HMinus, P_g, 3594, check)
      call createCurrent(P_Ha, P_Z, P_G0, P_Z, 3318, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, P_Ha, 2980, check)
      call createCurrent(P_Hl, P_HMinus, P_Hh, P_HPlus, 1904, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, P_Ha, 3481, check)
      call createCurrent(P_Ha, P_HPlus, P_G0, P_GMinus, 2642, check)
      call createCurrent(P_Z, P_Z, P_HMinus, P_HPlus, 1592, check)
      call createCurrent(P_Z, P_WPlus, P_HMinus, P_Hh, 861, check)
      call createCurrent(P_Ha, P_HMinus, P_Hh, P_HPlus, 3581, check)
      call createCurrent(P_HMinus, P_nu_tau, P_tauPlus, 757, check)
      call createCurrent(P_G0, P_GMinus, P_HPlus, P_Ha, 378, check)
      call createCurrent(P_HMinus, P_GPlus, P_G0, P_Hh, 1192, check)
      call createCurrent(P_A, P_A, P_Hh, P_Hl, 3756, check)
      call createCurrent(P_WMinus, P_HPlus, P_Hh, P_Z, 17, check)
      call createCurrent(P_GPlus, P_G0, P_WMinus, P_Z, 2681, check)
      call createCurrent(P_G0, P_d, P_dAnti, 1868, check)
      call createCurrent(P_bAnti, P_G0, P_b, 1051, check)
      call createCurrent(P_GPlus, P_Hl, P_Hh, P_GMinus, 2690, check)
      call createCurrent(P_Hh, P_Hl, P_Ha, P_G0, 2055, check)
      call createCurrent(P_GMinus, P_Z, P_HPlus, 2896, check)
      call createCurrent(P_Hl, P_Ha, P_GMinus, P_GPlus, 3448, check)
      call createCurrent(P_GPlus, P_G0, P_GMinus, P_G0, 1599, check)
      call createCurrent(P_G0, P_HPlus, P_Z, P_WMinus, 3337, check)
      call createCurrent(P_Hh, P_HMinus, P_Hl, P_GPlus, 2427, check)
      call createCurrent(P_A, P_HPlus, P_HMinus, P_Z, 986, check)
      call createCurrent(P_G0, P_G0, P_Hh, P_Hh, 2031, check)
      call createCurrent(P_G0, P_Ha, P_GPlus, P_HMinus, 1433, check)
      call createCurrent(P_HMinus, P_WPlus, P_HPlus, P_WMinus, 2138, check)
      call createCurrent(P_GMinus, P_A, P_Hh, P_WPlus, 599, check)
      call createCurrent(P_A, P_Hh, P_G0, 3104, check)
      call createCurrent(P_GPlus, P_Ha, P_HMinus, P_Hl, 1204, check)
      call createCurrent(P_Z, P_HMinus, P_HPlus, 2073, check)
      call createCurrent(P_HPlus, P_WMinus, P_Ha, P_Z, 1342, check)
      call createCurrent(P_bAnti, P_Z, P_b, 322, check)
      call createCurrent(P_A, P_Z, P_Hl, P_Hl, 3044, check)
      call createCurrent(P_GMinus, P_HPlus, P_Ha, 1311, check)
      call createCurrent(P_Z, P_GMinus, P_Hh, P_WPlus, 1110, check)
      call createCurrent(P_Hh, P_Hh, P_G0, P_G0, 198, check)
      call createCurrent(P_HPlus, P_A, P_Ha, P_WMinus, 1661, check)
      call createCurrent(P_Ha, P_G0, P_HPlus, P_HMinus, 1716, check)
      call createCurrent(P_Hh, P_Ha, P_Ha, P_Hl, 1220, check)
      call createCurrent(P_d, P_dAnti, P_A, 350, check)
      call createCurrent(P_Z, P_GPlus, P_Z, P_GMinus, 674, check)
      call createCurrent(P_WMinus, P_Z, P_Hl, P_GPlus, 1178, check)
      call createCurrent(P_GMinus, P_G0, P_GPlus, P_Hh, 3506, check)
      call createCurrent(P_tAnti, P_Ha, P_t, 2635, check)
      call createCurrent(P_WPlus, P_G0, P_WMinus, P_Ha, 3036, check)
      call createCurrent(P_HMinus, P_WPlus, 3584, check)
      call createCurrent(P_g, P_g, P_A, P_g, 3814, check)
      call createCurrent(P_Hl, P_HMinus, P_HPlus, P_Hh, 2046, check)
      call createCurrent(P_HPlus, P_G0, P_Hl, P_GMinus, 1951, check)
      call createCurrent(P_Hl, P_A, P_G0, 3505, check)
      call createCurrent(P_g, P_G0, P_g, P_Ha, 3807, check)
      call createCurrent(P_GPlus, P_HMinus, P_Ha, P_Ha, 1998, check)
      call createCurrent(P_A, P_HPlus, P_HMinus, 1579, check)
      call createCurrent(P_WPlus, P_g, P_WMinus, P_g, 3644, check)
      call createCurrent(P_HPlus, P_WMinus, P_Ha, 2053, check)
      call createCurrent(P_G0, P_Hl, P_GPlus, P_GMinus, 3281, check)
      call createCurrent(P_Ha, P_GPlus, P_GMinus, P_Ha, 2148, check)
      call createCurrent(P_WPlus, P_WMinus, 3229, check)
      call createCurrent(P_G0, P_Z, P_WMinus, P_GPlus, 1616, check)
      call createCurrent(P_Hh, P_GPlus, P_Hh, P_HMinus, 1413, check)
      call createCurrent(P_HMinus, P_Z, P_Ha, P_WPlus, 178, check)
      call createCurrent(P_eMinus, P_Hl, P_ePlus, 716, check)
      call createCurrent(P_Hl, P_G0, P_HMinus, P_HPlus, 3348, check)
      call createCurrent(P_Z, P_nu_tauAnti, P_nu_tau, 1094, check)
      call createCurrent(P_HPlus, P_Hh, P_HMinus, P_Hl, 208, check)
      call createCurrent(P_WPlus, P_Ha, P_A, P_GMinus, 3082, check)
      call createCurrent(P_HPlus, P_G0, P_WMinus, P_Z, 3061, check)
      call createCurrent(P_Z, P_HPlus, P_HMinus, P_A, 1912, check)
      call createCurrent(P_HMinus, P_HPlus, P_G0, P_Hh, 2782, check)
      call createCurrent(P_A, P_HMinus, P_Ha, P_WPlus, 2436, check)
      call createCurrent(P_Hl, P_t, P_tAnti, 1438, check)
      call createCurrent(P_A, P_A, P_GMinus, P_GPlus, 1948, check)
      call createCurrent(P_HPlus, P_G0, P_WMinus, 2958, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_HMinus, 3501, check)
      call createCurrent(P_G0, P_Z, P_Ha, P_Z, 3406, check)
      call createCurrent(P_HMinus, P_Hl, P_WPlus, P_Z, 1379, check)
      call createCurrent(P_GMinus, P_Hl, P_Ha, P_HPlus, 142, check)
      call createCurrent(P_G0, P_WPlus, P_HMinus, P_Z, 2865, check)
      call createCurrent(P_HPlus, P_GMinus, P_Ha, 138, check)
      call createCurrent(P_Hl, P_G0, P_GMinus, P_HPlus, 1326, check)
      call createCurrent(P_WMinus, P_A, P_G0, P_GPlus, 114, check)
      call createCurrent(P_G0, P_GMinus, P_WPlus, P_A, 1780, check)
      call createCurrent(P_GPlus, P_A, P_A, P_GMinus, 2555, check)
      call createCurrent(P_eMinus, P_GPlus, P_nu_eAnti, 600, check)
      call createCurrent(P_A, P_G0, P_WPlus, P_HMinus, 3396, check)
      call createCurrent(P_G0, P_GPlus, P_Hh, P_HMinus, 244, check)
      call createCurrent(P_HPlus, P_nu_muAnti, P_muMinus, 1427, check)
      call createCurrent(P_Hl, P_WPlus, P_Z, P_HMinus, 411, check)
      call createCurrent(P_Ha, P_WPlus, P_Ha, P_WMinus, 2300, check)
      call createCurrent(P_GPlus, P_HMinus, P_G0, P_Hl, 866, check)
      call createCurrent(P_Hh, P_A, P_Z, P_Hl, 3867, check)
      call createCurrent(P_A, P_Z, P_A, P_Z, 3665, check)
      call createCurrent(P_G0, P_Hh, P_Ha, 1405, check)
      call createCurrent(P_HMinus, P_GPlus, P_Hl, P_Hh, 1125, check)
      call createCurrent(P_d, P_G0, P_dAnti, 2020, check)
      call createCurrent(P_GMinus, P_GPlus, P_Hl, P_Ha, 3486, check)
      call createCurrent(P_s, P_WPlus, P_cAnti, 2072, check)
      call createCurrent(P_dAnti, P_d, P_A, 1683, check)
      call createCurrent(P_HPlus, P_Hh, P_Hh, P_HMinus, 2410, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, P_Hl, 2193, check)
      call createCurrent(P_dAnti, P_WMinus, P_u, 1665, check)
      call createCurrent(P_Hh, P_g, P_g, P_Hh, 3649, check)
      call createCurrent(P_Hl, P_WPlus, P_GMinus, P_Z, 462, check)
      call createCurrent(P_HMinus, P_Ha, P_HPlus, P_Hl, 2748, check)
      call createCurrent(P_uAnti, P_d, P_HPlus, 153, check)
      call createCurrent(P_Z, P_HPlus, P_Hh, P_WMinus, 247, check)
      call createCurrent(P_Ha, P_G0, P_HMinus, P_HPlus, 854, check)
      call createCurrent(P_HMinus, P_A, P_WPlus, P_Hl, 1249, check)
      call createCurrent(P_HMinus, P_GMinus, P_HPlus, P_GPlus, 2026, check)
      call createCurrent(P_A, P_Ha, P_Hl, 3392, check)
      call createCurrent(P_GPlus, P_Hh, P_Ha, P_HMinus, 2361, check)
      call createCurrent(P_Ha, P_G0, P_Hl, P_Hh, 2276, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Ha, 2811, check)
      call createCurrent(P_dAnti, P_d, P_Hh, 1552, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, P_G0, 2349, check)
      call createCurrent(P_Z, P_HPlus, P_Z, P_GMinus, 3160, check)
      call createCurrent(P_Z, P_Hh, P_Z, 978, check)
      call createCurrent(P_WMinus, P_Hl, P_Z, P_HPlus, 1499, check)
      call createCurrent(P_Z, P_Z, P_Z, P_A, 3647, check)
      call createCurrent(P_Ha, P_GMinus, P_HPlus, P_Hl, 2376, check)
      call createCurrent(P_Ha, P_GMinus, P_Hh, P_GPlus, 2798, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, P_Hl, 870, check)
      call createCurrent(P_ghWpAnti, P_A, P_ghWp, 1242, check)
      call createCurrent(P_Ha, P_GPlus, P_HMinus, 1684, check)
      call createCurrent(P_Ha, P_WMinus, P_GPlus, 2876, check)
      call createCurrent(P_HPlus, P_nu_eAnti, P_eMinus, 391, check)
      call createCurrent(P_G0, P_GMinus, P_Z, P_WPlus, 2580, check)
      call createCurrent(P_uAnti, P_u, P_Hh, 884, check)
      call createCurrent(P_HPlus, P_HPlus, P_GMinus, P_GMinus, 1787, check)
      call createCurrent(P_Hh, P_Z, P_GPlus, P_WMinus, 410, check)
      call createCurrent(P_Hh, P_GMinus, P_G0, P_HPlus, 1482, check)
      call createCurrent(P_g, P_Hl, P_Hl, P_g, 3821, check)
      call createCurrent(P_WMinus, P_HPlus, P_G0, 2709, check)
      call createCurrent(P_A, P_Ha, P_A, P_Ha, 3745, check)
      call createCurrent(P_G0, P_GMinus, P_Ha, P_GPlus, 471, check)
      call createCurrent(P_nu_muAnti, P_nu_mu, 3006, check)
      call createCurrent(P_GPlus, P_g, P_GMinus, P_g, 3797, check)
      call createCurrent(P_WMinus, P_HPlus, P_Hh, P_A, 2059, check)
      call createCurrent(P_GPlus, P_Hh, P_WMinus, 1191, check)
      call createCurrent(P_Hl, P_Hh, P_HPlus, P_HMinus, 807, check)
      call createCurrent(P_Hh, P_A, P_G0, 2852, check)
      call createCurrent(P_A, P_Z, P_WMinus, P_WPlus, 564, check)
      call createCurrent(P_Hl, P_Ha, P_Hh, P_Ha, 2321, check)
      call createCurrent(P_Ha, P_WPlus, P_GMinus, P_Z, 3546, check)
      call createCurrent(P_Hl, P_HMinus, P_HPlus, 1300, check)
      call createCurrent(P_G0, P_Hl, P_G0, P_Hl, 2615, check)
      call createCurrent(P_Ha, P_Hh, P_Hh, P_Hh, 3839, check)
      call createCurrent(P_A, P_s, P_sAnti, 636, check)
      call createCurrent(P_WMinus, P_A, P_WPlus, P_Z, 1088, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, 1647, check)
      call createCurrent(P_HMinus, P_HPlus, P_A, P_A, 2542, check)
      call createCurrent(P_Hl, P_G0, P_GPlus, P_HMinus, 1906, check)
      call createCurrent(P_Ha, P_WPlus, P_GMinus, 3170, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, P_Ha, 3516, check)
      call createCurrent(P_A, P_WMinus, P_Z, P_WPlus, 760, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, P_Hh, 1882, check)
      call createCurrent(P_GMinus, P_Hl, P_GPlus, P_Hl, 1764, check)
      call createCurrent(P_WPlus, P_Ha, P_Z, P_GMinus, 3301, check)
      call createCurrent(P_d, P_g, P_dAnti, 437, check)
      call createCurrent(P_g, P_t, P_tAnti, 2260, check)
      call createCurrent(P_GPlus, P_Ha, P_Ha, P_GMinus, 1314, check)
      call createCurrent(P_ghWm, P_HPlus, P_ghZAnti, 2792, check)
      call createCurrent(P_G0, P_HPlus, P_HMinus, P_Ha, 2569, check)
      call createCurrent(P_GMinus, P_HPlus, P_A, P_A, 2858, check)
      call createCurrent(P_HPlus, P_Ha, P_WMinus, P_A, 2128, check)
      call createCurrent(P_HMinus, P_ghWp, P_ghZAnti, 3024, check)
      call createCurrent(P_G0, P_HPlus, P_GMinus, P_Hh, 578, check)
      call createCurrent(P_A, P_GPlus, P_A, P_HMinus, 2831, check)
      call createCurrent(P_A, P_Z, P_Z, P_A, 3674, check)
      call createCurrent(P_GMinus, P_Hl, P_WPlus, 1652, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghZ, 1874, check)
      call createCurrent(P_GMinus, P_Hh, P_Hh, P_GPlus, 165, check)
      call createCurrent(P_Ha, P_g, P_G0, P_g, 3612, check)
      call createCurrent(P_nu_mu, P_nu_muAnti, 2726, check)
      call createCurrent(P_HMinus, P_WPlus, P_Z, 1122, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, 532, check)
      call createCurrent(P_GMinus, P_WMinus, P_WPlus, P_HPlus, 3183, check)
      call createCurrent(P_WPlus, P_GMinus, P_Hh, P_Z, 2154, check)
      call createCurrent(P_A, P_WMinus, P_G0, P_GPlus, 2208, check)
      call createCurrent(P_Ha, P_HMinus, P_Ha, P_GPlus, 1136, check)
      call createCurrent(P_s, P_Ha, P_sAnti, 1376, check)
      call createCurrent(P_u, P_uAnti, P_Z, 367, check)
      call createCurrent(P_WMinus, P_HPlus, P_Ha, P_A, 1810, check)
      call createCurrent(P_GPlus, P_GMinus, P_Hh, P_G0, 2825, check)
      call createCurrent(P_WPlus, P_Hh, P_Z, P_GMinus, 1975, check)
      call createCurrent(P_HPlus, P_WMinus, P_A, 2623, check)
      call createCurrent(P_WMinus, P_Hh, P_A, P_GPlus, 1506, check)
      call createCurrent(P_G0, P_HPlus, P_A, P_WMinus, 3518, check)
      call createCurrent(P_nu_eAnti, P_nu_e, P_Z, 1472, check)
      call createCurrent(P_t, P_bAnti, P_WMinus, 614, check)
      call createCurrent(P_Hh, P_c, P_cAnti, 1255, check)
      call createCurrent(P_Hl, P_G0, P_G0, P_Hl, 1623, check)
      call createCurrent(P_HMinus, P_bAnti, P_t, 2209, check)
      call createCurrent(P_WMinus, P_Ha, P_Z, P_GPlus, 3499, check)
      call createCurrent(P_G0, P_HPlus, P_Ha, P_HMinus, 2110, check)
      call createCurrent(P_g, P_b, P_bAnti, 2144, check)
      call createCurrent(P_A, P_b, P_bAnti, 1944, check)
      call createCurrent(P_ePlus, P_eMinus, P_G0, 1203, check)
      call createCurrent(P_G0, P_HMinus, P_GPlus, 1266, check)
      call createCurrent(P_G0, P_G0, P_Z, P_A, 3311, check)
      call createCurrent(P_WPlus, P_WMinus, P_Z, 1604, check)
      call createCurrent(P_HMinus, P_ghA, P_ghWmAnti, 3089, check)
      call createCurrent(P_HMinus, P_WPlus, P_Hl, 2407, check)
      call createCurrent(P_Hh, P_HMinus, P_HPlus, P_Hl, 1450, check)
      call createCurrent(P_g, P_Z, P_Z, P_g, 3652, check)
      call createCurrent(P_Hh, P_GPlus, P_Ha, P_HMinus, 356, check)
      call createCurrent(P_A, P_Z, P_WPlus, P_WMinus, 1358, check)
      call createCurrent(P_GMinus, P_nu_tau, P_tauPlus, 204, check)
      call createCurrent(P_Ha, P_Ha, P_Z, P_Z, 73, check)
      call createCurrent(P_Ha, P_GMinus, P_GPlus, P_Hl, 3401, check)
      call createCurrent(P_HPlus, P_HMinus, P_A, 2164, check)
      call createCurrent(P_HPlus, P_Ha, P_G0, P_HMinus, 1978, check)
      call createCurrent(P_Z, P_HPlus, P_G0, P_WMinus, 3455, check)
      call createCurrent(P_g, P_Hh, P_g, P_Hh, 3863, check)
      call createCurrent(P_A, P_Hh, P_Z, P_Hl, 3844, check)
      call createCurrent(P_b, P_HPlus, P_tAnti, 581, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, P_Ha, 2887, check)
      call createCurrent(P_HPlus, P_HMinus, P_Ha, P_G0, 220, check)
      call createCurrent(P_Hh, P_GPlus, P_GMinus, P_Ha, 3302, check)
      call createCurrent(P_Ha, P_HMinus, P_GPlus, 2190, check)
      call createCurrent(P_Hl, P_Ha, P_Hl, P_Hl, 3886, check)
      call createCurrent(P_A, P_WPlus, P_G0, P_GMinus, 2071, check)
      call createCurrent(P_Z, P_Hh, P_Ha, 552, check)
      call createCurrent(P_Hl, P_GPlus, P_G0, P_GMinus, 2994, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_Hl, 2473, check)
      call createCurrent(P_A, P_GMinus, P_Hh, P_WPlus, 2083, check)
      call createCurrent(P_G0, P_G0, P_Ha, 3761, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Ha, 2754, check)
      call createCurrent(P_G0, P_GPlus, P_GMinus, P_Hl, 3578, check)
      call createCurrent(P_WPlus, P_WMinus, P_WMinus, P_WPlus, 822, check)
      call createCurrent(P_Hl, P_GPlus, P_Hh, P_GMinus, 1476, check)
      call createCurrent(P_G0, P_WPlus, P_Z, P_HMinus, 3116, check)
      call createCurrent(P_Ha, P_A, P_WMinus, P_HPlus, 2133, check)
      call createCurrent(P_g, P_GPlus, P_GMinus, P_g, 3812, check)
      call createCurrent(P_Hl, P_Ha, P_A, 2974, check)
      call createCurrent(P_A, P_Ha, P_HMinus, P_WPlus, 1946, check)
      call createCurrent(P_HPlus, P_A, P_GMinus, P_Z, 3527, check)
      call createCurrent(P_Ha, P_Hh, P_HMinus, P_HPlus, 3028, check)
      call createCurrent(P_WMinus, P_WPlus, P_GPlus, P_GMinus, 362, check)
      call createCurrent(P_G0, P_A, P_G0, P_Z, 3347, check)
      call createCurrent(P_HPlus, P_WMinus, P_Z, P_Hh, 1451, check)
      call createCurrent(P_HPlus, P_HMinus, P_HPlus, P_HMinus, 1494, check)
      call createCurrent(P_ghZ, P_HPlus, P_ghWpAnti, 3488, check)
      call createCurrent(P_WPlus, P_muMinus, P_nu_muAnti, 2266, check)
      call createCurrent(P_HMinus, P_A, P_Hh, P_WPlus, 681, check)
      call createCurrent(P_sAnti, P_s, P_G0, 1448, check)
      call createCurrent(P_HPlus, P_WMinus, P_Hl, P_A, 1109, check)
      call createCurrent(P_HMinus, P_Hh, P_A, P_WPlus, 838, check)
      call createCurrent(P_Z, P_Z, P_HPlus, P_HMinus, 2320, check)
      call createCurrent(P_HMinus, P_HMinus, P_HPlus, P_HPlus, 995, check)
      call createCurrent(P_WPlus, P_A, P_Ha, P_HMinus, 538, check)
      call createCurrent(P_A, P_HPlus, P_WMinus, 71, check)
      call createCurrent(P_b, P_Hl, P_bAnti, 2140, check)
      call createCurrent(P_A, P_Hl, P_A, P_Hh, 3705, check)
      call createCurrent(P_HPlus, P_GMinus, P_Hl, P_Ha, 2221, check)
      call createCurrent(P_u, P_G0, P_uAnti, 1803, check)
      call createCurrent(P_Hl, P_GMinus, P_Ha, P_GPlus, 3446, check)
      call createCurrent(P_Ha, P_GPlus, P_Hh, P_GMinus, 3407, check)
      call createCurrent(P_Z, P_Hh, P_Hh, P_A, 3272, check)
      call createCurrent(P_g, P_HPlus, P_GMinus, P_g, 3676, check)
      call createCurrent(P_Hl, P_HMinus, P_Hl, P_GPlus, 2702, check)
      call createCurrent(P_G0, P_HMinus, P_Hl, P_HPlus, 2943, check)
      call createCurrent(P_GMinus, P_GPlus, P_Hl, P_Hh, 915, check)
      call createCurrent(P_HMinus, P_HPlus, P_G0, P_Hl, 2786, check)
      call createCurrent(P_Ha, P_Hl, P_Ha, P_Hh, 28, check)
      call createCurrent(P_Hl, P_Ha, P_GPlus, P_GMinus, 3571, check)
      call createCurrent(P_A, P_G0, P_G0, P_Z, 3151, check)
      call createCurrent(P_Hh, P_WMinus, P_HPlus, P_A, 494, check)
      call createCurrent(P_HPlus, P_Hh, P_HMinus, 1686, check)
      call createCurrent(P_G0, P_sAnti, P_s, 452, check)
      call createCurrent(P_Ha, P_HPlus, P_Ha, P_GMinus, 510, check)
      call createCurrent(P_Hl, P_GPlus, P_GMinus, P_G0, 3568, check)
      call createCurrent(P_G0, P_Ha, P_Hl, P_G0, 3817, check)
      call createCurrent(P_GPlus, P_Hl, P_G0, P_HMinus, 382, check)
      call createCurrent(P_Hl, P_A, P_HPlus, P_WMinus, 972, check)
      call createCurrent(P_G0, P_GPlus, P_Hl, P_HMinus, 59, check)
      call createCurrent(P_Z, P_Hl, P_WPlus, P_GMinus, 2286, check)
      call createCurrent(P_ghWmAnti, P_G0, P_ghWm, 1004, check)
      call createCurrent(P_GPlus, P_Hh, P_Ha, P_GMinus, 2737, check)
      call createCurrent(P_WPlus, P_A, P_WMinus, 1260, check)
      call createCurrent(P_HPlus, P_Ha, P_HMinus, P_Ha, 1701, check)
      call createCurrent(P_Hh, P_A, P_Hh, P_Z, 2837, check)
      call createCurrent(P_eMinus, P_ePlus, P_A, 1239, check)
      call createCurrent(P_A, P_HMinus, P_WPlus, P_Hh, 1680, check)
      call createCurrent(P_HMinus, P_Hh, P_WPlus, 1778, check)
      call createCurrent(P_Hh, P_WMinus, P_HPlus, P_Z, 2428, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_G0, 1580, check)
      call createCurrent(P_g, P_g, P_GMinus, P_HPlus, 3842, check)
      call createCurrent(P_G0, P_Hl, P_Ha, P_Hl, 1509, check)
      call createCurrent(P_A, P_tauMinus, P_tauPlus, 2106, check)
      call createCurrent(P_G0, P_GMinus, P_A, P_WPlus, 703, check)
      call createCurrent(P_HMinus, P_nu_e, P_ePlus, 851, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, P_G0, 525, check)
      call createCurrent(P_G0, P_WPlus, P_Ha, P_WMinus, 3574, check)
      call createCurrent(P_GMinus, P_Hh, P_G0, P_HPlus, 461, check)
      call createCurrent(P_GPlus, P_Hl, P_Hl, P_HMinus, 271, check)
      call createCurrent(P_HMinus, P_u, P_dAnti, 1460, check)
      call createCurrent(P_HPlus, P_Hh, P_Z, P_WMinus, 982, check)
      call createCurrent(P_G0, P_Hh, P_Hl, P_Ha, 1646, check)
      call createCurrent(P_HPlus, P_G0, P_GMinus, P_Ha, 634, check)
      call createCurrent(P_A, P_Hl, P_Hh, P_A, 3785, check)
      call createCurrent(P_uAnti, P_G0, P_u, 2382, check)
      call createCurrent(P_d, P_GPlus, P_uAnti, 847, check)
      call createCurrent(P_GMinus, P_Ha, P_Ha, P_HPlus, 923, check)
      call createCurrent(P_Ha, P_Hl, P_GMinus, P_GPlus, 3387, check)
      call createCurrent(P_Z, P_GMinus, P_Z, P_GPlus, 342, check)
      call createCurrent(P_GMinus, P_GPlus, P_G0, P_Hh, 2874, check)
      call createCurrent(P_Hl, P_WMinus, P_Z, P_HPlus, 1223, check)
      call createCurrent(P_GMinus, P_GPlus, P_Z, 832, check)
      call createCurrent(P_WPlus, P_Z, P_Ha, P_HMinus, 2483, check)
      call createCurrent(P_d, P_dAnti, P_G0, 151, check)
      call createCurrent(P_HMinus, P_WPlus, P_Ha, P_A, 1190, check)
      call createCurrent(P_Hh, P_A, P_Hh, P_A, 3798, check)
      call createCurrent(P_WMinus, P_WPlus, P_WMinus, P_WPlus, 1022, check)
      call createCurrent(P_Hl, P_HMinus, P_G0, P_HPlus, 2931, check)
      call createCurrent(P_Hh, P_Hh, P_GPlus, P_GMinus, 290, check)
      call createCurrent(P_Ha, P_HPlus, P_WMinus, P_Z, 1038, check)
      call createCurrent(P_GPlus, P_WMinus, P_Hh, P_Z, 1885, check)
      call createCurrent(P_HPlus, P_Ha, P_GMinus, 338, check)
      call createCurrent(P_WPlus, P_WMinus, P_G0, P_G0, 435, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_WPlus, 2547, check)
      call createCurrent(P_Z, P_HMinus, P_Hl, P_WPlus, 303, check)
      call createCurrent(P_HPlus, P_Hh, P_WMinus, P_A, 1270, check)
      call createCurrent(P_Ha, P_Hh, P_G0, P_Hh, 805, check)
      call createCurrent(P_GMinus, P_HPlus, P_WMinus, P_WPlus, 3250, check)
      call createCurrent(P_G0, P_HPlus, P_Ha, P_GMinus, 2622, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_GMinus, 1598, check)
      call createCurrent(P_HPlus, P_HMinus, P_G0, 2998, check)
      call createCurrent(P_Ha, P_WMinus, P_Z, P_GPlus, 2777, check)
      call createCurrent(P_Hh, P_uAnti, P_u, 2565, check)
      call createCurrent(P_Hl, P_Hh, P_g, P_g, 3617, check)
      call createCurrent(P_Z, P_A, P_GPlus, P_HMinus, 3029, check)
      call createCurrent(P_Hh, P_HPlus, P_HMinus, P_Ha, 2962, check)
      call createCurrent(P_s, P_Hl, P_sAnti, 1309, check)
      call createCurrent(P_uAnti, P_u, P_Ha, 1872, check)
      call createCurrent(P_Z, P_eMinus, P_ePlus, 1216, check)
      call createCurrent(P_Hl, P_GMinus, P_HPlus, P_Ha, 1449, check)
      call createCurrent(P_GMinus, P_G0, P_Hl, P_GPlus, 3384, check)
      call createCurrent(P_g, P_g, P_g, P_Z, 3880, check)
      call createCurrent(P_A, P_HMinus, P_HPlus, 1152, check)
      call createCurrent(P_Ha, P_Hh, P_HMinus, P_GPlus, 2271, check)
      call createCurrent(P_Ha, P_Ha, P_WPlus, P_WMinus, 1441, check)
      call createCurrent(P_WMinus, P_Hh, P_WPlus, P_Hh, 1175, check)
      call createCurrent(P_WMinus, P_Z, P_Ha, P_HPlus, 588, check)
      call createCurrent(P_Hh, P_Ha, P_HMinus, P_GPlus, 40, check)
      call createCurrent(P_WPlus, P_Hl, P_WMinus, 1726, check)
      call createCurrent(P_WMinus, P_Hh, P_Hh, P_WPlus, 268, check)
      call createCurrent(P_Z, P_WPlus, P_G0, P_GMinus, 2168, check)
      call createCurrent(P_muPlus, P_GMinus, P_nu_mu, 2296, check)
      call createCurrent(P_HMinus, P_G0, P_Ha, P_HPlus, 102, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_GMinus, 670, check)
      call createCurrent(P_A, P_tauPlus, P_tauMinus, 1534, check)
      call createCurrent(P_Hh, P_GPlus, P_G0, P_HMinus, 1280, check)
      call createCurrent(P_Hh, P_Hl, P_Hl, P_Hh, 1365, check)
      call createCurrent(P_A, P_HMinus, P_Hl, P_WPlus, 0, check)
      call createCurrent(P_HPlus, P_GMinus, P_A, P_Z, 3457, check)
      call createCurrent(P_Hh, P_Ha, P_G0, P_Hh, 1417, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_G0, 2267, check)
      call createCurrent(P_Hh, P_Hh, P_Hl, P_Hl, 619, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, P_Hl, 1425, check)
      call createCurrent(P_Ha, P_d, P_dAnti, 2467, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, 1852, check)
      call createCurrent(P_GMinus, P_A, P_G0, P_WPlus, 90, check)
      call createCurrent(P_d, P_uAnti, P_WPlus, 2047, check)
      call createCurrent(P_Hl, P_sAnti, P_s, 1795, check)
      call createCurrent(P_G0, P_Z, P_Hl, 117, check)
      call createCurrent(P_c, P_Z, P_cAnti, 122, check)
      call createCurrent(P_HPlus, P_WMinus, P_Hl, P_Z, 2405, check)
      call createCurrent(P_WMinus, P_Z, P_HPlus, P_Ha, 985, check)
      call createCurrent(P_Z, P_HPlus, P_WMinus, 2038, check)
      call createCurrent(P_G0, P_GPlus, P_WMinus, P_Z, 1869, check)
      call createCurrent(P_Ha, P_G0, P_Ha, P_Ha, 869, check)
      call createCurrent(P_Ha, P_WPlus, P_WMinus, P_Ha, 1776, check)
      call createCurrent(P_WPlus, P_Z, P_Hh, P_HMinus, 593, check)
      call createCurrent(P_G0, P_GMinus, P_WPlus, P_Z, 1982, check)
      call createCurrent(P_HPlus, P_Hl, P_WMinus, P_A, 398, check)
      call createCurrent(P_G0, P_Ha, P_g, P_g, 3692, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_Hl, 1429, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, P_Ha, 2733, check)
      call createCurrent(P_HPlus, P_G0, P_Ha, P_HMinus, 254, check)
      call createCurrent(P_Hh, P_Z, P_Z, P_Hl, 2778, check)
      call createCurrent(P_g, P_g, 3131, check)
      call createCurrent(P_Hl, P_HMinus, P_A, P_WPlus, 1804, check)
      call createCurrent(P_G0, P_G0, P_Hh, 1207, check)
      call createCurrent(P_Hl, P_GPlus, P_Hl, P_GMinus, 2196, check)
      call createCurrent(P_G0, P_WPlus, P_HMinus, 3113, check)
      call createCurrent(P_A, P_HMinus, P_Z, P_HPlus, 732, check)
      call createCurrent(P_GPlus, P_GMinus, P_Ha, 3156, check)
      call createCurrent(P_WMinus, P_Hl, P_GPlus, P_A, 1875, check)
      call createCurrent(P_WPlus, P_nu_eAnti, P_eMinus, 916, check)
      call createCurrent(P_WPlus, P_A, P_G0, P_GMinus, 2559, check)
      call createCurrent(P_G0, P_Ha, P_Hh, P_Hl, 1694, check)
      call createCurrent(P_Hh, P_GPlus, P_GMinus, P_Hh, 459, check)
      call createCurrent(P_Z, P_Ha, P_A, P_Ha, 3030, check)
      call createCurrent(P_Hh, P_HPlus, P_HMinus, 2003, check)
      call createCurrent(P_WPlus, P_Ha, P_GMinus, P_A, 3580, check)
      call createCurrent(P_Hh, P_GMinus, P_WPlus, 966, check)
      call createCurrent(P_ghA, P_HPlus, P_ghWpAnti, 3339, check)
      call createCurrent(P_A, P_eMinus, P_ePlus, 1486, check)
      call createCurrent(P_G0, P_Ha, P_G0, P_Hl, 3841, check)
      call createCurrent(P_HMinus, P_HPlus, P_GMinus, P_GPlus, 738, check)
      call createCurrent(P_c, P_cAnti, P_Hh, 1696, check)
      call createCurrent(P_GPlus, P_GMinus, P_g, P_g, 3601, check)
      call createCurrent(P_G0, P_G0, P_Hl, P_Hl, 1305, check)
      call createCurrent(P_u, P_uAnti, P_g, 2029, check)
      call createCurrent(P_A, P_Hl, P_GMinus, P_WPlus, 2351, check)
      call createCurrent(P_ghWm, P_Hh, P_ghWmAnti, 33, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghA, 48, check)
      call createCurrent(P_HPlus, P_WMinus, P_Hl, 1194, check)
      call createCurrent(P_HMinus, P_HPlus, 3223, check)
      call createCurrent(P_Hl, P_Hh, P_A, P_A, 3610, check)
      call createCurrent(P_HPlus, P_A, P_WMinus, P_Ha, 2606, check)
      call createCurrent(P_WPlus, P_Hh, P_HMinus, 1462, check)
      call createCurrent(P_WMinus, P_Hh, P_Z, P_HPlus, 2219, check)
      call createCurrent(P_Hh, P_WMinus, P_WPlus, 1400, check)
      call createCurrent(P_HPlus, P_A, P_HMinus, 707, check)
      call createCurrent(P_HPlus, P_HMinus, P_Hl, P_G0, 3299, check)
      call createCurrent(P_Hh, P_HPlus, P_Ha, P_HMinus, 3275, check)
      call createCurrent(P_GMinus, P_GMinus, P_GPlus, P_HPlus, 2507, check)
      call createCurrent(P_Ha, P_Hl, P_GMinus, P_HPlus, 1672, check)
      call createCurrent(P_Hl, P_Z, P_A, P_Hh, 3780, check)
      call createCurrent(P_Hh, P_GMinus, P_HPlus, P_G0, 639, check)
      call createCurrent(P_A, P_G0, P_WMinus, P_GPlus, 2633, check)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_HPlus, 305, check)
      call createCurrent(P_WPlus, P_GMinus, 3072, check)
      call createCurrent(P_A, P_WMinus, P_Ha, P_GPlus, 3356, check)
      call createCurrent(P_Hl, P_Ha, P_Ha, P_Hl, 1966, check)
      call createCurrent(P_G0, P_GPlus, P_Hl, P_GMinus, 2835, check)
      call createCurrent(P_G0, P_HMinus, P_WPlus, P_A, 2855, check)
      call createCurrent(P_u, P_g, P_uAnti, 2609, check)
      call createCurrent(P_GPlus, P_G0, P_Z, P_WMinus, 2391, check)
      call createCurrent(P_WMinus, P_WPlus, P_HPlus, P_HMinus, 2043, check)
      call createCurrent(P_GMinus, P_WPlus, P_Ha, P_Z, 2869, check)
      call createCurrent(P_A, P_WPlus, P_Hh, P_GMinus, 717, check)
      call createCurrent(P_Hh, P_g, P_g, 3847, check)
      call createCurrent(P_HPlus, P_GMinus, P_Hl, 704, check)
      call createCurrent(P_WMinus, P_Hl, P_WPlus, P_Hh, 3480, check)
      call createCurrent(P_Hl, P_GPlus, P_Ha, P_GMinus, 3118, check)
      call createCurrent(P_nu_tauAnti, P_GPlus, P_tauMinus, 596, check)
      call createCurrent(P_A, P_WPlus, P_Z, P_WMinus, 2608, check)
      call createCurrent(P_A, P_Ha, P_Hh, 3114, check)
      call createCurrent(P_G0, P_Hl, P_Ha, P_G0, 3675, check)
      call createCurrent(P_Hl, P_G0, P_G0, 1855, check)
      call createCurrent(P_GPlus, P_G0, P_Hl, P_GMinus, 3070, check)
      call createCurrent(P_ePlus, P_eMinus, P_A, 381, check)
      call createCurrent(P_HMinus, P_GPlus, P_G0, P_G0, 371, check)
      call createCurrent(P_Z, P_Hl, P_A, 2722, check)
      call createCurrent(P_Hl, P_WMinus, P_Hl, P_WPlus, 1105, check)
      call createCurrent(P_GMinus, P_G0, P_GPlus, P_Hl, 2999, check)
      call createCurrent(P_HMinus, P_Ha, P_GPlus, P_Ha, 2579, check)
      call createCurrent(P_cAnti, P_c, 3191, check)
      call createCurrent(P_A, P_HMinus, P_WPlus, P_Ha, 324, check)
      call createCurrent(P_Hl, P_GMinus, P_GPlus, P_Hl, 2441, check)
      call createCurrent(P_ePlus, P_eMinus, P_Hl, 2095, check)
      call createCurrent(P_Hh, P_GMinus, P_HPlus, P_Hl, 1024, check)
      call createCurrent(P_G0, P_HMinus, P_Z, P_WPlus, 3542, check)
      call createCurrent(P_HMinus, P_G0, P_G0, P_GPlus, 497, check)
      call createCurrent(P_Ha, P_WMinus, P_WPlus, P_Ha, 1988, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghAAnti, 394, check)
      call createCurrent(P_dAnti, P_HMinus, P_u, 1461, check)
      call createCurrent(P_muMinus, P_nu_muAnti, P_GPlus, 336, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_HMinus, 3080, check)
      call createCurrent(P_Ha, P_Hh, P_HPlus, P_HMinus, 3058, check)
      call createCurrent(P_HPlus, P_G0, P_GMinus, P_Hh, 1100, check)
      call createCurrent(P_WPlus, P_G0, P_GMinus, 591, check)
      call createCurrent(P_WPlus, P_GMinus, P_G0, P_Z, 2691, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_HPlus, 3474, check)
      call createCurrent(P_Hl, P_Hh, P_Z, P_A, 3831, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_HMinus, 3071, check)
      call createCurrent(P_t, P_tAnti, P_A, 824, check)
      call createCurrent(P_HMinus, P_HPlus, P_WPlus, P_WMinus, 764, check)
      call createCurrent(P_GPlus, P_A, P_Hl, P_WMinus, 2297, check)
      call createCurrent(P_G0, P_G0, P_G0, P_Ha, 335, check)
      call createCurrent(P_G0, P_Hh, P_Hh, P_G0, 1749, check)
      call createCurrent(P_WPlus, P_Hl, P_A, P_HMinus, 1741, check)
      call createCurrent(P_A, P_Ha, P_GMinus, P_WPlus, 3144, check)
      call createCurrent(P_Z, P_WMinus, P_WPlus, P_A, 46, check)
      call createCurrent(P_Hh, P_WMinus, P_A, P_GPlus, 1112, check)
      call createCurrent(P_A, P_nu_mu, P_nu_muAnti, 2930, check)
      call createCurrent(P_Ha, P_A, P_G0, P_Z, 3795, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, P_Hl, 998, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, P_Hh, 1211, check)
      call createCurrent(P_GPlus, P_A, P_GMinus, P_A, 965, check)
      call createCurrent(P_Z, P_G0, P_G0, P_A, 3517, check)
      call createCurrent(P_Hh, P_Z, P_HPlus, P_WMinus, 79, check)
      call createCurrent(P_G0, P_Ha, P_GPlus, P_GMinus, 150, check)
      call createCurrent(P_Hl, P_HPlus, P_G0, P_GMinus, 2468, check)
      call createCurrent(P_Ha, P_Z, P_HPlus, P_WMinus, 991, check)
      call createCurrent(P_Ha, P_HMinus, P_Ha, P_HPlus, 2592, check)
      call createCurrent(P_sAnti, P_s, P_Hh, 2431, check)
      call createCurrent(P_g, P_HMinus, P_g, P_HPlus, 3843, check)
      call createCurrent(P_Z, P_A, P_Hl, P_Hl, 3196, check)
      call createCurrent(P_Hh, P_HPlus, P_HMinus, P_Hh, 297, check)
      call createCurrent(P_g, P_Z, P_g, P_Z, 3603, check)
      call createCurrent(P_GPlus, P_Z, P_Z, P_GMinus, 215, check)
      call createCurrent(P_HPlus, P_GMinus, P_g, P_g, 3626, check)
      call createCurrent(P_Ha, P_Ha, P_GMinus, P_GPlus, 648, check)
      call createCurrent(P_t, P_tAnti, P_G0, 2275, check)
      call createCurrent(P_Hl, P_Hl, P_Z, P_Z, 1144, check)
      call createCurrent(P_WMinus, P_WPlus, P_Z, 1769, check)
      call createCurrent(P_d, P_WPlus, P_uAnti, 545, check)
      call createCurrent(P_G0, P_G0, P_Ha, P_Hh, 3827, check)
      call createCurrent(P_Hl, P_GPlus, P_HMinus, P_Hl, 2279, check)
      call createCurrent(P_dAnti, P_u, P_GMinus, 706, check)
      call createCurrent(P_GPlus, P_HMinus, P_Ha, P_G0, 1045, check)
      call createCurrent(P_Z, P_GPlus, P_Ha, P_WMinus, 3198, check)
      call createCurrent(P_GMinus, P_Ha, P_G0, P_HPlus, 425, check)
      call createCurrent(P_A, P_Hh, P_Z, 2849, check)
      call createCurrent(P_Hl, P_A, P_WMinus, P_GPlus, 2701, check)
      call createCurrent(P_Hh, P_Hh, P_Ha, P_Ha, 702, check)
      call createCurrent(P_Hh, P_WPlus, P_Z, P_GMinus, 242, check)
      call createCurrent(P_GPlus, P_A, P_HMinus, 3570, check)
      call createCurrent(P_Hl, P_cAnti, P_c, 223, check)
      call createCurrent(P_HMinus, P_GPlus, P_Z, P_A, 2830, check)
      call createCurrent(P_HPlus, P_HMinus, P_Z, P_A, 1347, check)
      call createCurrent(P_muMinus, P_Hh, P_muPlus, 743, check)
      call createCurrent(P_Hl, P_A, P_HMinus, P_WPlus, 68, check)
      call createCurrent(P_GPlus, P_Hl, P_G0, P_GMinus, 3214, check)
      call createCurrent(P_Z, P_Ha, P_G0, P_A, 3661, check)
      call createCurrent(P_Ha, P_GPlus, P_HMinus, P_Hh, 1426, check)
      call createCurrent(P_HMinus, P_Z, P_GPlus, P_Z, 3460, check)
      call createCurrent(P_Z, P_Hl, P_WMinus, P_GPlus, 563, check)
      call createCurrent(P_GMinus, P_dAnti, P_u, 1076, check)
      call createCurrent(P_tauMinus, P_HPlus, P_nu_tauAnti, 1695, check)
      call createCurrent(P_Z, P_HPlus, P_Hl, P_WMinus, 788, check)
      call createCurrent(P_GPlus, P_G0, P_A, P_WMinus, 731, check)
      call createCurrent(P_G0, P_WMinus, P_G0, P_WPlus, 820, check)
      call createCurrent(P_A, P_HMinus, P_WPlus, 655, check)
      call createCurrent(P_Hh, P_ghWpAnti, P_ghWp, 2641, check)
      call createCurrent(P_HPlus, P_G0, P_HMinus, P_Hh, 2972, check)
      call createCurrent(P_Hl, P_WMinus, P_WPlus, 1870, check)
      call createCurrent(P_WMinus, P_nu_mu, P_muPlus, 1089, check)
      call createCurrent(P_WMinus, P_Z, P_HPlus, P_Hh, 944, check)
      call createCurrent(P_WPlus, P_Z, P_G0, P_GMinus, 1662, check)
      call createCurrent(P_WMinus, P_G0, P_GPlus, 963, check)
      call createCurrent(P_G0, P_eMinus, P_ePlus, 1858, check)
      call createCurrent(P_Hl, P_A, P_Z, P_Hh, 3791, check)
      call createCurrent(P_Z, P_GMinus, P_Z, P_HPlus, 3439, check)
      call createCurrent(P_Ha, P_Hl, P_GPlus, P_HMinus, 641, check)
      call createCurrent(P_HMinus, P_t, P_bAnti, 677, check)
      call createCurrent(P_u, P_dAnti, P_HMinus, 2700, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, P_Hh, 466, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, 699, check)
      call createCurrent(P_G0, P_GMinus, P_GPlus, P_Ha, 314, check)
      call createCurrent(P_G0, P_WMinus, P_A, P_GPlus, 2368, check)
      call createCurrent(P_WPlus, P_HMinus, P_Hl, P_A, 1054, check)
      call createCurrent(P_HPlus, P_muMinus, P_nu_muAnti, 249, check)
      call createCurrent(P_Ha, P_Ha, P_Ha, P_Ha, 2562, check)
      call createCurrent(P_Ha, P_GPlus, P_GMinus, P_Hl, 2819, check)
      call createCurrent(P_A, P_A, P_Hl, 3732, check)
      call createCurrent(P_GPlus, P_Hh, P_GMinus, P_G0, 3022, check)
      call createCurrent(P_u, P_dAnti, P_WMinus, 1062, check)
      call createCurrent(P_tAnti, P_GPlus, P_b, 2033, check)
      call createCurrent(P_HMinus, P_WPlus, P_A, P_Hh, 2299, check)
      call createCurrent(P_A, P_HMinus, P_WPlus, P_G0, 2979, check)
      call createCurrent(P_WMinus, P_Hl, P_Hh, P_WPlus, 3185, check)
      call createCurrent(P_HMinus, P_HPlus, P_Hh, P_Hl, 1296, check)
      call createCurrent(P_G0, P_Hl, P_G0, 1058, check)
      call createCurrent(P_Z, P_A, P_GMinus, P_HPlus, 3582, check)
      call createCurrent(P_HMinus, P_GPlus, P_WPlus, P_WMinus, 3370, check)
      call createCurrent(P_Hl, P_s, P_sAnti, 2683, check)
      call createCurrent(P_G0, P_HPlus, P_WMinus, 3215, check)
      call createCurrent(P_g, P_g, P_G0, P_Ha, 3823, check)
      call createCurrent(P_Hh, P_u, P_uAnti, 1734, check)
      call createCurrent(P_Z, P_Z, P_g, P_g, 3775, check)
      call createCurrent(P_s, P_A, P_sAnti, 2659, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, P_Hl, 658, check)
      call createCurrent(P_GMinus, P_G0, P_HPlus, P_G0, 989, check)
      call createCurrent(P_Z, P_A, P_A, P_A, 3826, check)
      call createCurrent(P_HMinus, P_GPlus, P_Hh, P_Hl, 349, check)
      call createCurrent(P_GPlus, P_HMinus, P_Hl, P_Hl, 1303, check)
      call createCurrent(P_G0, P_WMinus, P_Z, P_GPlus, 444, check)
      call createCurrent(P_Hl, P_A, P_Z, 3043, check)
      call createCurrent(P_muPlus, P_muMinus, P_G0, 1809, check)
      call createCurrent(P_GMinus, P_Hh, P_G0, P_GPlus, 3342, check)
      call createCurrent(P_Z, P_Z, P_Ha, P_G0, 2743, check)
      call createCurrent(P_HPlus, P_Hl, P_HMinus, P_Ha, 3443, check)
      call createCurrent(P_HMinus, P_Hh, P_HPlus, 1013, check)
      call createCurrent(P_GPlus, P_HMinus, P_G0, P_Ha, 909, check)
      call createCurrent(P_WMinus, P_G0, P_HPlus, P_A, 3225, check)
      call createCurrent(P_A, P_Hh, P_Hl, P_A, 3879, check)
      call createCurrent(P_G0, P_A, P_WPlus, P_HMinus, 2757, check)
      call createCurrent(P_HMinus, P_WPlus, P_G0, 3136, check)
      call createCurrent(P_Hh, P_HMinus, P_Ha, P_GPlus, 1559, check)
      call createCurrent(P_sAnti, P_c, P_HMinus, 1421, check)
      call createCurrent(P_GMinus, P_HPlus, P_g, P_g, 3658, check)
      call createCurrent(P_GMinus, P_GPlus, P_GPlus, P_HMinus, 728, check)
      call createCurrent(P_WMinus, P_GMinus, P_GPlus, P_WPlus, 1625, check)
      call createCurrent(P_WPlus, P_d, P_uAnti, 308, check)
      call createCurrent(P_Hl, P_HPlus, P_HMinus, P_Hl, 603, check)
      call createCurrent(P_Z, P_A, P_G0, P_G0, 3434, check)
      call createCurrent(P_GMinus, P_bAnti, P_t, 917, check)
      call createCurrent(P_WMinus, P_GPlus, P_Ha, P_A, 3150, check)
      call createCurrent(P_Ha, P_GMinus, P_Ha, P_HPlus, 2180, check)
      call createCurrent(P_tauPlus, P_Hl, P_tauMinus, 1814, check)
      call createCurrent(P_Hh, P_GPlus, P_WMinus, P_Z, 1023, check)
      call createCurrent(P_Ha, P_Hh, P_G0, P_G0, 3593, check)
      call createCurrent(P_HMinus, P_Hh, P_GPlus, P_Hl, 6, check)
      call createCurrent(P_Hh, P_Hl, P_G0, P_Ha, 1573, check)
      call createCurrent(P_ghWm, P_Ha, P_ghWmAnti, 2824, check)
      call createCurrent(P_GPlus, P_WMinus, P_Hh, P_A, 1466, check)
      call createCurrent(P_HPlus, P_Z, P_GMinus, P_A, 3335, check)
      call createCurrent(P_WMinus, P_WPlus, P_GPlus, P_HMinus, 2867, check)
      call createCurrent(P_Ha, P_GPlus, P_GMinus, P_Hh, 2768, check)
      call createCurrent(P_cAnti, P_A, P_c, 794, check)
      call createCurrent(P_WPlus, P_Ha, P_A, P_HMinus, 579, check)
      call createCurrent(P_Hl, P_Ha, P_G0, 826, check)
      call createCurrent(P_WPlus, P_G0, P_GMinus, P_Z, 1833, check)
      call createCurrent(P_tauPlus, P_G0, P_tauMinus, 821, check)
      call createCurrent(P_Hl, P_A, P_A, P_Hl, 3801, check)
      call createCurrent(P_tauMinus, P_WPlus, P_nu_tauAnti, 1159, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, P_Hl, 779, check)
      call createCurrent(P_Z, P_HMinus, P_WPlus, 1830, check)
      call createCurrent(P_HMinus, P_Ha, P_HPlus, P_G0, 1445, check)
      call createCurrent(P_Hh, P_Ha, P_HPlus, P_HMinus, 2914, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, P_G0, 932, check)
      call createCurrent(P_WMinus, P_ghZAnti, P_ghWp, 2000, check)
      call createCurrent(P_nu_e, P_nu_eAnti, P_Z, 2343, check)
      call createCurrent(P_G0, P_WMinus, P_GPlus, P_Z, 393, check)
      call createCurrent(P_Hh, P_Hh, P_A, P_A, 3802, check)
      call createCurrent(P_eMinus, P_ePlus, P_Hl, 904, check)
      call createCurrent(P_muMinus, P_muPlus, 3140, check)
      call createCurrent(P_Hh, P_HPlus, P_WMinus, P_A, 2600, check)
      call createCurrent(P_HMinus, P_ghWmAnti, P_ghA, 3249, check)
      call createCurrent(P_Hl, P_Hl, P_Hh, 1475, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, P_Hh, 1344, check)
      call createCurrent(P_HPlus, P_s, P_cAnti, 370, check)
      call createCurrent(P_WPlus, P_WMinus, P_A, P_A, 309, check)
      call createCurrent(P_Ha, P_HPlus, P_Hl, P_HMinus, 3426, check)
      call createCurrent(P_HMinus, P_HPlus, P_G0, P_G0, 432, check)
      call createCurrent(P_bAnti, P_b, P_G0, 539, check)
      call createCurrent(P_nu_eAnti, P_nu_e, 3188, check)
      call createCurrent(P_HMinus, P_G0, P_HPlus, P_Hl, 3195, check)
      call createCurrent(P_A, P_HPlus, P_G0, P_WMinus, 2851, check)
      call createCurrent(P_G0, P_Hl, P_G0, P_Ha, 3602, check)
      call createCurrent(P_Hl, P_Ha, P_G0, P_G0, 3796, check)
      call createCurrent(P_Ha, P_muPlus, P_muMinus, 1503, check)
      call createCurrent(P_g, P_GMinus, P_GPlus, P_g, 3656, check)
      call createCurrent(P_GMinus, P_GPlus, P_GMinus, P_HPlus, 1143, check)
      call createCurrent(P_Z, P_nu_tau, P_nu_tauAnti, 630, check)
      call createCurrent(P_WPlus, P_GMinus, P_WMinus, P_HPlus, 3430, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghZ, 2036, check)
      call createCurrent(P_GPlus, P_GMinus, P_Hh, P_Hl, 36, check)
      call createCurrent(P_WPlus, P_nu_muAnti, P_muMinus, 1993, check)
      call createCurrent(P_muMinus, P_muPlus, P_A, 1596, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, P_G0, 2048, check)
      call createCurrent(P_dAnti, P_d, P_Z, 1495, check)
      call createCurrent(P_G0, P_Hh, P_Ha, P_Hh, 1873, check)
      call createCurrent(P_Z, P_WMinus, P_Hl, P_GPlus, 2218, check)
      call createCurrent(P_Ha, P_ghWm, P_ghWmAnti, 2775, check)
      call createCurrent(P_G0, P_Hh, P_Hl, P_G0, 1842, check)
      call createCurrent(P_Hh, P_A, P_HPlus, P_WMinus, 301, check)
      call createCurrent(P_sAnti, P_s, P_Ha, 879, check)
      call createCurrent(P_WMinus, P_c, P_sAnti, 1529, check)
      call createCurrent(P_WMinus, P_WPlus, P_Hl, P_Hh, 3014, check)
      call createCurrent(P_GMinus, P_Hl, P_A, P_WPlus, 2315, check)
      call createCurrent(P_Ha, P_GPlus, P_WMinus, P_A, 2939, check)
      call createCurrent(P_A, P_Z, 2844, check)
      call createCurrent(P_ghWmAnti, P_HMinus, P_ghA, 3441, check)
      call createCurrent(P_WPlus, P_A, P_HMinus, P_G0, 3358, check)
      call createCurrent(P_Hl, P_G0, P_Hl, P_Ha, 74, check)
      call createCurrent(P_GMinus, P_GPlus, P_HPlus, P_GMinus, 2591, check)
      call createCurrent(P_A, P_Ha, P_Ha, P_Z, 2797, check)
      call createCurrent(P_Hl, P_WPlus, P_Hl, P_WMinus, 857, check)
      call createCurrent(P_Hh, P_GMinus, P_HPlus, P_Hh, 1464, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, P_G0, 1848, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_Hl, 1364, check)
      call createCurrent(P_G0, P_A, P_WMinus, P_GPlus, 2189, check)
      call createCurrent(P_b, P_bAnti, P_G0, 1452, check)
      call createCurrent(P_Z, P_WPlus, P_HMinus, P_Hl, 1317, check)
      call createCurrent(P_HPlus, P_Hh, P_GMinus, 1465, check)
      call createCurrent(P_A, P_WPlus, P_WMinus, 328, check)
      call createCurrent(P_GPlus, P_Hh, P_Hh, P_GMinus, 193, check)
      call createCurrent(P_HPlus, P_Z, P_Hl, P_WMinus, 1386, check)
      call createCurrent(P_WMinus, P_G0, P_HPlus, P_Z, 3328, check)
      call createCurrent(P_Ha, P_Hh, P_Ha, 292, check)
      call createCurrent(P_G0, P_HMinus, P_HPlus, P_Ha, 1678, check)
      call createCurrent(P_tauPlus, P_A, P_tauMinus, 2146, check)
      call createCurrent(P_Z, P_Z, P_GPlus, P_GMinus, 2, check)
      call createCurrent(P_WMinus, P_Hl, P_Z, P_GPlus, 2081, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_WPlus, 1481, check)
      call createCurrent(P_HMinus, P_Z, P_HPlus, 1246, check)
      call createCurrent(P_GMinus, P_Z, P_GPlus, P_A, 2611, check)
      call createCurrent(P_Ha, P_Hh, P_A, 2921, check)
      call createCurrent(P_bAnti, P_WMinus, P_t, 536, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, 1624, check)
      call createCurrent(P_Hh, P_GMinus, P_A, P_WPlus, 1153, check)
      call createCurrent(P_HMinus, P_GMinus, P_HPlus, P_HPlus, 331, check)
      call createCurrent(P_GMinus, P_GPlus, P_Ha, P_Ha, 1340, check)
      call createCurrent(P_Ha, P_Hl, P_GPlus, P_GMinus, 3362, check)
      call createCurrent(P_HMinus, P_WPlus, P_Hl, P_A, 490, check)
      call createCurrent(P_HMinus, P_HPlus, P_Hl, P_Hh, 523, check)
      call createCurrent(P_WPlus, P_A, P_WMinus, P_A, 1469, check)
      call createCurrent(P_HMinus, P_Hl, P_GPlus, P_G0, 346, check)
      call createCurrent(P_GPlus, P_HMinus, P_Hh, P_Hl, 688, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, 1389, check)
      call createCurrent(P_GMinus, P_A, P_Ha, P_WPlus, 3445, check)
      call createCurrent(P_Z, P_Hl, P_HMinus, P_WPlus, 810, check)
      call createCurrent(P_Z, P_HMinus, P_G0, P_WPlus, 3543, check)
      call createCurrent(P_HPlus, P_A, P_GMinus, 3567, check)
      call createCurrent(P_A, P_G0, P_WMinus, P_HPlus, 3333, check)
      call createCurrent(P_Hh, P_HPlus, P_HMinus, P_G0, 3369, check)
      call createCurrent(P_ghGAnti, P_g, P_ghG, 2269, check)
      call createCurrent(P_Hh, P_Ha, P_Ha, P_Hh, 156, check)
      call createCurrent(P_Z, P_Ha, P_WMinus, P_HPlus, 2224, check)
      call createCurrent(P_s, P_cAnti, P_WPlus, 145, check)
      call createCurrent(P_Hl, P_WPlus, P_Z, P_GMinus, 2166, check)
      call createCurrent(P_WMinus, P_Hh, P_HPlus, P_Z, 1161, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, P_G0, 2125, check)
      call createCurrent(P_Z, P_WPlus, P_Hh, P_HMinus, 1532, check)
      call createCurrent(P_G0, P_GMinus, P_Ha, P_HPlus, 1831, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, 192, check)
      call createCurrent(P_HPlus, P_HMinus, P_Hl, P_Hh, 897, check)
      call createCurrent(P_A, P_WMinus, P_WPlus, 1544, check)
      call createCurrent(P_G0, P_HPlus, P_Hh, P_GMinus, 61, check)
      call createCurrent(P_HMinus, P_Ha, P_G0, P_GPlus, 546, check)
      call createCurrent(P_GPlus, P_G0, P_GMinus, P_Hh, 3182, check)
      call createCurrent(P_Hl, P_WMinus, P_HPlus, P_A, 837, check)
      call createCurrent(P_WMinus, P_Hl, P_WPlus, 388, check)
      call createCurrent(P_Ha, P_Hh, P_Hh, P_G0, 1133, check)
      call createCurrent(P_Hh, P_G0, P_G0, P_Hl, 1095, check)
      call createCurrent(P_Z, P_A, P_Ha, P_Ha, 3376, check)
      call createCurrent(P_Ha, P_HPlus, P_GMinus, P_Hl, 45, check)
      call createCurrent(P_Hl, P_Z, P_WMinus, P_GPlus, 1146, check)
      call createCurrent(P_Hh, P_G0, P_Ha, P_G0, 3753, check)
      call createCurrent(P_WPlus, P_b, P_tAnti, 1755, check)
      call createCurrent(P_A, P_GMinus, P_GPlus, P_A, 1896, check)
      call createCurrent(P_Hl, P_bAnti, P_b, 1200, check)
      call createCurrent(P_ghA, P_GPlus, P_ghWpAnti, 412, check)
      call createCurrent(P_Hh, P_Z, P_Hh, P_Z, 1066, check)
      call createCurrent(P_Hl, P_HMinus, P_Hl, P_HPlus, 455, check)
      call createCurrent(P_A, P_Hh, P_HMinus, P_WPlus, 2215, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghZAnti, 1370, check)
      call createCurrent(P_A, P_WPlus, P_G0, P_HMinus, 3408, check)
      call createCurrent(P_Hh, P_G0, P_GPlus, P_HMinus, 2614, check)
      call createCurrent(P_Z, P_A, P_G0, P_Ha, 3881, check)
      call createCurrent(P_HPlus, P_Hh, P_HMinus, P_Hh, 874, check)
      call createCurrent(P_GPlus, P_Ha, P_GMinus, P_Ha, 2089, check)
      call createCurrent(P_Z, P_WMinus, P_HPlus, 369, check)
      call createCurrent(P_HPlus, P_Z, P_A, P_HMinus, 2012, check)
      call createCurrent(P_GMinus, P_WMinus, P_HPlus, P_WPlus, 2832, check)
      call createCurrent(P_nu_muAnti, P_A, P_nu_mu, 3530, check)
      call createCurrent(P_Ha, P_Z, P_HMinus, P_WPlus, 1354, check)
      call createCurrent(P_ghZAnti, P_HMinus, P_ghWp, 3037, check)
      call createCurrent(P_WMinus, P_WPlus, P_G0, P_Ha, 2765, check)
      call createCurrent(P_ghWp, P_Ha, P_ghWpAnti, 2710, check)
      call createCurrent(P_HMinus, P_G0, P_WPlus, P_A, 3069, check)
      call createCurrent(P_WMinus, P_Z, P_A, P_WPlus, 2627, check)
      call createCurrent(P_GPlus, P_Hl, P_Ha, P_HMinus, 1792, check)
      call createCurrent(P_Hh, P_Hl, P_g, P_g, 3810, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghZ, 1554, check)
      call createCurrent(P_G0, P_Ha, P_G0, P_Hh, 3854, check)
      call createCurrent(P_GPlus, P_WMinus, P_Hl, 2440, check)
      call createCurrent(P_HPlus, P_WMinus, P_HMinus, P_WPlus, 450, check)
      call createCurrent(P_Hl, P_GPlus, P_GMinus, 2504, check)
      call createCurrent(P_Hl, P_WMinus, P_GPlus, P_Z, 891, check)
      call createCurrent(P_GPlus, P_HMinus, P_G0, P_Hh, 1321, check)
      call createCurrent(P_GMinus, P_Z, P_Hl, P_WPlus, 2268, check)
      call createCurrent(P_Hh, P_G0, P_G0, P_Ha, 3592, check)
      call createCurrent(P_g, P_GPlus, P_g, P_HMinus, 3819, check)
      call createCurrent(P_nu_mu, P_A, P_nu_muAnti, 3351, check)
      call createCurrent(P_A, P_WPlus, P_WMinus, P_A, 2162, check)
      call createCurrent(P_HMinus, P_GPlus, P_Hl, P_Hl, 1576, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, P_G0, 181, check)
      call createCurrent(P_Ha, P_A, P_GMinus, P_WPlus, 3393, check)
      call createCurrent(P_HMinus, P_GPlus, P_HMinus, P_GPlus, 977, check)
      call createCurrent(P_GPlus, P_HMinus, P_Hh, 2519, check)
      call createCurrent(P_HMinus, P_WPlus, P_Z, P_Hh, 651, check)
      call createCurrent(P_HMinus, P_WPlus, P_Hh, P_A, 1135, check)
      call createCurrent(P_Hl, P_WPlus, P_HMinus, 1250, check)
      call createCurrent(P_GPlus, P_WMinus, P_WPlus, P_GMinus, 2187, check)
      call createCurrent(P_GMinus, P_ghA, P_ghWmAnti, 2677, check)
      call createCurrent(P_G0, P_bAnti, P_b, 1071, check)
      call createCurrent(P_Z, P_Z, P_HMinus, P_GPlus, 3235, check)
      call createCurrent(P_Z, P_Z, P_Hl, P_Hl, 2201, check)
      call createCurrent(P_HPlus, P_GMinus, P_A, 2970, check)
      call createCurrent(P_GMinus, P_WPlus, P_Hl, P_A, 325, check)
      call createCurrent(P_Z, P_WPlus, P_WMinus, P_A, 1899, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, P_Hl, 2684, check)
      call createCurrent(P_G0, P_Ha, P_WPlus, P_WMinus, 3174, check)
      call createCurrent(P_HMinus, P_A, P_WPlus, P_Hh, 2439, check)
      call createCurrent(P_Ha, P_GMinus, P_HPlus, P_G0, 806, check)
      call createCurrent(P_Hl, P_GMinus, P_WPlus, 668, check)
      call createCurrent(P_Ha, P_G0, P_Hl, P_Hl, 2100, check)
      call createCurrent(P_GMinus, P_HMinus, P_HPlus, P_GPlus, 2004, check)
      call createCurrent(P_Ha, P_WMinus, P_G0, P_WPlus, 3110, check)
      call createCurrent(P_GPlus, P_Hl, P_Hh, P_HMinus, 352, check)
      call createCurrent(P_WPlus, P_HMinus, P_Z, P_Hl, 2254, check)
      call createCurrent(P_nu_muAnti, P_HPlus, P_muMinus, 1011, check)
      call createCurrent(P_GMinus, P_tauPlus, P_nu_tau, 1056, check)
      call createCurrent(P_A, P_GPlus, P_Hl, P_WMinus, 137, check)
      call createCurrent(P_WPlus, P_WMinus, P_A, P_Z, 1561, check)
      call createCurrent(P_Hl, P_Hl, P_Z, P_A, 3153, check)
      call createCurrent(P_muPlus, P_Ha, P_muMinus, 1145, check)
      call createCurrent(P_WMinus, P_HPlus, P_Z, P_G0, 2997, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, P_Hh, 2605, check)
      call createCurrent(P_HMinus, P_GPlus, P_Z, 2890, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, P_G0, 107, check)
      call createCurrent(P_WPlus, P_GMinus, P_HPlus, P_WMinus, 2990, check)
      call createCurrent(P_A, P_Ha, P_A, P_G0, 3846, check)
      call createCurrent(P_HMinus, P_nu_mu, P_muPlus, 177, check)
      call createCurrent(P_A, P_GMinus, P_G0, P_WPlus, 1168, check)
      call createCurrent(P_b, P_tAnti, P_HPlus, 385, check)
      call createCurrent(P_A, P_WPlus, P_Hh, P_HMinus, 267, check)
      call createCurrent(P_G0, P_GMinus, P_Hh, P_HPlus, 488, check)
      call createCurrent(P_c, P_sAnti, P_HMinus, 2643, check)
      call createCurrent(P_Z, P_Hl, P_G0, 727, check)
      call createCurrent(P_Ha, P_GPlus, P_HMinus, P_Ha, 983, check)
      call createCurrent(P_Hl, P_G0, P_Ha, P_Hl, 2087, check)
      call createCurrent(P_WMinus, P_A, P_A, P_WPlus, 2471, check)
      call createCurrent(P_WPlus, P_WMinus, P_Z, P_A, 1286, check)
      call createCurrent(P_G0, P_Hl, P_G0, P_Hh, 2137, check)
      call createCurrent(P_A, P_G0, P_Z, P_G0, 3563, check)
      call createCurrent(P_G0, P_GMinus, P_G0, P_HPlus, 680, check)
      call createCurrent(P_WPlus, P_GMinus, P_Hh, 1801, check)
      call createCurrent(P_WPlus, P_tAnti, P_b, 1320, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, P_Hl, 2362, check)
      call createCurrent(P_nu_tauAnti, P_nu_tau, 2840, check)
      call createCurrent(P_GPlus, P_G0, P_Hl, P_HMinus, 553, check)
      call createCurrent(P_GMinus, P_Hl, P_HPlus, P_Hl, 1530, check)
      call createCurrent(P_Z, P_G0, P_WMinus, P_HPlus, 3476, check)
      call createCurrent(P_Hh, P_Z, P_G0, 871, check)
      call createCurrent(P_nu_eAnti, P_WPlus, P_eMinus, 1383, check)
      call createCurrent(P_WPlus, P_G0, P_HMinus, P_Z, 3245, check)
      call createCurrent(P_GMinus, P_G0, P_Ha, P_GPlus, 592, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, P_Hl, 1225, check)
      call createCurrent(P_Z, P_Hl, P_HPlus, P_WMinus, 862, check)
      call createCurrent(P_GPlus, P_HMinus, P_WPlus, P_WMinus, 2884, check)
      call createCurrent(P_dAnti, P_u, P_HMinus, 2478, check)
      call createCurrent(P_Z, P_WMinus, P_Z, P_WPlus, 233, check)
      call createCurrent(P_g, P_G0, P_G0, P_g, 3604, check)
      call createCurrent(P_tauPlus, P_tauMinus, 2823, check)
      call createCurrent(P_HMinus, P_G0, P_A, P_WPlus, 3238, check)
      call createCurrent(P_Hh, P_Hh, P_HMinus, P_GPlus, 1807, check)
      call createCurrent(P_GPlus, P_G0, P_HMinus, P_Hl, 508, check)
      call createCurrent(P_G0, P_HPlus, P_HMinus, P_G0, 274, check)
      call createCurrent(P_WPlus, P_WMinus, P_Hl, P_Hl, 771, check)
      call createCurrent(P_WPlus, P_WMinus, P_Hl, 2336, check)
      call createCurrent(P_nu_mu, P_nu_muAnti, P_A, 2945, check)
      call createCurrent(P_G0, P_HMinus, P_HPlus, P_Hl, 2856, check)
      call createCurrent(P_nu_tauAnti, P_nu_tau, P_Z, 2194, check)
      call createCurrent(P_GMinus, P_Z, P_HPlus, P_Z, 3379, check)
      call createCurrent(P_WPlus, P_GPlus, P_WMinus, P_HMinus, 3179, check)
      call createCurrent(P_tAnti, P_t, 3525, check)
      call createCurrent(P_g, P_Hh, P_g, 3625, check)
      call createCurrent(P_WPlus, P_HMinus, P_A, P_Hl, 449, check)
      call createCurrent(P_Ha, P_WPlus, P_G0, P_WMinus, 2728, check)
      call createCurrent(P_Hl, P_Z, P_Hh, P_Z, 3142, check)
      call createCurrent(P_HPlus, P_A, P_Hl, P_WMinus, 57, check)
      call createCurrent(P_Z, P_HMinus, P_GPlus, P_A, 2767, check)
      call createCurrent(P_HMinus, P_WMinus, P_HPlus, P_WPlus, 594, check)
      call createCurrent(P_GMinus, P_G0, P_WPlus, P_A, 2396, check)
      call createCurrent(P_Ha, P_GMinus, P_Hl, P_HPlus, 873, check)
      call createCurrent(P_Hh, P_WMinus, P_WPlus, P_Hh, 1016, check)
      call createCurrent(P_Z, P_WPlus, P_WMinus, 1195, check)
      call createCurrent(P_WPlus, P_Hl, P_Z, P_HMinus, 453, check)
      call createCurrent(P_GMinus, P_Z, P_HPlus, P_A, 3487, check)
      call createCurrent(P_g, P_Ha, P_G0, P_g, 3691, check)
      call createCurrent(P_Hh, P_A, P_Z, 2885, check)
      call createCurrent(P_Ha, P_ghWmAnti, P_ghWm, 2936, check)
      call createCurrent(P_G0, P_HPlus, P_Hl, P_GMinus, 1009, check)
      call createCurrent(P_GMinus, P_Hh, P_HPlus, P_G0, 2324, check)
      call createCurrent(P_Ha, P_A, P_Hh, 3222, check)
      call createCurrent(P_HMinus, P_Ha, P_Hh, P_HPlus, 3491, check)
      call createCurrent(P_GMinus, P_Ha, P_HPlus, 180, check)
      call createCurrent(P_WPlus, P_uAnti, P_d, 676, check)
      call createCurrent(P_WMinus, P_GPlus, P_Hh, P_Z, 206, check)
      call createCurrent(P_Z, P_HMinus, P_WPlus, P_Ha, 1371, check)
      call createCurrent(P_G0, P_Z, P_Hh, 155, check)
      call createCurrent(P_WPlus, P_Z, P_HMinus, P_Hl, 2632, check)
      call createCurrent(P_GPlus, P_GMinus, P_Z, P_Z, 1980, check)
      call createCurrent(P_Ha, P_Z, P_WMinus, P_GPlus, 2926, check)
      call createCurrent(P_Hl, P_Z, P_Hh, P_A, 3614, check)
      call createCurrent(P_Z, P_g, P_g, P_A, 3677, check)
      call createCurrent(P_Hh, P_GPlus, P_HMinus, P_Hh, 456, check)
      call createCurrent(P_Hl, P_HMinus, P_Ha, P_GPlus, 1514, check)
      call createCurrent(P_Hh, P_WPlus, P_GMinus, P_A, 1781, check)
      call createCurrent(P_A, P_Hh, P_Z, P_Hh, 3367, check)
      call createCurrent(P_G0, P_HMinus, P_G0, P_GPlus, 2156, check)
      call createCurrent(P_Hl, P_G0, P_Ha, P_G0, 3747, check)
      call createCurrent(P_G0, P_HMinus, P_A, P_WPlus, 3421, check)
      call createCurrent(P_uAnti, P_A, P_u, 841, check)
      call createCurrent(P_Ha, P_u, P_uAnti, 443, check)
      call createCurrent(P_WMinus, P_Ha, P_GPlus, P_A, 2729, check)
      call createCurrent(P_uAnti, P_WPlus, P_d, 2455, check)
      call createCurrent(P_Z, P_A, P_GMinus, P_GPlus, 160, check)
      call createCurrent(P_HMinus, P_G0, P_Hh, P_HPlus, 3161, check)
      call createCurrent(P_WPlus, P_Ha, P_HMinus, P_A, 1293, check)
      call createCurrent(P_WPlus, P_Hl, P_Z, P_GMinus, 478, check)
      call createCurrent(P_ghZAnti, P_HPlus, P_ghWm, 3143, check)
      call createCurrent(P_Z, P_GPlus, P_HMinus, P_A, 2919, check)
      call createCurrent(P_WPlus, P_A, P_Z, P_WMinus, 2485, check)
      call createCurrent(P_Ha, P_Z, P_Hl, 1790, check)
      call createCurrent(P_Hh, P_WPlus, P_Hl, P_WMinus, 3471, check)
      call createCurrent(P_Ha, P_G0, P_Hh, P_G0, 3701, check)
      call createCurrent(P_G0, P_GPlus, P_GMinus, P_Hh, 3536, check)
      call createCurrent(P_tauPlus, P_GMinus, P_nu_tau, 1541, check)
      call createCurrent(P_GMinus, P_A, P_HPlus, P_Z, 2834, check)
      call createCurrent(P_ghZAnti, P_Hl, P_ghZ, 733, check)
      call createCurrent(P_Hl, P_GMinus, P_Ha, P_HPlus, 1905, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Ha, 3521, check)
      call createCurrent(P_Hl, P_A, P_Ha, 3098, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, P_Hh, 1322, check)
      call createCurrent(P_sAnti, P_c, P_GMinus, 2510, check)
      call createCurrent(P_WPlus, P_Ha, P_Ha, P_WMinus, 1497, check)
      call createCurrent(P_A, P_GMinus, P_GPlus, P_Z, 645, check)
      call createCurrent(P_HPlus, P_WMinus, P_Z, P_Hl, 1924, check)
      call createCurrent(P_WMinus, P_t, P_bAnti, 182, check)
      call createCurrent(P_ghWp, P_HMinus, P_ghZAnti, 3579, check)
      call createCurrent(P_GMinus, P_GPlus, P_HMinus, P_GPlus, 1162, check)
      call createCurrent(P_HMinus, P_c, P_sAnti, 1212, check)
      call createCurrent(P_Ha, P_HMinus, P_GPlus, P_Ha, 502, check)
      call createCurrent(P_A, P_nu_eAnti, P_nu_e, 3079, check)
      call createCurrent(P_c, P_cAnti, P_Hl, 2050, check)
      call createCurrent(P_Hh, P_G0, P_GMinus, P_GPlus, 3246, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, P_Ha, 2836, check)
      call createCurrent(P_HPlus, P_Z, P_WMinus, P_Ha, 1557, check)
      call createCurrent(P_G0, P_Hl, P_Hl, P_G0, 285, check)
      call createCurrent(P_WMinus, P_Z, P_HPlus, P_G0, 2897, check)
      call createCurrent(P_WPlus, P_Hh, P_GMinus, P_Z, 1468, check)
      call createCurrent(P_Z, P_Hl, P_Ha, 347, check)
      call createCurrent(P_GMinus, P_Hh, P_HPlus, P_Hl, 2661, check)
      call createCurrent(P_nu_e, P_nu_eAnti, 2730, check)
      call createCurrent(P_Hl, P_Z, P_Ha, 128, check)
      call createCurrent(P_Ha, P_GMinus, P_GPlus, P_Ha, 2240, check)
      call createCurrent(P_HPlus, P_GMinus, P_HMinus, P_HPlus, 725, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Z, 984, check)
      call createCurrent(P_nu_eAnti, P_Z, P_nu_e, 755, check)
      call createCurrent(P_GPlus, P_Z, P_Z, P_HMinus, 3483, check)
      call createCurrent(P_HPlus, P_eMinus, P_nu_eAnti, 1660, check)
      call createCurrent(P_G0, P_A, P_Z, P_Ha, 3693, check)
      call createCurrent(P_Ha, P_WMinus, P_GPlus, P_A, 2810, check)
      call createCurrent(P_Hh, P_Z, P_A, P_Hh, 3449, check)
      call createCurrent(P_GMinus, P_Hh, P_HPlus, P_Ha, 2648, check)
      call createCurrent(P_Hl, P_dAnti, P_d, 770, check)
      call createCurrent(P_b, P_Z, P_bAnti, 2062, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, 375, check)
      call createCurrent(P_cAnti, P_WPlus, P_s, 2262, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_ghWp, 115, check)
      call createCurrent(P_A, P_Z, P_HMinus, P_HPlus, 1590, check)
      call createCurrent(P_HMinus, P_Hh, P_GPlus, 99, check)
      call createCurrent(P_GMinus, P_GPlus, P_A, P_A, 2310, check)
      call createCurrent(P_Ha, P_c, P_cAnti, 1416, check)
      call createCurrent(P_Hl, P_GMinus, P_GPlus, P_Ha, 2732, check)
      call createCurrent(P_Hl, P_Hh, P_GPlus, P_GMinus, 550, check)
      call createCurrent(P_Hl, P_GMinus, P_A, P_WPlus, 439, check)
      call createCurrent(P_nu_muAnti, P_nu_mu, P_Z, 1964, check)
      call createCurrent(P_GPlus, P_WPlus, P_GMinus, P_WMinus, 1536, check)
      call createCurrent(P_tauPlus, P_WMinus, P_nu_tau, 475, check)
      call createCurrent(P_GPlus, P_Ha, P_Hh, P_HMinus, 608, check)
      call createCurrent(P_b, P_tAnti, P_WPlus, 1119, check)
      call createCurrent(P_g, P_g, P_WPlus, P_WMinus, 3852, check)
      call createCurrent(P_Ha, P_GPlus, P_G0, P_GMinus, 1528, check)
      call createCurrent(P_HMinus, P_HPlus, P_Ha, P_G0, 1281, check)
      call createCurrent(P_u, P_HMinus, P_dAnti, 442, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_WMinus, 1487, check)
      call createCurrent(P_Z, P_GMinus, P_A, P_HPlus, 2917, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghZAnti, 750, check)
      call createCurrent(P_GPlus, P_Hl, P_WMinus, P_Z, 1428, check)
      call createCurrent(P_WMinus, P_Z, P_Hh, P_HPlus, 1258, check)
      call createCurrent(P_HMinus, P_WPlus, P_Hh, P_Z, 1657, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_WMinus, 1753, check)
      call createCurrent(P_Hh, P_A, P_GMinus, P_WPlus, 2295, check)
      call createCurrent(P_GMinus, P_GPlus, P_G0, P_Hl, 2872, check)
      call createCurrent(P_A, P_HPlus, P_Z, P_HMinus, 586, check)
      call createCurrent(P_A, P_G0, P_A, P_G0, 3837, check)
      call createCurrent(P_Hl, P_A, P_Hl, P_Z, 3259, check)
      call createCurrent(P_GMinus, P_WPlus, P_HPlus, P_WMinus, 3293, check)
      call createCurrent(P_WPlus, P_HPlus, P_WMinus, P_GMinus, 3475, check)
      call createCurrent(P_WMinus, P_WPlus, 3452, check)
      call createCurrent(P_Hl, P_Z, P_WPlus, P_GMinus, 2451, check)
      call createCurrent(P_Z, P_HMinus, P_GPlus, P_Z, 3236, check)
      call createCurrent(P_G0, P_b, P_bAnti, 1269, check)
      call createCurrent(P_Hh, P_GPlus, P_Ha, P_GMinus, 2982, check)
      call createCurrent(P_HPlus, P_Ha, P_Hl, P_GMinus, 1854, check)
      call createCurrent(P_A, P_WMinus, P_G0, P_HPlus, 3461, check)
      call createCurrent(P_eMinus, P_ePlus, P_Ha, 329, check)
      call createCurrent(P_HMinus, P_GMinus, P_GPlus, P_HPlus, 1075, check)
      call createCurrent(P_Ha, P_GPlus, P_Hl, P_HMinus, 2273, check)
      call createCurrent(P_Hh, P_G0, P_GMinus, P_HPlus, 376, check)
      call createCurrent(P_Z, P_A, P_Ha, P_G0, 3615, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghZAnti, 2534, check)
      call createCurrent(P_GPlus, P_Ha, P_HMinus, 1244, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, P_Hh, 339, check)
      call createCurrent(P_GPlus, P_GMinus, P_Hh, 1584, check)
      call createCurrent(P_Hl, P_HMinus, P_WPlus, P_Z, 92, check)
      call createCurrent(P_A, P_Z, P_Ha, P_G0, 3600, check)
      call createCurrent(P_Hh, P_ghWmAnti, P_ghWm, 1707, check)
      call createCurrent(P_tAnti, P_b, P_HPlus, 2664, check)
      call createCurrent(P_HPlus, P_Hl, P_GMinus, 1942, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_WPlus, 2159, check)
      call createCurrent(P_GMinus, P_WPlus, P_Ha, 2838, check)
      call createCurrent(P_WPlus, P_WMinus, P_WPlus, P_WMinus, 2068, check)
      call createCurrent(P_G0, P_GMinus, P_GPlus, P_Hh, 3395, check)
      call createCurrent(P_GMinus, P_HPlus, P_G0, P_Hl, 2290, check)
      call createCurrent(P_WPlus, P_Z, P_Hl, P_GMinus, 1754, check)
      call createCurrent(P_uAnti, P_Ha, P_u, 759, check)
      call createCurrent(P_Hl, P_ghWpAnti, P_ghWp, 1458, check)
      call createCurrent(P_Hh, P_Hl, P_GPlus, P_GMinus, 1811, check)
      call createCurrent(P_nu_tau, P_Z, P_nu_tauAnti, 81, check)
      call createCurrent(P_WPlus, P_Hh, P_Hl, P_WMinus, 3391, check)
      call createCurrent(P_Ha, P_A, P_GPlus, P_WMinus, 3429, check)
      call createCurrent(P_Hh, P_Hl, P_HMinus, P_HPlus, 1418, check)
      call createCurrent(P_WPlus, P_Z, P_WMinus, P_A, 2061, check)
      call createCurrent(P_HMinus, P_GPlus, P_Hl, P_G0, 1098, check)
      call createCurrent(P_Z, P_Hh, P_WMinus, P_HPlus, 10, check)
      call createCurrent(P_Hl, P_Hh, P_HPlus, P_GMinus, 327, check)
      call createCurrent(P_HPlus, P_G0, P_A, P_WMinus, 3202, check)
      call createCurrent(P_Z, P_HMinus, P_WPlus, P_G0, 2747, check)
      call createCurrent(P_Hl, P_g, P_g, P_Hl, 3687, check)
      call createCurrent(P_cAnti, P_c, P_Hh, 2335, check)
      call createCurrent(P_bAnti, P_t, P_WMinus, 2477, check)
      call createCurrent(P_Hl, P_Z, P_Hl, P_Z, 1962, check)
      call createCurrent(P_WMinus, P_HPlus, P_GMinus, P_WPlus, 3467, check)
      call createCurrent(P_Hh, P_Ha, P_G0, P_Hl, 1894, check)
      call createCurrent(P_HMinus, P_Hh, P_Ha, P_GPlus, 2582, check)
      call createCurrent(P_GMinus, P_G0, P_Hh, P_HPlus, 2652, check)
      call createCurrent(P_Ha, P_HPlus, P_Z, P_WMinus, 2449, check)
      call createCurrent(P_Z, P_GMinus, P_GPlus, P_A, 2388, check)
      call createCurrent(P_GPlus, P_Ha, P_Ha, P_HMinus, 815, check)
      call createCurrent(P_G0, P_GMinus, P_G0, P_GPlus, 2332, check)
      call createCurrent(P_Z, P_HPlus, P_GMinus, 2937, check)
      call createCurrent(P_WMinus, P_Hh, P_GPlus, P_Z, 1059, check)
      call createCurrent(P_WPlus, P_eMinus, P_nu_eAnti, 2184, check)
      call createCurrent(P_tAnti, P_WPlus, P_b, 340, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, P_Hl, 2516, check)
      call createCurrent(P_WPlus, P_Z, P_HMinus, P_G0, 3562, check)
      call createCurrent(P_Hl, P_HPlus, P_A, P_WMinus, 154, check)
      call createCurrent(P_G0, P_Hh, P_G0, P_Ha, 3638, check)
      call createCurrent(P_WMinus, P_ghAAnti, P_ghWp, 1183, check)
      call createCurrent(P_GPlus, P_HMinus, P_WMinus, P_WPlus, 3039, check)
      call createCurrent(P_Hl, P_ghWm, P_ghWmAnti, 1513, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, P_Ha, 3252, check)
      call createCurrent(P_Hh, P_Hh, P_Hh, P_Ha, 3632, check)
      call createCurrent(P_Ha, P_Hh, P_Ha, P_Hh, 1908, check)
      call createCurrent(P_Ha, P_HPlus, P_GMinus, 1600, check)
      call createCurrent(P_HMinus, P_G0, P_WPlus, 2857, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_WMinus, 1717, check)
      call createCurrent(P_Z, P_HMinus, P_WPlus, P_Hh, 2616, check)
      call createCurrent(P_g, P_Hl, P_g, P_Hh, 3653, check)
      call createCurrent(P_Hh, P_WPlus, P_HMinus, 2067, check)
      call createCurrent(P_Hh, P_HPlus, P_GMinus, 489, check)
      call createCurrent(P_WPlus, P_G0, P_HMinus, 3263, check)
      call createCurrent(P_Hh, P_GPlus, P_HMinus, P_Ha, 1609, check)
      call createCurrent(P_HMinus, P_WPlus, P_G0, P_Z, 3462, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, P_G0, 1197, check)
      call createCurrent(P_GMinus, P_HPlus, P_Z, P_A, 2932, check)
      call createCurrent(P_HMinus, P_HPlus, P_Z, 2074, check)
      call createCurrent(P_Hl, P_WPlus, P_WMinus, 2541, check)
      call createCurrent(P_Ha, P_ePlus, P_eMinus, 2111, check)
      call createCurrent(P_HMinus, P_sAnti, P_c, 1459, check)
      call createCurrent(P_nu_eAnti, P_nu_e, P_A, 2796, check)
      call createCurrent(P_WPlus, P_ghA, P_ghWpAnti, 1786, check)
      call createCurrent(P_HPlus, P_Hh, P_G0, P_GMinus, 521, check)
      call createCurrent(P_A, P_WMinus, P_Hh, P_HPlus, 831, check)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_GPlus, 1113, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, 1124, check)
      call createCurrent(P_G0, P_GMinus, P_Hh, P_GPlus, 3327, check)
      call createCurrent(P_WMinus, P_WPlus, P_A, P_A, 951, check)
      call createCurrent(P_GMinus, P_g, P_HPlus, P_g, 3606, check)
      call createCurrent(P_HPlus, P_ghZ, P_ghWpAnti, 3365, check)
      call createCurrent(P_A, P_ghWpAnti, P_ghWp, 561, check)
      call createCurrent(P_G0, P_G0, P_Hl, P_Hh, 1292, check)
      call createCurrent(P_GMinus, P_G0, P_Ha, P_HPlus, 1857, check)
      call createCurrent(P_Ha, P_Hl, P_Hl, P_Hl, 3787, check)
      call createCurrent(P_HMinus, P_Z, P_Hh, P_WPlus, 1886, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_Ha, 1760, check)
      call createCurrent(P_Hh, P_Hl, P_HPlus, P_HMinus, 2549, check)
      call createCurrent(P_Z, P_Z, P_Ha, P_Ha, 1500, check)
      call createCurrent(P_g, P_Z, P_A, P_g, 3829, check)
      call createCurrent(P_GPlus, P_d, P_uAnti, 1102, check)
      call createCurrent(P_Hh, P_Hh, P_HPlus, P_GMinus, 1198, check)
      call createCurrent(P_eMinus, P_ePlus, 2934, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, 1850, check)
      call createCurrent(P_Z, P_GMinus, P_GPlus, P_Z, 389, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, P_Ha, 3224, check)
      call createCurrent(P_Z, P_HMinus, P_Ha, P_WPlus, 188, check)
      call createCurrent(P_Hh, P_GPlus, P_G0, P_GMinus, 3477, check)
      call createCurrent(P_G0, P_Hl, P_Hh, P_G0, 1698, check)
      call createCurrent(P_G0, P_HMinus, P_GPlus, P_Hl, 2340, check)
      call createCurrent(P_Hl, P_HPlus, P_HMinus, P_Ha, 2923, check)
      call createCurrent(P_Hh, P_A, P_HMinus, P_WPlus, 2560, check)
      call createCurrent(P_HMinus, P_WPlus, P_Z, P_G0, 2942, check)
      call createCurrent(P_ghWm, P_Z, P_ghWmAnti, 2280, check)
      call createCurrent(P_HPlus, P_WMinus, P_A, P_G0, 3019, check)
      call createCurrent(P_Ha, P_A, P_Z, P_Ha, 2898, check)
      call createCurrent(P_A, P_WMinus, P_WPlus, P_Z, 902, check)
      call createCurrent(P_HMinus, P_g, P_HPlus, P_g, 3719, check)
      call createCurrent(P_Z, P_A, P_WMinus, P_WPlus, 2530, check)
      call createCurrent(P_Ha, P_A, P_G0, P_A, 3698, check)
      call createCurrent(P_HMinus, P_Ha, P_HPlus, P_Ha, 171, check)
      call createCurrent(P_WPlus, P_G0, P_Z, P_HMinus, 2981, check)
      call createCurrent(P_GPlus, P_WMinus, P_Ha, P_A, 3309, check)
      call createCurrent(P_tauMinus, P_Ha, P_tauPlus, 522, check)
      call createCurrent(P_G0, P_Ha, P_G0, P_G0, 2682, check)
      call createCurrent(P_WPlus, P_G0, P_A, P_HMinus, 3498, check)
      call createCurrent(P_G0, P_HMinus, P_Hh, P_GPlus, 1832, check)
      call createCurrent(P_A, P_A, P_GPlus, P_GMinus, 1064, check)
      call createCurrent(P_Hh, P_HPlus, P_A, P_WMinus, 631, check)
      call createCurrent(P_Ha, P_Hl, P_HMinus, P_HPlus, 3463, check)
      call createCurrent(P_G0, P_Hh, P_HPlus, P_GMinus, 422, check)
      call createCurrent(P_A, P_tAnti, P_t, 925, check)
      call createCurrent(P_WPlus, P_Hl, P_GMinus, 169, check)
      call createCurrent(P_G0, P_GPlus, P_WMinus, 2386, check)
      call createCurrent(P_Ha, P_Z, P_WMinus, P_HPlus, 277, check)
      call createCurrent(P_Hl, P_G0, P_GPlus, P_GMinus, 3266, check)
      call createCurrent(P_eMinus, P_Ha, P_ePlus, 2142, check)
      call createCurrent(P_Hl, P_Hh, P_Ha, P_Ha, 1663, check)
      call createCurrent(P_WPlus, P_HMinus, P_Ha, 2311, check)
      call createCurrent(P_GPlus, P_Z, P_GMinus, P_A, 2476, check)
      call createCurrent(P_WMinus, P_Hh, P_GPlus, 2486, check)
      call createCurrent(P_Hl, P_HMinus, P_G0, P_GPlus, 1080, check)
      call createCurrent(P_Z, P_d, P_dAnti, 993, check)
      call createCurrent(P_G0, P_WMinus, P_WPlus, P_G0, 1718, check)
      call createCurrent(P_ghZAnti, P_Hh, P_ghZ, 2673, check)
      call createCurrent(P_Ha, P_HMinus, P_HPlus, P_Hl, 2984, check)
      call createCurrent(P_Ha, P_Z, 3064, check)
      call createCurrent(P_HPlus, P_WMinus, P_A, P_Hl, 2424, check)
      call createCurrent(P_ePlus, P_nu_e, P_GMinus, 2412, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, P_Ha, 3015, check)
      call createCurrent(P_HPlus, P_d, P_uAnti, 1876, check)
      call createCurrent(P_A, P_nu_e, P_nu_eAnti, 3016, check)
      call createCurrent(P_GPlus, P_GMinus, P_Ha, P_Hh, 3241, check)
      call createCurrent(P_G0, P_Ha, P_Z, P_Z, 3220, check)
      call createCurrent(P_eMinus, P_ePlus, P_Hh, 669, check)
      call createCurrent(P_HMinus, P_WPlus, P_WMinus, P_HPlus, 2323, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_GMinus, 1971, check)
      call createCurrent(P_Z, P_A, P_GPlus, P_GMinus, 1120, check)
      call createCurrent(P_GPlus, P_GMinus, P_Hl, P_G0, 2924, check)
      call createCurrent(P_G0, P_WPlus, P_G0, P_WMinus, 1261, check)
      call createCurrent(P_GMinus, P_c, P_sAnti, 1711, check)
      call createCurrent(P_g, P_c, P_cAnti, 2500, check)
      call createCurrent(P_G0, P_WMinus, P_GPlus, 1817, check)
      call createCurrent(P_HMinus, P_Ha, P_HPlus, 3343, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_A, 2466, check)
      call createCurrent(P_Ha, P_HMinus, P_Hl, P_HPlus, 2880, check)
      call createCurrent(P_Hh, P_GPlus, P_GMinus, 1328, check)
      call createCurrent(P_HPlus, P_GMinus, P_Z, P_Z, 3560, check)
      call createCurrent(P_Hh, P_Z, P_A, 3033, check)
      call createCurrent(P_GPlus, P_GPlus, P_HMinus, P_HMinus, 819, check)
      call createCurrent(P_G0, P_Hh, P_Ha, P_G0, 3803, check)
      call createCurrent(P_WPlus, P_WMinus, P_GPlus, P_GMinus, 1510, check)
      call createCurrent(P_Ha, P_HMinus, P_GPlus, P_G0, 2374, check)
      call createCurrent(P_Hl, P_WPlus, P_A, P_GMinus, 1186, check)
      call createCurrent(P_GPlus, P_HMinus, P_Hh, P_G0, 337, check)
      call createCurrent(P_HMinus, P_Z, P_WPlus, P_Ha, 698, check)
      call createCurrent(P_HMinus, P_HPlus, P_Hl, P_G0, 3484, check)
      call createCurrent(P_G0, P_Z, P_GPlus, P_WMinus, 1828, check)
      call createCurrent(P_Hh, P_G0, P_GPlus, P_GMinus, 3159, check)
      call createCurrent(P_Hh, P_dAnti, P_d, 1981, check)
      call createCurrent(P_ePlus, P_nu_e, P_HMinus, 312, check)
      call createCurrent(P_GPlus, P_Ha, P_G0, P_HMinus, 1083, check)
      call createCurrent(P_Hh, P_HPlus, P_HMinus, P_Hl, 721, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_A, 1965, check)
      call createCurrent(P_Ha, P_Hh, P_GPlus, P_HMinus, 1050, check)
      call createCurrent(P_s, P_Hh, P_sAnti, 1422, check)
      call createCurrent(P_G0, P_GPlus, P_G0, P_GMinus, 211, check)
      call createCurrent(P_Hh, P_HMinus, P_G0, P_HPlus, 3340, check)
      call createCurrent(P_GMinus, P_G0, P_Z, P_WPlus, 1312, check)
      call createCurrent(P_WMinus, P_GPlus, 2801, check)
      call createCurrent(P_A, P_nu_tau, P_nu_tauAnti, 3283, check)
      call createCurrent(P_Z, P_GMinus, P_HPlus, P_Z, 2821, check)
      call createCurrent(P_Ha, P_HMinus, P_GPlus, P_Hh, 1384, check)
      call createCurrent(P_Hl, P_GPlus, P_HMinus, P_Hh, 229, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, P_Ha, 3171, check)
      call createCurrent(P_g, P_sAnti, P_s, 54, check)
      call createCurrent(P_HPlus, P_Z, P_HMinus, 1757, check)
      call createCurrent(P_A, P_A, P_Hh, P_Hh, 3673, check)
      call createCurrent(P_ePlus, P_nu_e, P_WMinus, 1104, check)
      call createCurrent(P_GMinus, P_Ha, P_Hl, P_HPlus, 683, check)
      call createCurrent(P_Ha, P_G0, P_GMinus, P_HPlus, 1247, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, 2644, check)
      call createCurrent(P_GPlus, P_Ha, P_WMinus, P_A, 3509, check)
      call createCurrent(P_A, P_G0, P_Ha, P_Z, 3619, check)
      call createCurrent(P_Z, P_Ha, P_HMinus, P_WPlus, 1626, check)
      call createCurrent(P_A, P_t, P_tAnti, 798, check)
      call createCurrent(P_G0, P_A, P_GPlus, P_WMinus, 2669, check)
      call createCurrent(P_HMinus, P_Ha, P_WPlus, P_Z, 136, check)
      call createCurrent(P_b, P_G0, P_bAnti, 269, check)
      call createCurrent(P_nu_tau, P_GMinus, P_tauPlus, 659, check)
      call createCurrent(P_Z, P_Hl, P_Hl, P_Z, 2010, check)
      call createCurrent(P_WMinus, P_GPlus, P_Hl, P_A, 687, check)
      call createCurrent(P_Hh, P_WMinus, P_GPlus, P_Z, 1032, check)
      call createCurrent(P_WPlus, P_A, P_Hl, P_GMinus, 2115, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, 684, check)
      call createCurrent(P_ghWpAnti, P_Z, P_ghWp, 671, check)
      call createCurrent(P_Hl, P_WMinus, P_GPlus, 2358, check)
      call createCurrent(P_GPlus, P_Ha, P_Hh, P_GMinus, 2891, check)
      call createCurrent(P_Z, P_s, P_sAnti, 1393, check)
      call createCurrent(P_nu_tau, P_WMinus, P_tauPlus, 2532, check)
      call createCurrent(P_sAnti, P_g, P_s, 2576, check)
      call createCurrent(P_bAnti, P_HMinus, P_t, 2318, check)
      call createCurrent(P_Hl, P_Hh, P_GPlus, P_HMinus, 162, check)
      call createCurrent(P_Hl, P_WMinus, P_WPlus, P_Hl, 175, check)
      call createCurrent(P_GPlus, P_HPlus, P_GMinus, P_GMinus, 2293, check)
      call createCurrent(P_GPlus, P_GMinus, P_GPlus, P_GMinus, 1381, check)
      call createCurrent(P_HMinus, P_HPlus, P_g, P_g, 3685, check)
      call createCurrent(P_c, P_HMinus, P_sAnti, 1036, check)
      call createCurrent(P_G0, P_A, P_HMinus, P_WPlus, 2841, check)
      call createCurrent(P_sAnti, P_s, P_g, 1943, check)
      call createCurrent(P_G0, P_Hh, P_G0, P_Hh, 2191, check)
      call createCurrent(P_Z, P_A, P_A, P_Z, 3806, check)
      call createCurrent(P_GPlus, P_Ha, P_Hl, P_GMinus, 3494, check)
      call createCurrent(P_HPlus, P_HMinus, P_GMinus, P_HPlus, 1666, check)
      call createCurrent(P_GMinus, P_Z, P_A, P_HPlus, 3360, check)
      call createCurrent(P_A, P_g, P_Z, P_g, 3767, check)
      call createCurrent(P_Ha, P_t, P_tAnti, 284, check)
      call createCurrent(P_WPlus, P_WPlus, P_WMinus, P_WMinus, 280, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, 241, check)
      call createCurrent(P_HPlus, P_A, P_Z, P_HMinus, 447, check)
      call createCurrent(P_Ha, P_uAnti, P_u, 809, check)
      call createCurrent(P_ePlus, P_Hl, P_eMinus, 1033, check)
      call createCurrent(P_A, P_GMinus, P_Hl, P_WPlus, 401, check)
      call createCurrent(P_WMinus, P_Hl, P_HPlus, P_Z, 2281, check)
      call createCurrent(P_HMinus, P_HPlus, P_Hh, P_Hh, 846, check)
      call createCurrent(P_tAnti, P_t, P_g, 2493, check)
      call createCurrent(P_HPlus, P_GMinus, P_Ha, P_Hh, 1877, check)
      call createCurrent(P_G0, P_Z, P_Z, P_Ha, 2888, check)
      call createCurrent(P_Ha, P_G0, P_A, P_A, 3759, check)
      call createCurrent(P_Hl, P_GPlus, P_GMinus, P_Hl, 962, check)
      call createCurrent(P_G0, P_Ha, P_HMinus, P_GPlus, 96, check)
      call createCurrent(P_HPlus, P_Ha, P_A, P_WMinus, 2051, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, P_Hh, 1446, check)
      call createCurrent(P_GPlus, P_ghZ, P_ghWpAnti, 1546, check)
      call createCurrent(P_Ha, P_G0, P_G0, P_G0, 530, check)
      call createCurrent(P_GMinus, P_Hh, P_GPlus, 1560, check)
      call createCurrent(P_GPlus, P_Ha, P_GMinus, P_G0, 782, check)
      call createCurrent(P_HMinus, P_GPlus, P_Hh, P_Hh, 2312, check)
      call createCurrent(P_Ha, P_Hh, P_GMinus, P_HPlus, 476, check)
      call createCurrent(P_HPlus, P_GMinus, P_WPlus, P_WMinus, 3307, check)
      call createCurrent(P_t, P_tAnti, P_Hl, 1160, check)
      call createCurrent(P_HMinus, P_Ha, P_Ha, P_HPlus, 1359, check)
      call createCurrent(P_A, P_Hl, P_Hl, P_A, 3754, check)
      call createCurrent(P_ghWmAnti, P_Ha, P_ghWm, 2740, check)
      call createCurrent(P_HMinus, P_G0, P_Hl, P_GPlus, 517, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghZAnti, 1611, check)
      call createCurrent(P_Ha, P_GPlus, P_GMinus, P_G0, 740, check)
      call createCurrent(P_eMinus, P_ePlus, P_G0, 2225, check)
      call createCurrent(P_A, P_GMinus, P_HPlus, P_A, 3382, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, P_G0, 53, check)
      call createCurrent(P_Ha, P_GPlus, P_HMinus, P_Hl, 1903, check)
      call createCurrent(P_g, P_g, P_g, 1794, check)
      call createCurrent(P_Hl, P_GMinus, P_Z, P_WPlus, 359, check)
      call createCurrent(P_Ha, P_Hl, P_G0, 855, check)
      call createCurrent(P_Hh, P_A, P_WMinus, P_GPlus, 2520, check)
      call createCurrent(P_GMinus, P_HPlus, P_Hh, P_G0, 2178, check)
      call createCurrent(P_A, P_Hl, P_WPlus, P_HMinus, 293, check)
      call createCurrent(P_G0, P_WPlus, P_WMinus, P_Ha, 3258, check)
      call createCurrent(P_Hl, P_tauPlus, P_tauMinus, 2443, check)
      call createCurrent(P_Hl, P_Ha, P_HMinus, P_GPlus, 1209, check)
      call createCurrent(P_A, P_Hh, P_GMinus, P_WPlus, 682, check)
      call createCurrent(P_Hl, P_HPlus, P_HMinus, P_Hh, 1172, check)
      call createCurrent(P_Hh, P_GMinus, P_WPlus, P_A, 1930, check)
      call createCurrent(P_GPlus, P_WMinus, P_Hh, 60, check)
      call createCurrent(P_GMinus, P_HPlus, P_Hl, P_Ha, 710, check)
      call createCurrent(P_WPlus, P_HMinus, P_Ha, P_A, 1003, check)
      call createCurrent(P_HMinus, P_Ha, P_Ha, P_GPlus, 124, check)
      call createCurrent(P_Ha, P_Ha, P_GPlus, P_GMinus, 1847, check)
      call createCurrent(P_HPlus, P_HPlus, P_HMinus, P_GMinus, 761, check)
      call createCurrent(P_GMinus, P_G0, P_Hh, P_GPlus, 3135, check)
      call createCurrent(P_nu_tau, P_A, P_nu_tauAnti, 3334, check)
      call createCurrent(P_Z, P_WMinus, P_WPlus, P_Z, 767, check)
      call createCurrent(P_GPlus, P_HMinus, P_Hl, 2155, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghA, 2528, check)
      call createCurrent(P_WPlus, P_HMinus, 2899, check)
      call createCurrent(P_g, P_Hl, P_Hh, P_g, 3776, check)
      call createCurrent(P_WMinus, P_GPlus, P_G0, P_Z, 2338, check)
      call createCurrent(P_HPlus, P_Ha, P_HMinus, P_G0, 413, check)
      call createCurrent(P_Ha, P_Hl, P_G0, P_Hh, 4, check)
      call createCurrent(P_WPlus, P_HMinus, P_GPlus, P_WMinus, 3017, check)
      call createCurrent(P_Hl, P_A, P_Hl, P_A, 3878, check)
      call createCurrent(P_GMinus, P_GPlus, P_GPlus, P_GMinus, 258, check)
      call createCurrent(P_GPlus, P_GMinus, P_Hl, P_Ha, 2749, check)
      call createCurrent(P_HPlus, P_WPlus, P_GMinus, P_WMinus, 3373, check)
      call createCurrent(P_u, P_WMinus, P_dAnti, 179, check)
      call createCurrent(P_GPlus, P_A, P_Z, P_HMinus, 3173, check)
      call createCurrent(P_GMinus, P_GPlus, P_Ha, 3260, check)
      call createCurrent(P_Ha, P_GPlus, P_Ha, P_HMinus, 2538, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, 2030, check)
      call createCurrent(P_GPlus, P_GMinus, P_G0, P_Ha, 714, check)
      call createCurrent(P_ghG, P_g, P_ghGAnti, 2597, check)
      call createCurrent(P_G0, P_Hh, P_A, 3291, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, P_Hl, 896, check)
      call createCurrent(P_GPlus, P_GMinus, P_GMinus, P_HPlus, 2203, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_ghWm, 1902, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_HPlus, 3219, check)
      call createCurrent(P_HMinus, P_A, P_Z, P_GPlus, 3550, check)
      call createCurrent(P_HPlus, P_Hl, P_GMinus, P_Hh, 110, check)
      call createCurrent(P_tauPlus, P_Hh, P_tauMinus, 1139, check)
      call createCurrent(P_sAnti, P_HMinus, P_c, 1507, check)
      call createCurrent(P_tauMinus, P_Z, P_tauPlus, 744, check)
      call createCurrent(P_A, P_g, P_g, P_A, 3766, check)
      call createCurrent(P_GMinus, P_Ha, P_WPlus, P_Z, 3577, check)
      call createCurrent(P_HMinus, P_G0, P_HPlus, P_Hh, 3175, check)
      call createCurrent(P_GMinus, P_nu_mu, P_muPlus, 1644, check)
      call createCurrent(P_HPlus, P_HMinus, P_Z, P_Z, 1836, check)
      call createCurrent(P_G0, P_GMinus, P_Hl, P_HPlus, 176, check)
      call createCurrent(P_A, P_bAnti, P_b, 1049, check)
      call createCurrent(P_g, P_HMinus, P_HPlus, P_g, 3733, check)
      call createCurrent(P_A, P_Z, P_Hl, P_Hh, 3790, check)
      call createCurrent(P_GPlus, P_GMinus, P_Hh, P_Hh, 22, check)
      call createCurrent(P_G0, P_G0, P_A, P_Z, 3213, check)
      call createCurrent(P_HMinus, P_HPlus, P_Ha, P_Ha, 35, check)
      call createCurrent(P_ePlus, P_eMinus, 2985, check)
      call createCurrent(P_HMinus, P_A, P_A, P_GPlus, 2843, check)
      call createCurrent(P_nu_tau, P_nu_tauAnti, P_Z, 2699, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghA, 379, check)
      call createCurrent(P_GMinus, P_G0, P_G0, P_GPlus, 1480, check)
      call createCurrent(P_WPlus, P_GMinus, P_Hl, P_Z, 1048, check)
      call createCurrent(P_Hh, P_s, P_sAnti, 2217, check)
      call createCurrent(P_Hh, P_HPlus, P_Z, P_WMinus, 996, check)
      call createCurrent(P_Ha, P_GPlus, P_Z, P_WMinus, 2806, check)
      call createCurrent(P_A, P_Z, P_Hh, 2717, check)
      call createCurrent(P_HMinus, P_HMinus, P_GPlus, P_HPlus, 2571, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_GPlus, 2703, check)
      call createCurrent(P_t, P_bAnti, P_GMinus, 2488, check)
      call createCurrent(P_g, P_Ha, P_Ha, P_g, 3715, check)
      call createCurrent(P_GPlus, P_G0, P_HMinus, P_Ha, 1394, check)
      call createCurrent(P_GPlus, P_G0, P_HMinus, 898, check)
      call createCurrent(P_Hh, P_HMinus, P_GPlus, 626, check)
      call createCurrent(P_WPlus, P_Ha, P_WMinus, P_Ha, 793, check)
      call createCurrent(P_bAnti, P_GMinus, P_t, 1615, check)
      call createCurrent(P_g, P_Z, P_g, P_g, 3683, check)
      call createCurrent(P_Z, P_tauMinus, P_tauPlus, 1380, check)
      call createCurrent(P_Z, P_HMinus, P_GPlus, 2927, check)
      call createCurrent(P_HMinus, P_Z, P_GPlus, 3031, check)
      call createCurrent(P_GMinus, P_HMinus, P_HPlus, P_HPlus, 1649, check)
      call createCurrent(P_GPlus, P_HPlus, P_HMinus, P_GMinus, 1583, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_A, 168, check)
      call createCurrent(P_Ha, P_A, P_WPlus, P_HMinus, 1334, check)
      call createCurrent(P_Z, P_A, P_WPlus, P_WMinus, 63, check)
      call createCurrent(P_Hl, P_Hl, P_Hl, P_Hh, 572, check)
      call createCurrent(P_nu_tau, P_tauPlus, P_GMinus, 2103, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, P_G0, 1420, check)
      call createCurrent(P_HPlus, P_Hl, P_A, P_WMinus, 1229, check)
      call createCurrent(P_WPlus, P_WMinus, P_Hh, 1762, check)
      call createCurrent(P_GMinus, P_WPlus, P_Hh, P_A, 2006, check)
      call createCurrent(P_nu_muAnti, P_muMinus, P_HPlus, 1257, check)
      call createCurrent(P_Ha, P_eMinus, P_ePlus, 1983, check)
      call createCurrent(P_GPlus, P_uAnti, P_d, 1470, check)
      call createCurrent(P_WPlus, P_WMinus, P_Hl, P_Hh, 2742, check)
      call createCurrent(P_GMinus, P_HPlus, P_Ha, P_Hl, 464, check)
      call createCurrent(P_WMinus, P_Hh, P_GPlus, P_A, 2531, check)
      call createCurrent(P_Hh, P_HMinus, P_HPlus, P_G0, 3094, check)
      call createCurrent(P_HPlus, P_Hl, P_Hh, P_HMinus, 1217, check)
      call createCurrent(P_Hl, P_Hh, P_Hl, 1745, check)
      call createCurrent(P_G0, P_tauMinus, P_tauPlus, 1547, check)
      call createCurrent(P_A, P_A, P_Hl, P_Hl, 3778, check)
      call createCurrent(P_GPlus, P_HMinus, P_Hh, P_Hh, 1889, check)
      call createCurrent(P_G0, P_s, P_sAnti, 2371, check)
      call createCurrent(P_Hh, P_HPlus, P_GMinus, P_Hh, 1387, check)
      call createCurrent(P_WMinus, P_HPlus, P_Hl, 2041, check)
      call createCurrent(P_GPlus, P_HMinus, P_g, P_g, 3737, check)
      call createCurrent(P_Ha, P_Ha, P_GMinus, P_HPlus, 1947, check)
      call createCurrent(P_Z, P_WMinus, P_Hh, P_HPlus, 311, check)
      call createCurrent(P_Hl, P_G0, P_HMinus, P_GPlus, 988, check)
      call createCurrent(P_bAnti, P_b, P_Hl, 2228, check)
      call createCurrent(P_Ha, P_Hl, P_Ha, 104, check)
      call createCurrent(P_G0, P_WMinus, P_A, P_HPlus, 3023, check)
      call createCurrent(P_Hh, P_Hl, P_GMinus, P_HPlus, 1234, check)
      call createCurrent(P_GMinus, P_HPlus, P_G0, P_G0, 2687, check)
      call createCurrent(P_A, P_GMinus, P_HPlus, 3539, check)
      call createCurrent(P_muMinus, P_muPlus, P_Hl, 2075, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_ghWm, 2250, check)
      call createCurrent(P_nu_tau, P_nu_tauAnti, 3267, check)
      call createCurrent(P_Ha, P_A, P_Hl, 3304, check)
      call createCurrent(P_muPlus, P_HMinus, P_nu_mu, 1995, check)
      call createCurrent(P_WMinus, P_Hl, P_GPlus, 886, check)
      call createCurrent(P_tauPlus, P_nu_tau, P_WMinus, 1424, check)
      call createCurrent(P_HPlus, P_GPlus, P_HMinus, P_HMinus, 816, check)
      call createCurrent(P_WMinus, P_WPlus, P_G0, P_G0, 1331, check)
      call createCurrent(P_Z, P_g, P_A, P_g, 3686, check)
      call createCurrent(P_tAnti, P_t, P_G0, 216, check)
      call createCurrent(P_muMinus, P_nu_muAnti, P_HPlus, 549, check)
      call createCurrent(P_HPlus, P_GMinus, P_GMinus, P_GPlus, 482, check)
      call createCurrent(P_WPlus, P_WMinus, P_HPlus, P_GMinus, 3386, check)
      call createCurrent(P_WPlus, P_Hl, P_A, P_GMinus, 1720, check)
      call createCurrent(P_Hh, P_tauMinus, P_tauPlus, 2452, check)
      call createCurrent(P_Hh, P_G0, P_G0, P_Hh, 403, check)
      call createCurrent(P_GPlus, P_GMinus, P_HPlus, P_GMinus, 2602, check)
      call createCurrent(P_GPlus, P_HMinus, P_Hl, P_Ha, 417, check)
      call createCurrent(P_b, P_bAnti, P_Hh, 713, check)
      call createCurrent(P_A, P_G0, P_Z, P_Ha, 3681, check)
      call createCurrent(P_s, P_G0, P_sAnti, 1, check)
      call createCurrent(P_Hl, P_GMinus, P_GPlus, P_Hh, 1725, check)
      call createCurrent(P_Z, P_G0, P_WMinus, P_GPlus, 1743, check)
      call createCurrent(P_Ha, P_GPlus, P_WMinus, 3063, check)
      call createCurrent(P_HMinus, P_G0, P_GPlus, 1148, check)
      call createCurrent(P_GMinus, P_ghWp, P_ghZAnti, 839, check)
      call createCurrent(P_HPlus, P_HMinus, P_G0, P_Ha, 2092, check)
      call createCurrent(P_Z, P_Z, P_Hh, P_Hh, 486, check)
      call createCurrent(P_A, P_GPlus, P_Ha, P_WMinus, 2975, check)
      call createCurrent(P_Hh, P_G0, P_G0, 491, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, P_Ha, 3097, check)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_WPlus, 2245, check)
      call createCurrent(P_nu_e, P_nu_eAnti, P_A, 3280, check)
      call createCurrent(P_Hh, P_G0, P_Hl, P_G0, 1213, check)
      call createCurrent(P_WPlus, P_Hh, P_WMinus, P_Hl, 3034, check)
      call createCurrent(P_A, P_Z, P_GPlus, P_GMinus, 354, check)
      call createCurrent(P_d, P_A, P_dAnti, 1411, check)
      call createCurrent(P_HPlus, P_WMinus, P_WPlus, P_HMinus, 2098, check)
      call createCurrent(P_HMinus, P_GPlus, P_Hh, P_Ha, 2212, check)
      call createCurrent(P_Hh, P_WPlus, P_GMinus, P_Z, 2458, check)
      call createCurrent(P_Z, P_G0, P_Ha, P_Z, 3564, check)
      call createCurrent(P_GMinus, P_GPlus, P_G0, P_Ha, 2054, check)
      call createCurrent(P_WPlus, P_Z, P_HMinus, 1952, check)
      call createCurrent(P_G0, P_GPlus, P_G0, P_HMinus, 1849, check)
      call createCurrent(P_HMinus, P_Hh, P_WPlus, P_A, 1721, check)
      call createCurrent(P_Hl, P_g, P_g, P_Hh, 3741, check)
      call createCurrent(P_G0, P_Ha, P_Hh, P_G0, 3702, check)
      call createCurrent(P_GPlus, P_G0, P_WMinus, 952, check)
      call createCurrent(P_Hh, P_Ha, P_GMinus, P_GPlus, 3066, check)
      call createCurrent(P_HMinus, P_HPlus, P_G0, 3314, check)
      call createCurrent(P_Z, P_G0, P_Z, P_Ha, 3279, check)
      call createCurrent(P_GMinus, P_WPlus, P_Hl, P_Z, 1577, check)
      call createCurrent(P_GMinus, P_HPlus, P_Hl, P_G0, 1138, check)
      call createCurrent(P_GMinus, P_Hl, P_Ha, P_GPlus, 3478, check)
      call createCurrent(P_HMinus, P_WPlus, P_Z, P_Hl, 1107, check)
      call createCurrent(P_g, P_g, P_Z, P_A, 3750, check)
      call createCurrent(P_Hh, P_HMinus, P_Hl, P_HPlus, 1740, check)
      call createCurrent(P_G0, P_HMinus, P_GPlus, P_G0, 945, check)
      call createCurrent(P_Z, P_Z, 3345, check)
      call createCurrent(P_Hh, P_Hl, P_Z, P_A, 3659, check)
      call createCurrent(P_ghZ, P_Hh, P_ghZAnti, 1939, check)
      call createCurrent(P_WPlus, P_Hh, P_GMinus, 575, check)
      call createCurrent(P_HPlus, P_GMinus, P_A, P_A, 2863, check)
      call createCurrent(P_A, P_WPlus, P_WMinus, P_Z, 2598, check)
      call createCurrent(P_HPlus, P_GPlus, P_HMinus, P_GMinus, 2636, check)
      call createCurrent(P_A, P_A, P_GMinus, P_HPlus, 3284, check)
      call createCurrent(P_WPlus, P_Ha, P_WMinus, P_G0, 3503, check)
      call createCurrent(P_A, P_WMinus, P_Hh, P_GPlus, 1318, check)
      call createCurrent(P_HPlus, P_WPlus, P_WMinus, P_GMinus, 3057, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, 1343, check)
      call createCurrent(P_GMinus, P_Ha, P_WPlus, 3101, check)
      call createCurrent(P_Hl, P_G0, P_Ha, 419, check)
      call createCurrent(P_GMinus, P_Hl, P_HPlus, 383, check)
      call createCurrent(P_GPlus, P_GMinus, P_G0, P_Hh, 2803, check)
      call createCurrent(P_HPlus, P_Ha, P_Ha, P_GMinus, 1158, check)
      call createCurrent(P_WMinus, P_A, P_Hl, P_GPlus, 245, check)
      call createCurrent(P_tAnti, P_A, P_t, 234, check)
      call createCurrent(P_Hh, P_G0, P_HMinus, P_GPlus, 1931, check)
      call createCurrent(P_Z, P_G0, P_A, P_G0, 3357, check)
      call createCurrent(P_HPlus, P_Z, P_Hh, P_WMinus, 2442, check)
      call createCurrent(P_WPlus, P_WMinus, P_GMinus, P_HPlus, 3155, check)
      call createCurrent(P_HMinus, P_GPlus, P_Ha, P_Hh, 880, check)
      call createCurrent(P_c, P_WMinus, P_sAnti, 990, check)
      call createCurrent(P_Hh, P_Hh, P_HPlus, P_HMinus, 689, check)
      call createCurrent(P_g, P_GPlus, P_g, P_GMinus, 3849, check)
      call createCurrent(P_Hh, P_GMinus, P_Z, P_WPlus, 420, check)
      call createCurrent(P_WPlus, P_GMinus, P_Hh, P_A, 2176, check)
      call createCurrent(P_s, P_sAnti, P_A, 259, check)
      call createCurrent(P_A, P_Hl, P_HPlus, P_WMinus, 2406, check)
      call createCurrent(P_Ha, P_s, P_sAnti, 765, check)
      call createCurrent(P_A, P_GPlus, P_Z, P_HMinus, 2963, check)
      call createCurrent(P_t, P_tAnti, P_g, 120, check)
      call createCurrent(P_Hl, P_HPlus, P_GMinus, P_Ha, 571, check)
      call createCurrent(P_GPlus, P_ghA, P_ghWpAnti, 2353, check)
      call createCurrent(P_Hl, P_HMinus, P_Z, P_WPlus, 605, check)
      call createCurrent(P_Hl, P_Hl, P_Ha, P_Ha, 366, check)
      call createCurrent(P_GPlus, P_Hh, P_G0, P_GMinus, 3319, check)
      call createCurrent(P_Hl, P_GMinus, P_WPlus, P_A, 1502, check)
      call createCurrent(P_A, P_HPlus, P_GMinus, 3065, check)
      call createCurrent(P_Z, P_Hh, P_A, 3295, check)
      call createCurrent(P_Hl, P_g, P_Hh, P_g, 3851, check)
      call createCurrent(P_Hl, P_g, P_g, 3824, check)
      call createCurrent(P_WMinus, P_WPlus, P_HMinus, P_GPlus, 3133, check)
      call createCurrent(P_Z, P_bAnti, P_b, 2450, check)
      call createCurrent(P_A, P_Hh, P_HPlus, P_WMinus, 2007, check)
      call createCurrent(P_Hh, P_Ha, P_Hh, P_G0, 1439, check)
      call createCurrent(P_Ha, P_A, P_HMinus, P_WPlus, 409, check)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_GPlus, 256, check)
      call createCurrent(P_G0, P_WPlus, P_GMinus, P_A, 1508, check)
      call createCurrent(P_Ha, P_Hl, P_Z, 396, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, P_Hh, 1887, check)
      call createCurrent(P_Z, P_dAnti, P_d, 2195, check)
      call createCurrent(P_HMinus, P_Hh, P_Ha, P_HPlus, 3093, check)
      call createCurrent(P_HMinus, P_GPlus, P_GPlus, P_HMinus, 2365, check)
      call createCurrent(P_A, P_WMinus, P_A, P_WPlus, 946, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Hl, 1184, check)
      call createCurrent(P_Ha, P_Ha, P_Hh, P_Hh, 1010, check)
      call createCurrent(P_HMinus, P_Hh, P_Hl, P_GPlus, 1404, check)
      call createCurrent(P_bAnti, P_b, P_Z, 1330, check)
      call createCurrent(P_sAnti, P_Hh, P_s, 2364, check)
      call createCurrent(P_G0, P_Ha, P_A, P_A, 3781, check)
      call createCurrent(P_HPlus, P_Hl, P_G0, P_HMinus, 3325, check)
      call createCurrent(P_G0, P_Hl, P_GMinus, P_HPlus, 441, check)
      call createCurrent(P_A, P_c, P_cAnti, 2283, check)
      call createCurrent(P_GPlus, P_Z, P_HMinus, 3274, check)
      call createCurrent(P_GPlus, P_G0, P_HMinus, P_Hh, 947, check)
      call createCurrent(P_WMinus, P_A, P_Ha, P_GPlus, 3025, check)
      call createCurrent(P_G0, P_Ha, P_Hh, P_Hh, 2307, check)
      call createCurrent(P_tAnti, P_t, P_Ha, 112, check)
      call createCurrent(P_A, P_uAnti, P_u, 2121, check)
      call createCurrent(P_A, P_GPlus, P_GMinus, P_A, 1685, check)
      call createCurrent(P_GPlus, P_Z, P_GMinus, 125, check)
      call createCurrent(P_GMinus, P_G0, P_HPlus, 2135, check)
      call createCurrent(P_Z, P_g, P_g, P_g, 3848, check)
      call createCurrent(P_HMinus, P_Z, P_Z, P_HPlus, 2341, check)
      call createCurrent(P_HPlus, P_G0, P_G0, P_GMinus, 2169, check)
      call createCurrent(P_nu_eAnti, P_HPlus, P_eMinus, 818, check)
      call createCurrent(P_GMinus, P_Z, P_GPlus, P_Z, 1802, check)
      call createCurrent(P_WPlus, P_HMinus, P_A, P_Hh, 876, check)
      call createCurrent(P_Hl, P_Hl, 2789, check)
      call createCurrent(P_Z, P_g, P_Z, P_g, 3762, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, P_Ha, 3248, check)
      call createCurrent(P_uAnti, P_u, 3231, check)
      call createCurrent(P_Ha, P_Z, P_Ha, P_Z, 654, check)
      call createCurrent(P_Hl, P_Ha, P_Z, 787, check)
      call createCurrent(P_b, P_A, P_bAnti, 500, check)
      call createCurrent(P_eMinus, P_nu_eAnti, P_WPlus, 2421, check)
      call createCurrent(P_HMinus, P_Hh, P_HPlus, P_Hh, 1736, check)
      call createCurrent(P_GMinus, P_Hh, P_GPlus, P_G0, 3227, check)
      call createCurrent(P_Hh, P_WMinus, P_WPlus, P_Hl, 3184, check)
      call createCurrent(P_s, P_g, P_sAnti, 1307, check)
      call createCurrent(P_Hl, P_Ha, P_HMinus, P_HPlus, 2960, check)
      call createCurrent(P_G0, P_G0, P_Z, P_Z, 2385, check)
      call createCurrent(P_HMinus, P_Hh, P_HPlus, P_G0, 2817, check)
      call createCurrent(P_G0, P_WMinus, P_HPlus, 2944, check)
      call createCurrent(P_GPlus, P_HMinus, P_Hh, P_Ha, 2628, check)
      call createCurrent(P_G0, P_Ha, P_HPlus, P_HMinus, 1940, check)
      call createCurrent(P_Hh, P_HPlus, P_GMinus, P_Ha, 1455, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, 480, check)
      call createCurrent(P_A, P_Hl, P_A, 3884, check)
      call createCurrent(P_Z, P_GMinus, P_Hl, P_WPlus, 2377, check)
      call createCurrent(P_HMinus, P_Z, P_HPlus, P_A, 2524, check)
      call createCurrent(P_GPlus, P_HMinus, P_Ha, P_Hh, 1297, check)
      call createCurrent(P_A, P_g, P_g, P_g, 3774, check)
      call createCurrent(P_Z, P_Ha, P_WPlus, P_GMinus, 2746, check)
      call createCurrent(P_WMinus, P_GPlus, P_Ha, 3132, check)
      call createCurrent(P_nu_e, P_GMinus, P_ePlus, 1655, check)
      call createCurrent(P_GPlus, P_Hl, P_GMinus, P_G0, 2908, check)
      call createCurrent(P_Hl, P_GMinus, P_GPlus, 326, check)
      call createCurrent(P_GPlus, P_G0, P_Ha, P_HMinus, 2640, check)
      call createCurrent(P_b, P_Hh, P_bAnti, 803, check)
      call createCurrent(P_Hh, P_GPlus, P_HMinus, P_Hl, 83, check)
      call createCurrent(P_WMinus, P_WPlus, P_HPlus, P_GMinus, 3221, check)
      call createCurrent(P_HMinus, P_WPlus, P_G0, P_A, 3239, check)
      call createCurrent(P_HPlus, P_Z, P_G0, P_WMinus, 2734, check)
      call createCurrent(P_WMinus, P_Ha, P_GPlus, 3405, check)
      call createCurrent(P_WMinus, P_Ha, P_Z, P_HPlus, 1861, check)
      call createCurrent(P_HMinus, P_Z, P_WPlus, P_G0, 3378, check)
      call createCurrent(P_Hh, P_Ha, P_G0, 1341, check)
      call createCurrent(P_ghZ, P_HMinus, P_ghWmAnti, 3353, check)
      call createCurrent(P_Hh, P_WPlus, P_WMinus, 664, check)
      call createCurrent(P_HPlus, P_Ha, P_G0, P_GMinus, 2403, check)
      call createCurrent(P_dAnti, P_d, 3372, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, P_Ha, 2829, check)
      call createCurrent(P_HPlus, P_Hl, P_Z, P_WMinus, 213, check)
      call createCurrent(P_Hh, P_Z, P_Hh, P_A, 2900, check)
      call createCurrent(P_s, P_sAnti, P_Z, 236, check)
      call createCurrent(P_A, P_Hl, P_Ha, 2894, check)
      call createCurrent(P_HPlus, P_G0, P_WMinus, P_A, 3454, check)
      call createCurrent(P_Hh, P_GPlus, P_Hl, P_HMinus, 140, check)
      call createCurrent(P_HPlus, P_HMinus, P_Hh, P_G0, 3397, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, P_Ha, 2973, check)
      call createCurrent(P_Hl, P_WPlus, P_HMinus, P_Z, 720, check)
      call createCurrent(P_Z, P_ghWm, P_ghWmAnti, 1323, check)
      call createCurrent(P_GMinus, P_GPlus, P_Ha, P_Hl, 3148, check)
      call createCurrent(P_WPlus, P_HMinus, P_Hh, P_Z, 2577, check)
      call createCurrent(P_GPlus, P_GPlus, P_GMinus, P_HMinus, 790, check)
      call createCurrent(P_Z, P_G0, P_Hl, 1401, check)
      call createCurrent(P_GMinus, P_Ha, P_HPlus, P_Hl, 2646, check)
      call createCurrent(P_Z, P_Hh, P_WMinus, P_GPlus, 825, check)
      call createCurrent(P_Hh, P_G0, P_Hh, P_G0, 730, check)
      call createCurrent(P_g, P_d, P_dAnti, 353, check)
      call createCurrent(P_HPlus, P_ghWpAnti, P_ghZ, 3432, check)
      call createCurrent(P_Hl, P_HPlus, P_WMinus, P_A, 2444, check)
      call createCurrent(P_G0, P_G0, P_Hl, P_Ha, 3755, check)
      call createCurrent(P_HMinus, P_GPlus, P_Hl, P_Ha, 672, check)
      call createCurrent(P_Hl, P_Hl, P_A, P_Z, 2854, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_HPlus, 3336, check)
      call createCurrent(P_cAnti, P_g, P_c, 1170, check)
      call createCurrent(P_Z, P_Z, P_G0, P_Ha, 2913, check)
      call createCurrent(P_HPlus, P_G0, P_Hh, P_HMinus, 3437, check)
      call createCurrent(P_A, P_cAnti, P_c, 1687, check)
      call createCurrent(P_HPlus, P_Hl, P_Ha, P_GMinus, 2044, check)
      call createCurrent(P_GMinus, P_WPlus, P_Hh, 2496, check)
      call createCurrent(P_GMinus, P_Z, P_A, P_GPlus, 1996, check)
      call createCurrent(P_WPlus, P_A, P_HMinus, 2085, check)
      call createCurrent(P_Ha, P_Hl, P_Ha, P_Hl, 2674, check)
      call createCurrent(P_HPlus, P_HMinus, P_HMinus, P_HPlus, 1382, check)
      call createCurrent(P_A, P_nu_muAnti, P_nu_mu, 2882, check)
      call createCurrent(P_g, P_tAnti, P_t, 1527, check)
      call createCurrent(P_WMinus, P_G0, P_WPlus, P_Ha, 3095, check)
      call createCurrent(P_GPlus, P_g, P_g, P_HMinus, 3730, check)
      call createCurrent(P_WPlus, P_Hl, P_HMinus, P_Z, 694, check)
      call createCurrent(P_A, P_A, P_A, P_A, 3734, check)
      call createCurrent(P_G0, P_Ha, P_HMinus, P_HPlus, 479, check)
      call createCurrent(P_cAnti, P_Hl, P_c, 1815, check)
      call createCurrent(P_Hh, P_GMinus, P_GPlus, P_Hh, 257, check)
      call createCurrent(P_Ha, P_Hl, P_G0, P_G0, 3845, check)
      call createCurrent(P_WMinus, P_GMinus, P_WPlus, P_HPlus, 3312, check)
      call createCurrent(P_A, P_Z, P_A, P_A, 3850, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Hl, 748, check)
      call createCurrent(P_Hh, P_WPlus, P_A, P_GMinus, 363, check)
      call createCurrent(P_Z, P_Z, P_Z, P_Z, 3815, check)
      call createCurrent(P_Hh, P_Hl, P_A, P_Z, 3680, check)
      call createCurrent(P_g, P_g, P_GMinus, P_GPlus, 3597, check)
      call createCurrent(P_cAnti, P_s, P_WPlus, 1739, check)
      call createCurrent(P_Hh, P_WPlus, P_Hh, P_WMinus, 1820, check)
      call createCurrent(P_t, P_g, P_tAnti, 2202, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, P_Hl, 1677, check)
      call createCurrent(P_HMinus, P_HPlus, P_Ha, P_Hl, 3583, check)
      call createCurrent(P_Hl, P_Z, P_HMinus, P_WPlus, 1169, check)
      call createCurrent(P_Z, P_Hh, P_Hh, P_Z, 1031, check)
      call createCurrent(P_g, P_g, P_Ha, P_G0, 3663, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_GMinus, 1291, check)
      call createCurrent(P_Z, P_HPlus, P_GMinus, P_Z, 2853, check)
      call createCurrent(P_G0, P_G0, P_HPlus, P_HMinus, 1785, check)
      call createCurrent(P_ghG, P_ghGAnti, P_g, 1126, check)
      call createCurrent(P_WPlus, P_Hl, P_GMinus, P_Z, 2032, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_ghWp, 2572, check)
      call createCurrent(P_HPlus, P_Hh, P_WMinus, P_Z, 1976, check)
      call createCurrent(P_Hh, P_Z, P_Hl, P_A, 3789, check)
      call createCurrent(P_HMinus, P_Hl, P_Ha, P_GPlus, 65, check)
      call createCurrent(P_G0, P_WPlus, P_Z, P_GMinus, 1043, check)
      call createCurrent(P_A, P_HMinus, P_A, P_GPlus, 3139, check)
      call createCurrent(P_WPlus, P_A, P_A, P_WMinus, 2248, check)
      call createCurrent(P_WMinus, P_HPlus, P_Hl, P_A, 1087, check)
      call createCurrent(P_Hl, P_A, P_Z, P_Hl, 3012, check)
      call createCurrent(P_ghA, P_WPlus, P_ghWpAnti, 768, check)
      call createCurrent(P_HMinus, P_Hl, P_GPlus, 2304, check)
      call createCurrent(P_Ha, P_Z, P_Ha, P_A, 2947, check)
      call createCurrent(P_WMinus, P_Ha, P_HPlus, P_A, 302, check)
      call createCurrent(P_Hl, P_d, P_dAnti, 2354, check)
      call createCurrent(P_HPlus, P_Ha, P_WMinus, 80, check)
      call createCurrent(P_Hh, P_eMinus, P_ePlus, 2631, check)
      call createCurrent(P_u, P_Hh, P_uAnti, 1892, check)
      call createCurrent(P_muPlus, P_muMinus, 3005, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_A, 892, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, 2214, check)
      call createCurrent(P_Z, P_HPlus, P_WMinus, P_Ha, 1911, check)
      call createCurrent(P_Ha, P_G0, P_GMinus, P_GPlus, 43, check)
      call createCurrent(P_GMinus, P_Hh, P_Hl, P_GPlus, 555, check)
      call createCurrent(P_G0, P_Ha, P_Hl, 72, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, P_Hl, 2639, check)
      call createCurrent(P_Ha, P_Hh, P_Z, 1188, check)
      call createCurrent(P_Z, P_nu_muAnti, P_nu_mu, 201, check)
      call createCurrent(P_Hh, P_HPlus, P_Ha, P_GMinus, 2521, check)
      call createCurrent(P_G0, P_G0, P_Ha, P_G0, 77, check)
      call createCurrent(P_Hh, P_WMinus, P_GPlus, P_A, 1313, check)
      call createCurrent(P_HMinus, P_GPlus, P_G0, P_Ha, 1658, check)
      call createCurrent(P_A, P_ghWmAnti, P_ghWm, 2163, check)
      call createCurrent(P_Z, P_A, P_Hh, P_Hl, 3595, check)
      call createCurrent(P_GMinus, P_WPlus, P_Hl, 2080, check)
      call createCurrent(P_WMinus, P_GPlus, P_G0, P_A, 2548, check)
      call createCurrent(P_HPlus, P_HMinus, P_GMinus, P_GPlus, 1215, check)
      call createCurrent(P_Hl, P_ghZAnti, P_ghZ, 1177, check)
      call createCurrent(P_Z, P_G0, P_Ha, P_A, 3660, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghZ, 1375, check)
      call createCurrent(P_Ha, P_A, P_A, P_Ha, 3689, check)
      call createCurrent(P_HPlus, P_WMinus, P_Z, P_G0, 3124, check)
      call createCurrent(P_d, P_Hl, P_dAnti, 157, check)
      call createCurrent(P_Hh, P_A, P_Hl, P_A, 3703, check)
      call createCurrent(P_Hl, P_u, P_uAnti, 296, check)
      call createCurrent(P_WPlus, P_WMinus, P_g, P_g, 3669, check)
      call createCurrent(P_WPlus, P_Ha, P_HMinus, 1651, check)
      call createCurrent(P_Z, P_G0, P_GPlus, P_WMinus, 1639, check)
      call createCurrent(P_Hl, P_ghWp, P_ghWpAnti, 968, check)
      call createCurrent(P_WPlus, P_WMinus, P_GPlus, P_HMinus, 2759, check)
      call createCurrent(P_HPlus, P_G0, P_HMinus, P_G0, 2088, check)
      call createCurrent(P_WMinus, P_A, P_Z, P_WPlus, 1659, check)
      call createCurrent(P_Z, P_b, P_bAnti, 620, check)
      call createCurrent(P_GMinus, P_G0, P_WPlus, P_Z, 747, check)
      call createCurrent(P_HMinus, P_G0, P_HPlus, 3420, check)
      call createCurrent(P_HMinus, P_Hl, P_Hl, P_GPlus, 2556, check)
      call createCurrent(P_muMinus, P_Hl, P_muPlus, 2392, check)
      call createCurrent(P_WPlus, P_G0, P_Z, P_GMinus, 1265, check)
      call createCurrent(P_HPlus, P_Hh, P_G0, P_HMinus, 2879, check)
      call createCurrent(P_G0, P_Hl, P_HPlus, P_GMinus, 248, check)
      call createCurrent(P_GMinus, P_Hl, P_HPlus, P_Hh, 1304, check)
      call createCurrent(P_GPlus, P_A, P_GMinus, 158, check)
      call createCurrent(P_GMinus, P_HPlus, P_HPlus, P_HMinus, 568, check)
      call createCurrent(P_Hh, P_Ha, P_Z, 1264, check)
      call createCurrent(P_WMinus, P_nu_e, P_ePlus, 914, check)
      call createCurrent(P_HMinus, P_Hl, P_HPlus, P_Ha, 3013, check)
      call createCurrent(P_WMinus, P_GPlus, P_Hh, 1654, check)
      call createCurrent(P_Ha, P_Z, P_WPlus, P_HMinus, 942, check)
      call createCurrent(P_g, P_u, P_uAnti, 2090, check)
      call createCurrent(P_Hl, P_HPlus, P_GMinus, P_G0, 1878, check)
      call createCurrent(P_Hl, P_GMinus, P_GPlus, P_G0, 3410, check)
      call createCurrent(P_eMinus, P_A, P_ePlus, 460, check)
      call createCurrent(P_Hl, P_Hh, P_Hl, P_Hl, 1485, check)
      call createCurrent(P_Hh, P_Hh, P_HMinus, P_HPlus, 789, check)
      call createCurrent(P_HPlus, P_WMinus, P_G0, P_Z, 2788, check)
      call createCurrent(P_A, P_Hh, P_Hh, P_Z, 2946, check)
      call createCurrent(P_Hl, P_GPlus, P_HMinus, P_G0, 468, check)
      call createCurrent(P_A, P_HPlus, P_HMinus, P_A, 1336, check)
      call createCurrent(P_nu_tauAnti, P_Z, P_nu_tau, 1841, check)
      call createCurrent(P_HMinus, P_WPlus, P_Ha, 1766, check)
      call createCurrent(P_A, P_G0, P_Hl, 3470, check)
      call createCurrent(P_Z, P_HMinus, P_WPlus, P_Hl, 1356, check)
      call createCurrent(P_Ha, P_WPlus, P_GMinus, P_A, 3163, check)
      call createCurrent(P_A, P_WPlus, P_HMinus, P_Hl, 919, check)
      call createCurrent(P_GPlus, P_GMinus, P_Z, 1937, check)
      call createCurrent(P_Hl, P_Hh, P_WMinus, P_WPlus, 3523, check)
      call createCurrent(P_g, P_Hl, P_g, P_Hl, 3695, check)
      call createCurrent(P_WMinus, P_GPlus, P_Hl, P_Z, 1149, check)
      call createCurrent(P_HPlus, P_GMinus, P_GMinus, P_HPlus, 1824, check)
      call createCurrent(P_HPlus, P_WMinus, P_Hh, P_Z, 12, check)
      call createCurrent(P_G0, P_GMinus, P_GPlus, P_G0, 701, check)
      call createCurrent(P_A, P_GMinus, P_A, P_GPlus, 2484, check)
      call createCurrent(P_Z, P_GMinus, P_Ha, P_WPlus, 3364, check)
      call createCurrent(P_Z, P_Hh, P_Z, P_Hh, 559, check)
      call createCurrent(P_bAnti, P_Ha, P_b, 1822, check)
      call createCurrent(P_Hl, P_GPlus, P_GMinus, P_Ha, 3320, check)
      call createCurrent(P_sAnti, P_s, P_A, 1385, check)
      call createCurrent(P_G0, P_Hh, P_HPlus, P_HMinus, 3468, check)
      call createCurrent(P_GMinus, P_Hh, P_GPlus, P_Hh, 2495, check)
      call createCurrent(P_muMinus, P_muPlus, P_Ha, 785, check)
      call createCurrent(P_Hl, P_HPlus, P_WMinus, 1017, check)
      call createCurrent(P_Ha, P_GMinus, P_Hl, P_GPlus, 3489, check)
      call createCurrent(P_HMinus, P_G0, P_Hl, P_HPlus, 3531, check)
      call createCurrent(P_GMinus, P_G0, P_HPlus, P_Ha, 2316, check)
      call createCurrent(P_WPlus, P_HMinus, P_Hl, P_Z, 2457, check)
      call createCurrent(P_WMinus, P_A, P_G0, P_HPlus, 2889, check)
      call createCurrent(P_eMinus, P_ePlus, P_Z, 31, check)
      call createCurrent(P_A, P_HPlus, P_Hh, P_WMinus, 2573, check)
      call createCurrent(P_HMinus, P_Hh, P_WPlus, P_Z, 1202, check)
      call createCurrent(P_HMinus, P_GPlus, P_GMinus, P_GPlus, 1595, check)
      call createCurrent(P_GMinus, P_HPlus, P_HMinus, P_HPlus, 202, check)
      call createCurrent(P_WPlus, P_GPlus, P_WMinus, P_GMinus, 1253, check)
      call createCurrent(P_s, P_sAnti, P_Hl, 1961, check)
      call createCurrent(P_G0, P_G0, P_WPlus, P_WMinus, 2490, check)
      call createCurrent(P_Hh, P_Z, P_WMinus, P_HPlus, 67, check)
      call createCurrent(P_GMinus, P_ePlus, P_nu_e, 950, check)
      call createCurrent(P_HPlus, P_WMinus, P_Hh, P_A, 1516, check)
      call createCurrent(P_HMinus, P_HPlus, P_Ha, 3168, check)
      call createCurrent(P_t, P_tAnti, P_Hh, 708, check)
      call createCurrent(P_Ha, P_HMinus, P_GPlus, P_Hl, 1856, check)
      call createCurrent(P_GPlus, P_G0, P_GMinus, 3164, check)
      call createCurrent(P_Z, P_Hl, P_Hh, P_A, 3648, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_WPlus, 1805, check)
      call createCurrent(P_t, P_Ha, P_tAnti, 905, check)
      call createCurrent(P_Hh, P_HPlus, P_WMinus, P_Z, 2695, check)
      call createCurrent(P_ePlus, P_Ha, P_eMinus, 1750, check)
      call createCurrent(P_Hl, P_GMinus, P_Hl, P_HPlus, 1643, check)
      call createCurrent(P_Z, P_Z, P_HPlus, P_GMinus, 3338, check)
      call createCurrent(P_GPlus, P_Ha, P_WMinus, 3572, check)
      call createCurrent(P_WPlus, P_ghAAnti, P_ghWm, 686, check)
      call createCurrent(P_Ha, P_bAnti, P_b, 2551, check)
      call createCurrent(P_HMinus, P_HPlus, P_Hl, 808, check)
      call createCurrent(P_cAnti, P_c, P_g, 1880, check)
      call createCurrent(P_cAnti, P_Ha, P_c, 20, check)
      call createCurrent(P_nu_tauAnti, P_nu_tau, P_A, 3210, check)
      call createCurrent(P_dAnti, P_Hh, P_d, 1090, check)
      call createCurrent(P_Hh, P_WPlus, P_GMinus, 2313, check)
      call createCurrent(P_G0, P_Hl, P_Hl, P_Ha, 912, check)
      call createCurrent(P_G0, P_G0, P_GPlus, P_HMinus, 1936, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghWm, 2518, check)
      call createCurrent(P_nu_e, P_ePlus, P_HMinus, 2105, check)
      call createCurrent(P_HPlus, P_Hl, P_HMinus, P_G0, 3018, check)
      call createCurrent(P_WMinus, P_WPlus, P_g, P_g, 3688, check)
      call createCurrent(P_Hh, P_Hl, P_HMinus, P_GPlus, 183, check)
      call createCurrent(P_Z, P_Ha, 2895, check)
      call createCurrent(P_HPlus, P_WMinus, 2928, check)
      call createCurrent(P_HPlus, P_Z, P_GMinus, P_Z, 2965, check)
      call createCurrent(P_A, P_g, P_A, P_g, 3643, check)
      call createCurrent(P_A, P_A, P_G0, P_Ha, 3697, check)
      call createCurrent(P_Hh, P_HPlus, P_Hh, P_HMinus, 2277, check)
      call createCurrent(P_Hh, P_Hl, P_GPlus, P_HMinus, 2223, check)
      call createCurrent(P_A, P_sAnti, P_s, 1504, check)
      call createCurrent(P_G0, P_GPlus, P_Hh, P_GMinus, 3294, check)
      call createCurrent(P_GMinus, P_Ha, P_GPlus, P_Hl, 3528, check)
      call createCurrent(P_HMinus, P_Ha, P_A, P_WPlus, 86, check)
      call createCurrent(P_Ha, P_GMinus, P_G0, P_HPlus, 833, check)
      call createCurrent(P_GMinus, P_Hl, P_HPlus, P_Ha, 1553, check)
      call createCurrent(P_WPlus, P_HMinus, P_HPlus, P_WMinus, 953, check)
      call createCurrent(P_HPlus, P_WMinus, P_A, P_Hh, 2129, check)
      call createCurrent(P_WPlus, P_Ha, P_GMinus, 2715, check)
      call createCurrent(P_cAnti, P_c, P_Z, 1620, check)
      call createCurrent(P_GMinus, P_HPlus, P_Z, P_Z, 3038, check)
      call createCurrent(P_Ha, P_A, P_Ha, P_Z, 3178, check)
      call createCurrent(P_d, P_dAnti, P_Z, 207, check)
      call createCurrent(P_WMinus, P_Ha, P_A, P_GPlus, 2780, check)
      call createCurrent(P_dAnti, P_Ha, P_d, 737, check)
      call createCurrent(P_GPlus, P_GMinus, P_Ha, P_Hl, 3100, check)
      call createCurrent(P_HMinus, P_tauPlus, P_nu_tau, 101, check)
      call createCurrent(P_Ha, P_GPlus, P_HMinus, P_G0, 2420, check)
      call createCurrent(P_G0, P_G0, P_WMinus, P_WPlus, 2064, check)
      call createCurrent(P_HPlus, P_Ha, P_GMinus, P_Ha, 1388, check)
      call createCurrent(P_GPlus, P_GMinus, P_HPlus, P_HMinus, 2671, check)
      call createCurrent(P_g, P_g, P_Hh, 3856, check)
      call createCurrent(P_G0, P_Hh, P_G0, 2693, check)
      call createCurrent(P_Hh, P_d, P_dAnti, 1165, check)
      call createCurrent(P_G0, P_WMinus, P_HPlus, P_Z, 3208, check)
      call createCurrent(P_GMinus, P_GPlus, P_Ha, P_Hh, 3297, check)
      call createCurrent(P_HPlus, P_WPlus, P_WMinus, P_HMinus, 56, check)
      call createCurrent(P_Ha, P_WMinus, P_A, P_GPlus, 2736, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghAAnti, 2014, check)
      call createCurrent(P_Ha, P_GMinus, P_G0, P_GPlus, 2379, check)
      call createCurrent(P_cAnti, P_s, P_GPlus, 1520, check)
      call createCurrent(P_G0, P_A, P_GMinus, P_WPlus, 424, check)
      call createCurrent(P_Z, P_A, P_g, P_g, 3713, check)
      call createCurrent(P_u, P_Hl, P_uAnti, 130, check)
      call createCurrent(P_A, P_HMinus, P_GPlus, 2807, check)
      call createCurrent(P_Z, P_HPlus, P_WMinus, P_Hh, 1414, check)
      call createCurrent(P_HPlus, P_Z, P_GMinus, 2871, check)
      call createCurrent(P_GMinus, P_G0, P_GPlus, 2862, check)
      call createCurrent(P_HPlus, P_g, P_HMinus, P_g, 3717, check)
      call createCurrent(P_Z, P_GMinus, P_A, P_GPlus, 1630, check)
      call createCurrent(P_GMinus, P_u, P_dAnti, 1274, check)
      call createCurrent(P_Ha, P_Hh, P_Hl, P_G0, 2171, check)
      call createCurrent(P_Ha, P_HPlus, P_Hl, P_GMinus, 1997, check)
      call createCurrent(P_GMinus, P_Hh, P_GPlus, P_Ha, 2783, check)
      call createCurrent(P_b, P_bAnti, P_A, 2294, check)
      call createCurrent(P_Hl, P_Ha, P_G0, P_Hl, 2686, check)
      call createCurrent(P_Z, P_ghWpAnti, P_ghWp, 865, check)
      call createCurrent(P_Z, P_Ha, P_HPlus, P_WMinus, 1970, check)
      call createCurrent(P_Ha, P_A, P_WMinus, P_GPlus, 2969, check)
      call createCurrent(P_Hh, P_Z, P_GMinus, P_WPlus, 2113, check)
      call createCurrent(P_Ha, P_G0, P_HPlus, P_GMinus, 2381, check)
      call createCurrent(P_WMinus, P_G0, P_WPlus, P_G0, 742, check)
      call createCurrent(P_A, P_Z, P_Hl, 3493, check)
      call createCurrent(P_Hh, P_Z, P_Hl, P_Z, 3374, check)
      call createCurrent(P_HMinus, P_Z, P_Z, P_GPlus, 3049, check)
      call createCurrent(P_Ha, P_HMinus, P_WPlus, P_Z, 2593, check)
      call createCurrent(P_Hl, P_Z, P_Z, P_Hh, 3428, check)
      call createCurrent(P_A, P_A, P_HMinus, P_GPlus, 3363, check)
      call createCurrent(P_WPlus, P_Z, P_WMinus, P_Z, 1650, check)
      call createCurrent(P_HPlus, P_HMinus, P_Ha, P_Hh, 3534, check)
      call createCurrent(P_sAnti, P_G0, P_s, 1920, check)
      call createCurrent(P_A, P_Z, P_HPlus, P_GMinus, 2820, check)
      call createCurrent(P_ghGAnti, P_ghG, P_g, 2445, check)
      call createCurrent(P_HPlus, P_ghWpAnti, P_ghA, 3380, check)
      call createCurrent(P_Ha, P_tauMinus, P_tauPlus, 1127, check)
      call createCurrent(P_Hh, P_G0, P_Z, 1176, check)
      call createCurrent(P_Hl, P_WMinus, P_GPlus, P_A, 2236, check)
      call createCurrent(P_GMinus, P_HPlus, P_Ha, P_Ha, 2326, check)
      call createCurrent(P_muMinus, P_Z, P_muPlus, 146, check)
      call createCurrent(P_HPlus, P_GMinus, P_Hl, P_G0, 1771, check)
      call createCurrent(P_GMinus, P_Hh, P_WPlus, P_Z, 1367, check)
      call createCurrent(P_Ha, P_WMinus, P_HPlus, P_Z, 1933, check)
      call createCurrent(P_Hl, P_g, P_Hl, P_g, 3885, check)
      call createCurrent(P_GPlus, P_Ha, P_HMinus, P_Ha, 2126, check)
      call createCurrent(P_Hh, P_Hh, P_Hh, P_Hl, 632, check)
      call createCurrent(P_A, P_G0, 3205, check)
      call createCurrent(P_G0, P_Hh, P_HMinus, P_GPlus, 1960, check)
      call createCurrent(P_GPlus, P_WMinus, P_HMinus, P_WPlus, 3409, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghZ, 1368, check)
      call createCurrent(P_A, P_Z, P_Hh, P_Hh, 3290, check)
      call createCurrent(P_A, P_Hh, P_GPlus, P_WMinus, 1797, check)
      call createCurrent(P_Z, P_t, P_tAnti, 1919, check)
      call createCurrent(P_Hl, P_WMinus, P_WPlus, P_Hh, 3011, check)
      call createCurrent(P_WMinus, P_GPlus, P_GMinus, P_WPlus, 210, check)
      call createCurrent(P_GMinus, P_G0, P_Hl, P_HPlus, 918, check)
      call createCurrent(P_Ha, P_WPlus, P_Z, P_HMinus, 2372, check)
      call createCurrent(P_Hl, P_Hh, P_Hh, 1374, check)
      call createCurrent(P_HPlus, P_g, P_GMinus, P_g, 3818, check)
      call createCurrent(P_g, P_g, P_g, P_g, 723, check)
      call createCurrent(P_HMinus, P_Z, P_A, P_GPlus, 2861, check)
      call createCurrent(P_G0, P_G0, P_Hh, P_Ha, 3711, check)
      call createCurrent(P_tAnti, P_b, P_WPlus, 2475, check)
      call createCurrent(P_G0, P_Hh, P_G0, P_Hl, 1728, check)
      call createCurrent(P_WMinus, P_HPlus, P_Hh, 1187, check)
      call createCurrent(P_GPlus, P_GMinus, P_HMinus, P_HPlus, 265, check)
      call createCurrent(P_GMinus, P_A, P_Z, P_HPlus, 3417, check)
      call createCurrent(P_HMinus, P_A, P_Z, P_HPlus, 2147, check)
      call createCurrent(P_nu_eAnti, P_eMinus, P_WPlus, 310, check)
      call createCurrent(P_Z, P_G0, P_HMinus, P_WPlus, 2993, check)
      call createCurrent(P_bAnti, P_b, P_Hh, 1864, check)
      call createCurrent(P_HPlus, P_Ha, P_GMinus, P_G0, 1813, check)
      call createCurrent(P_Hh, P_GMinus, P_Hh, P_GPlus, 1674, check)
      call createCurrent(P_HPlus, P_WPlus, P_HMinus, P_WMinus, 1994, check)
      call createCurrent(P_WMinus, P_Hl, P_HPlus, 1648, check)
      call createCurrent(P_Hh, P_GPlus, P_HMinus, P_G0, 1315, check)
      call createCurrent(P_A, P_GPlus, P_Z, P_GMinus, 2084, check)
      call createCurrent(P_HMinus, P_GPlus, P_Hh, P_G0, 758, check)
      call createCurrent(P_G0, P_HMinus, P_GPlus, P_Ha, 515, check)
      call createCurrent(P_Ha, P_G0, P_G0, P_Hl, 3723, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_ghWp, 1044, check)
      call createCurrent(P_A, P_Z, P_HMinus, P_GPlus, 3322, check)
      call createCurrent(P_GPlus, P_HMinus, P_A, P_A, 2992, check)
      call createCurrent(P_Hh, P_WMinus, P_Hl, P_WPlus, 2750, check)
      call createCurrent(P_HPlus, P_GMinus, P_Ha, P_Hl, 298, check)
      call createCurrent(P_G0, P_A, P_A, P_Ha, 3670, check)
      call createCurrent(P_t, P_WMinus, P_bAnti, 2337, check)
      call createCurrent(P_Hl, P_GPlus, P_GMinus, P_Hh, 1406, check)
      call createCurrent(P_GPlus, P_nu_muAnti, P_muMinus, 1992, check)
      call createCurrent(P_Hl, P_c, P_cAnti, 2022, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, P_Hl, 387, check)
      call createCurrent(P_b, P_bAnti, P_Hl, 1065, check)
      call createCurrent(P_GMinus, P_Hl, P_GPlus, P_G0, 3398, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, P_Hl, 1622, check)
      call createCurrent(P_t, P_tAnti, P_Ha, 373, check)
      call createCurrent(P_HMinus, P_Ha, P_GPlus, P_G0, 2675, check)
      call createCurrent(P_GPlus, P_GMinus, P_A, P_A, 2226, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghAAnti, 987, check)
      call createCurrent(P_HMinus, P_A, P_A, P_HPlus, 26, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, P_G0, 1351, check)
      call createCurrent(P_HPlus, P_GMinus, P_Z, P_A, 3282, check)
      call createCurrent(P_g, P_g, P_WMinus, P_WPlus, 3822, check)
      call createCurrent(P_A, P_HPlus, P_Hl, P_WMinus, 1793, check)
      call createCurrent(P_A, P_WMinus, P_Hl, P_HPlus, 1851, check)
      call createCurrent(P_Hh, P_HPlus, P_GMinus, P_G0, 1607, check)
      call createCurrent(P_Hl, P_GPlus, P_Hh, P_HMinus, 2564, check)
      call createCurrent(P_A, P_GPlus, P_GMinus, 467, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, 1362, check)
      call createCurrent(P_bAnti, P_A, P_b, 604, check)
      call createCurrent(P_Hh, P_Ha, P_HPlus, P_GMinus, 1008, check)
      call createCurrent(P_HMinus, P_GPlus, P_Ha, P_G0, 2114, check)
      call createCurrent(P_HMinus, P_ePlus, P_nu_e, 814, check)
      call createCurrent(P_A, P_A, P_A, P_Z, 3646, check)
      call createCurrent(P_Hl, P_Ha, P_HPlus, P_GMinus, 2479, check)
      call createCurrent(P_G0, P_t, P_tAnti, 817, check)
      call createCurrent(P_Hl, P_HMinus, P_Hh, P_GPlus, 1984, check)
      call createCurrent(P_Hl, P_Hh, P_G0, P_G0, 344, check)
      call createCurrent(P_tAnti, P_Hl, P_t, 1550, check)
      call createCurrent(P_cAnti, P_c, P_Hl, 2647, check)
      call createCurrent(P_bAnti, P_g, P_b, 1350, check)
      call createCurrent(P_GMinus, P_Hl, P_GPlus, 2052, check)
      call createCurrent(P_HMinus, P_Ha, P_GPlus, P_Hh, 1752, check)
      call createCurrent(P_HMinus, P_A, P_HPlus, P_Z, 1925, check)
      call createCurrent(P_Hh, P_GPlus, P_Hl, P_GMinus, 2425, check)
      call createCurrent(P_GMinus, P_GMinus, P_HPlus, P_GPlus, 577, check)
      call createCurrent(P_GMinus, P_A, P_GPlus, 1363, check)
      call createCurrent(P_WPlus, P_HMinus, P_A, P_G0, 3271, check)
      call createCurrent(P_GPlus, P_WMinus, P_Ha, P_Z, 3558, check)
      call createCurrent(P_GMinus, P_A, P_GPlus, P_A, 2008, check)
      call createCurrent(P_HMinus, P_G0, P_WPlus, P_Z, 3415, check)
      call createCurrent(P_HMinus, P_Hl, P_HPlus, 1228, check)
      call createCurrent(P_HPlus, P_A, P_HMinus, P_Z, 230, check)
      call createCurrent(P_Ha, P_Hl, P_G0, P_Hl, 1768, check)
      call createCurrent(P_WPlus, P_Hh, P_Hh, P_WMinus, 224, check)
      call createCurrent(P_Z, P_HPlus, P_HMinus, 1558, check)
      call createCurrent(P_Z, P_c, P_cAnti, 1524, check)
      call createCurrent(P_Hh, P_HMinus, P_Ha, P_HPlus, 3067, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghA, 1238, check)
      call createCurrent(P_GMinus, P_GPlus, P_Hl, 1705, check)
      call createCurrent(P_Ha, P_Hh, P_G0, 407, check)
      call createCurrent(P_GPlus, P_Z, P_A, P_GMinus, 629, check)
      call createCurrent(P_g, P_uAnti, P_u, 2347, check)
      call createCurrent(P_Ha, P_Z, P_GMinus, P_WPlus, 3350, check)
      call createCurrent(P_GMinus, P_HPlus, P_G0, P_Ha, 2314, check)
      call createCurrent(P_Ha, P_Hl, P_A, 2779, check)
      call createCurrent(P_HMinus, P_Ha, P_Hl, P_GPlus, 295, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, P_G0, 2165, check)
      call createCurrent(P_A, P_Hl, P_WPlus, P_GMinus, 2590, check)
      call createCurrent(P_Ha, P_HPlus, P_HMinus, 3206, check)
      call createCurrent(P_HPlus, P_Hl, P_GMinus, P_Hl, 859, check)
      call createCurrent(P_G0, P_Hl, P_A, 3511, check)
      call createCurrent(P_muMinus, P_G0, P_muPlus, 446, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, P_Hl, 358, check)
      call createCurrent(P_GPlus, P_HMinus, P_G0, P_G0, 2621, check)
      call createCurrent(P_HMinus, P_GPlus, P_A, 2988, check)
      call createCurrent(P_WMinus, P_A, P_Ha, P_HPlus, 2319, check)
      call createCurrent(P_nu_mu, P_GMinus, P_muPlus, 1763, check)
      call createCurrent(P_A, P_G0, P_Ha, P_A, 3700, check)
      call createCurrent(P_g, P_GMinus, P_HPlus, P_g, 3728, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_WMinus, 2694, check)
      call createCurrent(P_G0, P_Z, P_GMinus, P_WPlus, 2139, check)
      call createCurrent(P_HMinus, P_Hl, P_WPlus, 1263, check)
      call createCurrent(P_GMinus, P_G0, P_GPlus, P_Ha, 2704, check)
      call createCurrent(P_G0, P_Ha, P_A, P_Z, 3618, check)
      call createCurrent(P_tauMinus, P_Hl, P_tauPlus, 623, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_WPlus, 585, check)
      call createCurrent(P_Hh, P_bAnti, P_b, 386, check)
      call createCurrent(P_Ha, P_HPlus, P_Hh, P_GMinus, 1298, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_G0, 2523, check)
      call createCurrent(P_Hh, P_Z, P_Z, P_Hh, 661, check)
      call createCurrent(P_Hh, P_Hh, P_Z, P_A, 3047, check)
      call createCurrent(P_HMinus, P_WPlus, P_Ha, P_Z, 2613, check)
      call createCurrent(P_HPlus, P_GMinus, P_WMinus, P_WPlus, 3050, check)
      call createCurrent(P_WMinus, P_HPlus, P_Z, P_Hl, 1634, check)
      call createCurrent(P_muPlus, P_Z, P_muMinus, 1697, check)
      call createCurrent(P_Hh, P_Ha, P_GPlus, P_GMinus, 3230, check)
      call createCurrent(P_Hh, P_Hh, P_G0, P_Ha, 617, check)
      call createCurrent(P_Ha, P_HMinus, P_WPlus, 1432, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghZ, 2025, check)
      call createCurrent(P_A, P_A, P_Z, P_A, 3861, check)
      call createCurrent(P_HPlus, P_HMinus, P_Hl, P_Ha, 2866, check)
      call createCurrent(P_Hh, P_HMinus, P_WPlus, 266, check)
      call createCurrent(P_Ha, P_Ha, P_g, P_g, 3876, check)
      call createCurrent(P_G0, P_G0, P_Ha, P_Ha, 116, check)
      call createCurrent(P_Ha, P_Z, P_A, P_G0, 3629, check)
      call createCurrent(P_g, P_WMinus, P_WPlus, P_g, 3672, check)
      call createCurrent(P_Z, P_Hh, P_HMinus, P_WPlus, 365, check)
      call createCurrent(P_Hl, P_GMinus, P_WPlus, P_Z, 997, check)
      call createCurrent(P_d, P_Hh, P_dAnti, 1926, check)
      call createCurrent(P_Ha, P_cAnti, P_c, 2415, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Hh, 836, check)
      call createCurrent(P_HMinus, P_GPlus, P_A, P_Z, 3413, check)
      call createCurrent(P_Hh, P_Hh, P_g, P_g, 3857, check)
      call createCurrent(P_WMinus, P_WPlus, P_Ha, P_Ha, 882, check)
      call createCurrent(P_HPlus, P_Ha, P_Hh, P_HMinus, 3040, check)
      call createCurrent(P_HPlus, P_Ha, P_HMinus, 3292, check)
      call createCurrent(P_Z, P_A, P_Z, P_A, 3634, check)
      call createCurrent(P_HMinus, P_GPlus, P_GMinus, P_HPlus, 2288, check)
      call createCurrent(P_Hl, P_Hl, P_Hl, P_Hl, 999, check)
      call createCurrent(P_WPlus, P_WMinus, P_Ha, P_Ha, 1332, check)
      call createCurrent(P_HPlus, P_Hl, P_WMinus, P_Z, 878, check)
      call createCurrent(P_A, P_Hl, P_Hl, P_Z, 3261, check)
      call createCurrent(P_Z, P_cAnti, P_c, 2594, check)
      call createCurrent(P_Hl, P_ghZ, P_ghZAnti, 1060, check)
      call createCurrent(P_muPlus, P_G0, P_muMinus, 2249, check)
      call createCurrent(P_HPlus, P_G0, P_HMinus, P_Ha, 2265, check)
      call createCurrent(P_nu_eAnti, P_A, P_nu_e, 3192, check)
      call createCurrent(P_nu_tauAnti, P_WPlus, P_tauMinus, 1719, check)
      call createCurrent(P_Hl, P_G0, P_G0, P_Ha, 3809, check)
      call createCurrent(P_HPlus, P_HPlus, P_GMinus, P_HMinus, 133, check)
      call createCurrent(P_GMinus, P_HPlus, P_Ha, P_Hh, 935, check)
      call createCurrent(P_muMinus, P_muPlus, P_Hh, 1729, check)
      call createCurrent(P_HMinus, P_GPlus, P_HMinus, P_HPlus, 1463, check)
      call createCurrent(P_b, P_g, P_bAnti, 2086, check)
      call createCurrent(P_WMinus, P_HPlus, 3055, check)
      call createCurrent(P_A, P_A, P_Hl, P_Hh, 3613, check)
      call createCurrent(P_Hh, P_HPlus, P_GMinus, P_Hl, 2002, check)
      call createCurrent(P_WMinus, P_HPlus, P_Ha, 795, check)
      call createCurrent(P_Z, P_Hh, P_G0, 2325, check)
      call createCurrent(P_g, P_A, P_g, P_A, 3808, check)
      call createCurrent(P_GMinus, P_Hh, P_HPlus, 589, check)
      call createCurrent(P_G0, P_HPlus, P_Hl, P_HMinus, 3433, check)
      call createCurrent(P_Z, P_Z, P_Hh, 402, check)
      call createCurrent(P_GPlus, P_Ha, P_WMinus, P_Z, 3107, check)
      call createCurrent(P_G0, P_GMinus, P_HPlus, P_G0, 13, check)
      call createCurrent(P_bAnti, P_b, P_Ha, 1302, check)
      call createCurrent(P_s, P_cAnti, P_GPlus, 2603, check)
      call createCurrent(P_Hl, P_HPlus, P_HMinus, 2124, check)
      call createCurrent(P_cAnti, P_c, P_A, 920, check)
      call createCurrent(P_WMinus, P_Hl, P_A, P_GPlus, 428, check)
      call createCurrent(P_HPlus, P_WMinus, P_Hh, 1548, check)
      call createCurrent(P_HMinus, P_WPlus, P_A, P_Ha, 2546, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, P_Hh, 1825, check)
      call createCurrent(P_Hh, P_WMinus, P_Hh, P_WPlus, 938, check)
      call createCurrent(P_A, P_GMinus, P_Z, P_HPlus, 3091, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghAAnti, 1052, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, 1796, check)
      call createCurrent(P_Hl, P_Hl, P_A, P_A, 3828, check)
      call createCurrent(P_HPlus, P_HMinus, P_HMinus, P_GPlus, 103, check)
      call createCurrent(P_HMinus, P_G0, P_G0, P_HPlus, 1808, check)
      call createCurrent(P_Hl, P_GMinus, P_HPlus, 1498, check)
      call createCurrent(P_HPlus, P_G0, P_GMinus, 2188, check)
      call createCurrent(P_Ha, P_WPlus, P_A, P_GMinus, 3427, check)
      call createCurrent(P_tauMinus, P_G0, P_tauPlus, 752, check)
      call createCurrent(P_HPlus, P_WMinus, P_G0, P_A, 2964, check)
      call createCurrent(P_HPlus, P_GMinus, P_Ha, P_G0, 1490, check)
      call createCurrent(P_Hl, P_Hl, P_HMinus, P_GPlus, 2302, check)
      call createCurrent(P_Hh, P_WPlus, P_HMinus, P_Z, 2522, check)
      call createCurrent(P_G0, P_GMinus, P_HPlus, P_Hl, 2489, check)
      call createCurrent(P_HPlus, P_HMinus, P_G0, P_G0, 1618, check)
      call createCurrent(P_G0, P_GMinus, P_GPlus, 3576, check)
      call createCurrent(P_G0, P_ghWpAnti, P_ghWp, 507, check)
      call createCurrent(P_GMinus, P_nu_e, P_ePlus, 127, check)
      call createCurrent(P_HMinus, P_A, P_WPlus, 2599, check)
      call createCurrent(P_WPlus, P_HMinus, P_WMinus, P_HPlus, 1128, check)
      call createCurrent(P_GPlus, P_HMinus, P_Hl, P_Hh, 2334, check)
      call createCurrent(P_Hh, P_tauPlus, P_tauMinus, 1959, check)
      call createCurrent(P_Z, P_Z, P_Hh, P_Hl, 2727, check)
      call createCurrent(P_HPlus, P_HMinus, P_Hh, P_Ha, 2954, check)
      call createCurrent(P_Hl, P_Hh, P_Hl, P_Hh, 1953, check)
      call createCurrent(P_WMinus, P_Ha, P_Ha, P_WPlus, 786, check)
      call createCurrent(P_WMinus, P_ePlus, P_nu_e, 954, check)
      call createCurrent(P_HPlus, P_Hl, P_HMinus, P_Hh, 540, check)
      call createCurrent(P_GMinus, P_Ha, P_HPlus, P_Ha, 147, check)
      call createCurrent(P_Hl, P_WMinus, P_HPlus, 875, check)
      call createCurrent(P_WPlus, P_Hh, P_WMinus, P_Hh, 503, check)
      call createCurrent(P_GMinus, P_HPlus, P_A, 3472, check)
      call createCurrent(P_G0, P_Ha, P_GMinus, P_GPlus, 1865, check)
      call createCurrent(P_g, P_g, P_GPlus, P_HMinus, 3830, check)
      call createCurrent(P_HMinus, P_A, P_GPlus, 3286, check)
      call createCurrent(P_t, P_bAnti, P_HMinus, 75, check)
      call createCurrent(P_GMinus, P_A, P_HPlus, P_A, 2756, check)
      call createCurrent(P_Ha, P_HPlus, P_HMinus, P_Hh, 3211, check)
      call createCurrent(P_GMinus, P_GPlus, P_HPlus, P_HMinus, 361, check)
      call createCurrent(P_Ha, P_A, P_WPlus, P_GMinus, 3587, check)
      call createCurrent(P_Z, P_G0, P_Hh, 1231, check)
      call createCurrent(P_HPlus, P_GMinus, P_G0, P_Hl, 1026, check)
      call createCurrent(P_HPlus, P_HMinus, P_G0, P_Hl, 3092, check)
      call createCurrent(P_WPlus, P_Z, P_Ha, P_GMinus, 2903, check)
      call createCurrent(P_Hh, P_GPlus, P_Hh, P_GMinus, 1770, check)
      call createCurrent(P_Hl, P_Hh, P_G0, P_Ha, 47, check)
      call createCurrent(P_g, P_GMinus, P_g, P_HPlus, 3777, check)
      call createCurrent(P_Hl, P_WMinus, P_Hh, P_WPlus, 3411, check)
      call createCurrent(P_Z, P_A, P_HPlus, P_GMinus, 2915, check)
      call createCurrent(P_HMinus, P_Hh, P_Z, P_WPlus, 643, check)
      call createCurrent(P_A, P_G0, P_A, P_Ha, 3874, check)
      call createCurrent(P_cAnti, P_GPlus, P_s, 2049, check)
      call createCurrent(P_Hh, P_Z, P_Ha, 611, check)
      call createCurrent(P_uAnti, P_u, P_A, 1021, check)
      call createCurrent(P_tAnti, P_G0, P_t, 940, check)
      call createCurrent(P_WPlus, P_A, P_G0, P_HMinus, 3108, check)
      call createCurrent(P_ghWpAnti, P_HPlus, P_ghZ, 3137, check)
      call createCurrent(P_HPlus, P_HMinus, P_G0, P_Hh, 2956, check)
      call createCurrent(P_Hl, P_ghWmAnti, P_ghWm, 2462, check)
      call createCurrent(P_GPlus, P_Hh, P_HMinus, P_G0, 2470, check)
      call createCurrent(P_muPlus, P_nu_mu, P_GMinus, 1041, check)
      call createCurrent(P_Ha, P_WMinus, P_Ha, P_WPlus, 1941, check)
      call createCurrent(P_Z, P_nu_eAnti, P_nu_e, 2306, check)
      call createCurrent(P_WMinus, P_HPlus, P_A, P_G0, 3008, check)
      call createCurrent(P_WMinus, P_WPlus, P_Hh, P_Hh, 1221, check)
      call createCurrent(P_HPlus, P_A, P_WMinus, 929, check)
      call createCurrent(P_tAnti, P_Z, P_t, 2232, check)
      call createCurrent(P_Hh, P_Hh, 2791, check)
      call createCurrent(P_Hh, P_G0, P_HPlus, P_GMinus, 516, check)
      call createCurrent(P_HPlus, P_GMinus, P_G0, P_Hh, 1467, check)
      call createCurrent(P_G0, P_Z, P_Z, P_G0, 973, check)
      call createCurrent(P_Hh, P_muMinus, P_muPlus, 2246, check)
      call createCurrent(P_Ha, P_HMinus, P_HPlus, P_Ha, 1913, check)
      call createCurrent(P_GPlus, P_Ha, P_Hl, P_HMinus, 1262, check)
      call createCurrent(P_g, P_G0, P_Ha, P_g, 3855, check)
      call createCurrent(P_WMinus, P_Hh, P_Z, P_GPlus, 16, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Hh, 24, check)
      call createCurrent(P_HMinus, P_GPlus, P_Ha, P_Hl, 1333, check)
      call createCurrent(P_g, P_g, P_A, P_Z, 3825, check)
      call createCurrent(P_Z, P_Ha, P_WMinus, P_GPlus, 3400, check)
      call createCurrent(P_c, P_cAnti, P_G0, 1091, check)
      call createCurrent(P_GPlus, P_Ha, P_GMinus, P_Hh, 3538, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_Z, 1396, check)
      call createCurrent(P_G0, P_WPlus, P_WMinus, P_G0, 2550, check)
      call createCurrent(P_Hh, P_Hl, P_GMinus, P_GPlus, 1916, check)
      call createCurrent(P_b, P_bAnti, P_g, 1474, check)
      call createCurrent(P_Hl, P_HPlus, P_Hh, P_HMinus, 2511, check)
      call createCurrent(P_Z, P_WMinus, P_Hh, P_GPlus, 1163, check)
      call createCurrent(P_nu_mu, P_WMinus, P_muPlus, 1733, check)
      call createCurrent(P_Ha, P_G0, P_WPlus, P_WMinus, 2860, check)
      call createCurrent(P_GMinus, P_HPlus, P_GPlus, P_GMinus, 1189, check)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_WPlus, 69, check)
      call createCurrent(P_A, P_A, P_WMinus, P_WPlus, 1443, check)
      call createCurrent(P_G0, P_WPlus, P_GMinus, P_Z, 1166, check)
      call createCurrent(P_Hh, P_Hh, P_Z, P_Z, 2395, check)
      call createCurrent(P_Hl, P_WPlus, P_Hh, P_WMinus, 3548, check)
      call createCurrent(P_A, P_Z, P_Hh, P_Hl, 3630, check)
      call createCurrent(P_A, P_WPlus, P_Hl, P_GMinus, 1963, check)
      call createCurrent(P_g, P_A, P_A, P_g, 3868, check)
      call createCurrent(P_Ha, P_g, P_g, P_Ha, 3721, check)
      call createCurrent(P_G0, P_Ha, P_G0, 3704, check)
      call createCurrent(P_sAnti, P_Z, P_s, 2175, check)
      call createCurrent(P_Hh, P_G0, P_Ha, P_Hh, 239, check)
      call createCurrent(P_Ha, P_Ha, P_Hh, P_Hl, 863, check)
      call createCurrent(P_Hl, P_G0, P_Hh, P_G0, 1294, check)
      call createCurrent(P_Hl, P_GMinus, P_HPlus, P_Hl, 2401, check)
      call createCurrent(P_Hh, P_GMinus, P_GPlus, 1327, check)
      call createCurrent(P_G0, P_g, P_g, P_G0, 3770, check)
      call createCurrent(P_g, P_WPlus, P_WMinus, P_g, 3622, check)
      call createCurrent(P_G0, P_Ha, P_Hh, 2411, check)
      call createCurrent(P_Z, P_muMinus, P_muPlus, 1586, check)
      call createCurrent(P_Hl, P_HMinus, P_WPlus, P_A, 609, check)
      call createCurrent(P_Z, P_Ha, P_Z, P_G0, 3436, check)
      call createCurrent(P_WPlus, P_Z, P_Hh, P_GMinus, 1053, check)
      call createCurrent(P_HPlus, P_Hh, P_Ha, P_GMinus, 493, check)
      call createCurrent(P_WMinus, P_Z, P_HPlus, 109, check)
      call createCurrent(P_b, P_tAnti, P_GPlus, 1484, check)
      call createCurrent(P_HMinus, P_HMinus, P_GPlus, P_GPlus, 1653, check)
      call createCurrent(P_GMinus, P_WPlus, P_G0, P_A, 772, check)
      call createCurrent(P_A, P_WPlus, P_HMinus, P_G0, 2873, check)
      call createCurrent(P_WMinus, P_G0, P_A, P_HPlus, 3422, check)
      call createCurrent(P_dAnti, P_A, P_d, 1724, check)
      call createCurrent(P_Hl, P_G0, P_A, 3277, check)
      call createCurrent(P_HMinus, P_GPlus, P_A, P_A, 2901, check)
      call createCurrent(P_Z, P_WPlus, P_HMinus, 2685, check)
      call createCurrent(P_GPlus, P_WMinus, 3465, check)
      call createCurrent(P_Ha, P_WMinus, P_Z, P_HPlus, 582, check)
      call createCurrent(P_Z, P_tAnti, P_t, 1489, check)
      call createCurrent(P_Ha, P_A, P_Z, P_G0, 3788, check)
      call createCurrent(P_muPlus, P_muMinus, P_Hl, 2239, check)
      call createCurrent(P_Ha, P_GMinus, P_A, P_WPlus, 2859, check)
      call createCurrent(P_tauMinus, P_GPlus, P_nu_tauAnti, 2185, check)
      call createCurrent(P_Z, P_G0, P_WPlus, P_GMinus, 306, check)
      call createCurrent(P_g, P_g, P_Hl, P_Hh, 3616, check)
      call createCurrent(P_A, P_A, P_Z, P_Z, 3707, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, 1979, check)
      call createCurrent(P_GPlus, P_WMinus, P_G0, 1629, check)
      call createCurrent(P_A, P_Hl, P_WMinus, P_GPlus, 1492, check)
      call createCurrent(P_Z, P_Ha, P_G0, P_Z, 3020, check)
      call createCurrent(P_Hh, P_Ha, P_HMinus, P_HPlus, 2706, check)
      call createCurrent(P_s, P_sAnti, 3522, check)
      call createCurrent(P_G0, P_G0, P_Hl, 2079, check)
      call createCurrent(P_HMinus, P_Z, P_Hl, P_WPlus, 404, check)
      call createCurrent(P_dAnti, P_d, P_Ha, 2557, check)
      call createCurrent(P_GPlus, P_G0, P_GMinus, P_Ha, 1096, check)
      call createCurrent(P_Ha, P_HPlus, P_A, P_WMinus, 118, check)
      call createCurrent(P_Z, P_Z, P_GMinus, P_HPlus, 3310, check)
      call createCurrent(P_WMinus, P_GPlus, P_Hl, 2005, check)
      call createCurrent(P_HMinus, P_HPlus, P_HPlus, P_HMinus, 1664, check)
      call createCurrent(P_u, P_dAnti, P_GMinus, 2567, check)
      call createCurrent(P_HPlus, P_Hh, P_GMinus, P_Hl, 1969, check)
      call createCurrent(P_GMinus, P_GPlus, P_Z, P_Z, 1097, check)
      call createCurrent(P_A, P_Ha, P_Z, P_G0, 3591, check)
      call createCurrent(P_Ha, P_Hh, P_Hh, P_Ha, 705, check)
      call createCurrent(P_Hl, P_Ha, P_Hl, P_G0, 23, check)
      call createCurrent(P_WMinus, P_Z, P_G0, P_HPlus, 2719, check)
      call createCurrent(P_GMinus, P_Hl, P_HPlus, P_G0, 1057, check)
      call createCurrent(P_g, P_G0, P_g, P_G0, 3866, check)
      call createCurrent(P_WMinus, P_HMinus, P_GPlus, P_WPlus, 3201, check)
      call createCurrent(P_GMinus, P_A, P_A, P_HPlus, 3276, check)
      call createCurrent(P_GPlus, P_HMinus, P_GMinus, P_HPlus, 332, check)
      call createCurrent(P_Hl, P_A, P_GMinus, P_WPlus, 762, check)
      call createCurrent(P_WPlus, P_GMinus, P_G0, 2460, check)
      call createCurrent(P_uAnti, P_u, P_Z, 1142, check)
      call createCurrent(P_Z, P_G0, P_A, P_Ha, 3813, check)
      call createCurrent(P_HMinus, P_ghZAnti, P_ghWp, 2892, check)
      call createCurrent(P_WPlus, P_HMinus, P_A, 123, check)
      call createCurrent(P_Ha, P_Ha, P_Hl, P_Hl, 1349, check)
      call createCurrent(P_GPlus, P_HMinus, 2878, check)
      call createCurrent(P_GMinus, P_G0, P_GPlus, P_G0, 390, check)
      call createCurrent(P_HPlus, P_G0, P_Hl, P_HMinus, 3181, check)
      call createCurrent(P_Ha, P_G0, 2842, check)
      call createCurrent(P_Z, P_Hl, P_Hh, P_Z, 3394, check)
      call createCurrent(P_sAnti, P_c, P_WMinus, 2077, check)
      call createCurrent(P_GMinus, P_HPlus, 2875, check)
      call createCurrent(P_WPlus, P_Hl, P_Hh, P_WMinus, 3341, check)
      call createCurrent(P_bAnti, P_t, P_GMinus, 253, check)
      call createCurrent(P_GMinus, P_Ha, P_HPlus, P_Hh, 2474, check)
      call createCurrent(P_G0, P_HPlus, P_WMinus, P_Z, 3305, check)
      call createCurrent(P_Ha, P_WPlus, P_Z, P_GMinus, 3575, check)
      call createCurrent(P_GMinus, P_Ha, P_Hl, P_GPlus, 2793, check)
      call createCurrent(P_Hl, P_Hh, P_Ha, P_G0, 2454, check)
      call createCurrent(P_G0, P_Z, P_Ha, P_A, 3784, check)
      call createCurrent(P_c, P_cAnti, P_g, 1040, check)
      call createCurrent(P_GPlus, P_Hl, P_WMinus, 1681, check)
      call createCurrent(P_HPlus, P_A, P_WMinus, P_Hl, 1063, check)
      call createCurrent(P_cAnti, P_c, P_G0, 693, check)
      call createCurrent(P_G0, P_G0, 2986, check)
      call createCurrent(P_Z, P_GMinus, P_G0, P_WPlus, 1945, check)
      call createCurrent(P_A, P_Hh, P_WMinus, P_GPlus, 1845, check)
      call createCurrent(P_HMinus, P_Ha, P_WPlus, 2291, check)
      call createCurrent(P_Ha, P_HPlus, P_HMinus, P_Ha, 2024, check)
      call createCurrent(P_WMinus, P_bAnti, P_t, 1271, check)
      call createCurrent(P_nu_tau, P_HMinus, P_tauPlus, 1827, check)
      call createCurrent(P_Hh, P_WPlus, P_A, P_HMinus, 1713, check)
      call createCurrent(P_A, P_HPlus, P_Z, P_GMinus, 3074, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, P_G0, 434, check)
      call createCurrent(P_G0, P_Z, P_A, P_Ha, 3682, check)
      call createCurrent(P_GPlus, P_Ha, P_G0, P_GMinus, 1569, check)
      call createCurrent(P_GMinus, P_Z, P_Hh, P_WPlus, 1409, check)
      call createCurrent(P_HMinus, P_A, P_WPlus, P_Ha, 368, check)
      call createCurrent(P_G0, P_GMinus, P_WPlus, 907, check)
      call createCurrent(P_Hh, P_WMinus, P_Z, P_HPlus, 1538, check)
      call createCurrent(P_Hl, P_HMinus, P_GPlus, P_Ha, 2447, check)
      call createCurrent(P_Z, P_HMinus, P_Hh, P_WPlus, 1628, check)
      call createCurrent(P_GPlus, P_HMinus, P_Hl, P_G0, 1706, check)
      call createCurrent(P_WMinus, P_WPlus, P_A, 1935, check)
      call createCurrent(P_Z, P_G0, P_GMinus, P_WPlus, 957, check)
      call createCurrent(P_A, P_GPlus, P_Hh, P_WMinus, 255, check)
      call createCurrent(P_Hh, P_GMinus, P_GPlus, P_Hl, 2680, check)
      call createCurrent(P_Hh, P_HPlus, P_WMinus, 2205, check)
      call createCurrent(P_HMinus, P_Hl, P_G0, P_GPlus, 1430, check)
      call createCurrent(P_sAnti, P_GMinus, P_c, 1407, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, 1784, check)
      call createCurrent(P_Ha, P_WMinus, P_WPlus, P_G0, 3186, check)
      call createCurrent(P_GPlus, P_cAnti, P_s, 1839, check)
      call createCurrent(P_A, P_HPlus, P_A, P_HMinus, 544, check)
      call createCurrent(P_Hl, P_Z, P_WPlus, P_HMinus, 261, check)
      call createCurrent(P_ghWmAnti, P_Hh, P_ghWm, 2123, check)
      call createCurrent(P_WMinus, P_ghZ, P_ghWmAnti, 910, check)
      call createCurrent(P_Ha, P_G0, P_Hh, P_Hl, 625, check)
      call createCurrent(P_HMinus, P_Hh, P_GPlus, P_Hh, 2346, check)
      call createCurrent(P_g, P_ghG, P_ghGAnti, 2612, check)
      call createCurrent(P_Ha, P_GPlus, P_A, P_WMinus, 3216, check)
      call createCurrent(P_HMinus, P_G0, P_GPlus, P_G0, 2278, check)
      call createCurrent(P_GPlus, P_Z, P_A, P_HMinus, 3102, check)
      call createCurrent(P_GPlus, P_Hl, P_Ha, P_GMinus, 3520, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_GMinus, 804, check)
      call createCurrent(P_u, P_GMinus, P_dAnti, 2116, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_GPlus, 1918, check)
      call createCurrent(P_GPlus, P_g, P_g, P_GMinus, 3724, check)
      call createCurrent(P_Hl, P_HPlus, P_G0, P_HMinus, 3255, check)
      call createCurrent(P_nu_eAnti, P_GPlus, P_eMinus, 1638, check)
      call createCurrent(P_G0, P_Hh, P_GMinus, P_HPlus, 1154, check)
      call createCurrent(P_HMinus, P_HPlus, P_A, P_Z, 774, check)
      call createCurrent(P_HPlus, P_HMinus, P_HPlus, P_GMinus, 1196, check)
      call createCurrent(P_GPlus, P_ghWm, P_ghZAnti, 1556, check)
      call createCurrent(P_HPlus, P_HMinus, P_Hl, P_Hl, 272, check)
      call createCurrent(P_G0, P_HMinus, P_HPlus, P_G0, 3, check)
      call createCurrent(P_Hh, P_HPlus, P_Hl, P_GMinus, 275, check)
      call createCurrent(P_GPlus, P_GMinus, P_A, 1205, check)
      call createCurrent(P_Hl, P_Hl, P_GMinus, P_GPlus, 448, check)
      call createCurrent(P_tauMinus, P_Hh, P_tauPlus, 415, check)
      call createCurrent(P_c, P_cAnti, 3547, check)
      call createCurrent(P_Hl, P_Hl, P_HPlus, P_GMinus, 2653, check)
      call createCurrent(P_Z, P_WMinus, P_Hl, P_HPlus, 2398, check)
      call createCurrent(P_Hh, P_GMinus, P_GPlus, P_G0, 3149, check)
      call createCurrent(P_Z, P_Z, P_A, P_Z, 3712, check)
      call createCurrent(P_g, P_bAnti, P_b, 2093, check)
      call createCurrent(P_WPlus, P_HMinus, P_Z, P_G0, 3112, check)
      call createCurrent(P_Z, P_Hl, P_WMinus, P_HPlus, 1046, check)
      call createCurrent(P_Hl, P_GPlus, P_G0, P_HMinus, 1522, check)
      call createCurrent(P_ghA, P_WMinus, P_ghWmAnti, 433, check)
      call createCurrent(P_GMinus, P_GPlus, P_HMinus, P_HPlus, 1589, check)
      call createCurrent(P_HMinus, P_HPlus, P_Z, P_A, 2152, check)
      call createCurrent(P_WPlus, P_HMinus, P_Z, 587, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, P_Ha, 3045, check)
      call createCurrent(P_WMinus, P_muPlus, P_nu_mu, 343, check)
      call createCurrent(P_Hl, P_HPlus, P_Hl, P_HMinus, 712, check)
      call createCurrent(P_G0, P_Ha, P_Hl, P_Hl, 2654, check)
      call createCurrent(P_Hh, P_WPlus, P_WMinus, P_Hh, 1061, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_GMinus, 1954, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, P_Hh, 2339, check)
      call createCurrent(P_Ha, P_G0, P_Ha, P_G0, 1442, check)
      call createCurrent(P_A, P_GPlus, P_G0, P_WMinus, 776, check)
      call createCurrent(P_A, P_Hh, P_Hl, P_Z, 3725, check)
      call createCurrent(P_Hl, P_Hl, P_g, P_g, 3664, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, P_G0, 2069, check)
      call createCurrent(P_WMinus, P_sAnti, P_c, 2056, check)
      call createCurrent(P_Hl, P_G0, P_Hl, P_G0, 1085, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghA, 849, check)
      call createCurrent(P_Hh, P_HPlus, P_G0, P_GMinus, 2626, check)
      call createCurrent(P_A, P_Ha, P_WPlus, P_GMinus, 3508, check)
      call createCurrent(P_nu_mu, P_Z, P_nu_muAnti, 848, check)
      call createCurrent(P_bAnti, P_b, P_A, 487, check)
      call createCurrent(P_WMinus, P_WPlus, P_WPlus, P_WMinus, 2375, check)
      call createCurrent(P_HPlus, P_HMinus, P_GPlus, P_GMinus, 1798, check)
      call createCurrent(P_GPlus, P_Ha, P_A, P_WMinus, 3388, check)
      call createCurrent(P_GPlus, P_Hl, P_WMinus, P_A, 50, check)
      call createCurrent(P_Z, P_GPlus, P_Hl, P_WMinus, 1369, check)
      call createCurrent(P_G0, P_G0, P_GPlus, P_GMinus, 1037, check)
      call createCurrent(P_WPlus, P_Ha, P_Z, P_HMinus, 828, check)
      call createCurrent(P_WPlus, P_WMinus, P_Hh, P_Hl, 2772, check)
      call createCurrent(P_GMinus, P_muPlus, P_nu_mu, 2211, check)
      call createCurrent(P_Hh, P_g, P_g, P_Hl, 3666, check)
      call createCurrent(P_Z, P_WPlus, P_Hh, P_GMinus, 1301, check)
      call createCurrent(P_WMinus, P_HMinus, P_WPlus, P_HPlus, 1235, check)
      call createCurrent(P_Hh, P_Hl, P_HPlus, P_GMinus, 1377, check)
      call createCurrent(P_G0, P_muPlus, P_muMinus, 2167, check)
      call createCurrent(P_GMinus, P_HPlus, P_G0, 2380, check)
      call createCurrent(P_ePlus, P_HMinus, P_nu_e, 2578, check)
      call createCurrent(P_Hh, P_A, P_WMinus, P_HPlus, 2270, check)
      call createCurrent(P_Ha, P_Z, P_A, P_Ha, 3165, check)
      call createCurrent(P_Hl, P_Ha, P_HPlus, P_HMinus, 3130, check)
      call createCurrent(P_Ha, P_G0, P_Z, P_Z, 3354, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, 1222, check)
      call createCurrent(P_HPlus, P_GMinus, P_Hl, P_Hh, 1742, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_WMinus, 1735, check)
      call createCurrent(P_HMinus, P_g, P_GPlus, P_g, 3765, check)
      call createCurrent(P_Hl, P_GMinus, P_HPlus, P_G0, 106, check)
      call createCurrent(P_GMinus, P_HPlus, P_GMinus, P_HPlus, 1594, check)
      call createCurrent(P_b, P_GPlus, P_tAnti, 526, check)
      call createCurrent(P_HMinus, P_GPlus, P_Z, P_Z, 2731, check)
      call createCurrent(P_GMinus, P_GPlus, P_GMinus, P_GPlus, 573, check)
      call createCurrent(P_HMinus, P_WPlus, P_A, 1240, check)
      call createCurrent(P_GMinus, P_Hh, P_HPlus, P_Hh, 380, check)
      call createCurrent(P_HPlus, P_Hl, P_Hl, P_GMinus, 2589, check)
      call createCurrent(P_Ha, P_Hh, P_HPlus, P_GMinus, 1248, check)
      call createCurrent(P_GMinus, P_Hh, P_Hh, P_HPlus, 98, check)
      call createCurrent(P_muPlus, P_muMinus, P_A, 477, check)
      call createCurrent(P_WMinus, P_HPlus, P_WPlus, P_GMinus, 3081, check)
      call createCurrent(P_Ha, P_HPlus, P_WMinus, 1134, check)
      call createCurrent(P_HPlus, P_A, P_A, P_GMinus, 3099, check)
      call createCurrent(P_WMinus, P_GPlus, P_HMinus, P_WPlus, 3331, check)
      call createCurrent(P_g, P_GPlus, P_HMinus, P_g, 3679, check)
      call createCurrent(P_HMinus, P_Ha, P_WPlus, P_A, 692, check)
      call createCurrent(P_G0, P_GMinus, P_GPlus, P_Hl, 2818, check)
      call createCurrent(P_WMinus, P_nu_tau, P_tauPlus, 1015, check)
      call createCurrent(P_GMinus, P_HPlus, P_Z, 3383, check)
      call createCurrent(P_A, P_WPlus, P_HMinus, P_Hh, 1361, check)
      call createCurrent(P_GMinus, P_Ha, P_GPlus, P_Ha, 2575, check)
      call createCurrent(P_A, P_HPlus, P_WMinus, P_Hl, 1290, check)
      call createCurrent(P_b, P_WPlus, P_tAnti, 566, check)
      call createCurrent(P_G0, P_GPlus, P_GMinus, P_Ha, 2670, check)
      call createCurrent(P_Hl, P_Ha, P_Hh, P_G0, 994, check)
      call createCurrent(P_Z, P_A, P_HMinus, P_HPlus, 2066, check)
      call createCurrent(P_GMinus, P_HPlus, P_GMinus, P_GPlus, 1957, check)
      call createCurrent(P_HMinus, P_Hl, P_Ha, P_HPlus, 3088, check)
      call createCurrent(P_Hh, P_Z, P_WMinus, P_GPlus, 1299, check)
      call createCurrent(P_Ha, P_Hh, P_Ha, P_Hl, 792, check)
      call createCurrent(P_WMinus, P_A, P_HPlus, P_Hh, 2210, check)
      call createCurrent(P_Z, P_HPlus, P_Z, P_HMinus, 2492, check)
      call createCurrent(P_HPlus, P_GMinus, P_G0, P_Ha, 890, check)
      call createCurrent(P_WMinus, P_GPlus, P_Ha, P_Z, 3032, check)
      call createCurrent(P_g, P_HPlus, P_g, P_GMinus, 3641, check)
      call createCurrent(P_Ha, P_HMinus, P_A, P_WPlus, 1157, check)
      call createCurrent(P_HPlus, P_WMinus, P_G0, 2761, check)
      call createCurrent(P_Hl, P_HPlus, P_Hh, P_GMinus, 2151, check)
      call createCurrent(P_WMinus, P_Hl, P_HPlus, P_A, 2027, check)
      call createCurrent(P_tauPlus, P_nu_tau, P_HMinus, 1999, check)
      call createCurrent(P_Ha, P_G0, P_HMinus, P_GPlus, 2253, check)
      call createCurrent(P_HPlus, P_Z, P_WMinus, P_Hh, 226, check)
      call createCurrent(P_G0, P_GPlus, P_A, P_WMinus, 2566, check)
      call createCurrent(P_G0, P_Hl, P_GMinus, P_GPlus, 3569, check)
      call createCurrent(P_Hh, P_GPlus, P_WMinus, 2369, check)
      call createCurrent(P_Z, P_G0, 3193, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_HPlus, 3537, check)
      call createCurrent(P_A, P_A, P_HPlus, P_GMinus, 3326, check)
      call createCurrent(P_Z, P_Hl, P_WPlus, P_HMinus, 1775, check)
      call createCurrent(P_Hh, P_GMinus, P_Ha, P_GPlus, 3346, check)
      call createCurrent(P_A, P_nu_tauAnti, P_nu_tau, 3125, check)
      call createCurrent(P_tauMinus, P_A, P_tauPlus, 1907, check)
      call createCurrent(P_GMinus, P_WMinus, P_WPlus, P_GPlus, 152, check)
      call createCurrent(P_GPlus, P_A, P_Ha, P_WMinus, 2751, check)
      call createCurrent(P_HPlus, P_Ha, P_Ha, P_HMinus, 2540, check)
      call createCurrent(P_G0, P_HMinus, P_WPlus, 3329, check)
      call createCurrent(P_Z, P_WPlus, P_G0, P_HMinus, 3254, check)
      call createCurrent(P_Hl, P_Hh, P_HMinus, P_HPlus, 1758, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Hl, 501, check)
      call createCurrent(P_A, P_HPlus, P_Ha, P_WMinus, 1564, check)
      call createCurrent(P_ghWmAnti, P_Hl, P_ghWm, 251, check)
      call createCurrent(P_WPlus, P_HMinus, P_G0, 2809, check)
      call createCurrent(P_uAnti, P_g, P_u, 1224, check)
      call createCurrent(P_HMinus, P_A, P_WPlus, P_G0, 3507, check)
      call createCurrent(P_Hh, P_Hl, P_A, P_A, 3779, check)
      call createCurrent(P_GPlus, P_G0, P_Hh, P_HMinus, 1973, check)
      call createCurrent(P_Hh, P_Z, P_Z, 775, check)
      call createCurrent(P_GMinus, P_GPlus, P_G0, P_G0, 469, check)
      call createCurrent(P_WPlus, P_G0, P_A, P_GMinus, 565, check)
      call createCurrent(P_HPlus, P_GMinus, P_Z, 3419, check)
      call createCurrent(P_G0, P_A, 3515, check)
      call createCurrent(P_Hl, P_uAnti, P_u, 189, check)
      call createCurrent(P_GMinus, P_g, P_GPlus, P_g, 3678, check)
      call createCurrent(P_G0, P_Ha, P_Z, P_A, 3744, check)
      call createCurrent(P_ePlus, P_A, P_eMinus, 2317, check)
      call createCurrent(P_G0, P_HMinus, P_G0, P_HPlus, 735, check)
      call createCurrent(P_Z, P_HPlus, P_A, P_HMinus, 2099, check)
      call createCurrent(P_HPlus, P_G0, P_HMinus, 3556, check)
      call createCurrent(P_g, P_GMinus, P_g, P_GPlus, 3589, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Z, 2258, check)
      call createCurrent(P_HMinus, P_GPlus, P_Ha, P_Ha, 2284, check)
      call createCurrent(P_uAnti, P_Hl, P_u, 2096, check)
      call createCurrent(P_HPlus, P_GMinus, P_HPlus, P_GMinus, 1679, check)
      call createCurrent(P_Hl, P_A, P_WMinus, P_HPlus, 416, check)
      call createCurrent(P_Z, P_Hh, P_Hl, P_A, 3731, check)
      call createCurrent(P_Z, P_muPlus, P_muMinus, 1252, check)
      call createCurrent(P_b, P_Ha, P_bAnti, 1079, check)
      call createCurrent(P_GPlus, P_Z, P_GMinus, P_Z, 199, check)
      call createCurrent(P_A, P_Hh, P_WPlus, P_HMinus, 597, check)
      call createCurrent(P_GPlus, P_A, P_Hh, P_WMinus, 893, check)
      call createCurrent(P_GPlus, P_nu_tauAnti, P_tauMinus, 2145, check)
      call createCurrent(P_GMinus, P_GPlus, P_Hh, P_Hl, 1335, check)
      call createCurrent(P_GMinus, P_Ha, P_GPlus, P_Hh, 3317, check)
      call createCurrent(P_A, P_HPlus, P_GMinus, P_Z, 2949, check)
      call createCurrent(P_GPlus, P_WMinus, P_G0, P_A, 320, check)
      call createCurrent(P_GPlus, P_G0, P_G0, P_HMinus, 1669, check)
      call createCurrent(P_G0, P_Hh, P_Hh, P_Ha, 1285, check)
      call createCurrent(P_HPlus, P_cAnti, P_s, 2373, check)
      call createCurrent(P_HMinus, P_HPlus, P_HMinus, P_HPlus, 1549, check)
      call createCurrent(P_dAnti, P_d, P_G0, 141, check)
      call createCurrent(P_Hh, P_HMinus, P_WPlus, P_A, 895, check)
      call createCurrent(P_HMinus, P_Hh, P_GPlus, P_G0, 397, check)
      call createCurrent(P_G0, P_cAnti, P_c, 1391, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, P_G0, 1958, check)
      call createCurrent(P_A, P_Hh, P_A, P_Hl, 3726, check)
      call createCurrent(P_c, P_G0, P_cAnti, 638, check)
      call createCurrent(P_G0, P_HPlus, P_G0, P_HMinus, 926, check)
      call createCurrent(P_nu_mu, P_muPlus, P_GMinus, 319, check)
      call createCurrent(P_GMinus, P_Ha, P_A, P_WPlus, 3298, check)
      call createCurrent(P_Hh, P_Hh, P_GMinus, P_GPlus, 2264, check)
      call createCurrent(P_WMinus, P_Hh, P_HPlus, 1181, check)
      call createCurrent(P_Z, P_WPlus, P_HMinus, P_G0, 3552, check)
      call createCurrent(P_Hh, P_Ha, P_Hh, P_Hh, 3699, check)
      call createCurrent(P_WMinus, P_HPlus, P_Z, P_Ha, 113, check)
      call createCurrent(P_Hl, P_Z, P_A, 3555, check)
      call createCurrent(P_Hl, P_WMinus, P_Z, P_GPlus, 2629, check)
      call createCurrent(P_WPlus, P_Hl, P_HMinus, 334, check)
      call createCurrent(P_Z, P_Ha, P_Hh, 2494, check)
      call createCurrent(P_muMinus, P_muPlus, P_G0, 485, check)
      call createCurrent(P_Ha, P_HPlus, P_Ha, P_HMinus, 937, check)
      call createCurrent(P_HPlus, P_Hh, P_Hh, P_GMinus, 2482, check)
      call createCurrent(P_Z, P_HPlus, P_WMinus, P_Hl, 697, check)
      call createCurrent(P_Z, P_WPlus, P_Hl, P_HMinus, 1688, check)
      call createCurrent(P_A, P_A, P_Ha, P_Ha, 3623, check)
      call createCurrent(P_c, P_cAnti, P_Ha, 1398, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, P_Hh, 2045, check)
      call createCurrent(P_Hh, P_A, P_A, 3871, check)
      call createCurrent(P_Hl, P_Ha, P_G0, P_Hh, 200, check)
      call createCurrent(P_Z, P_HPlus, P_GMinus, P_A, 3423, check)
      call createCurrent(P_bAnti, P_Hh, P_b, 321, check)
      call createCurrent(P_Ha, P_WMinus, P_GPlus, P_Z, 2712, check)
      call createCurrent(P_t, P_Hh, P_tAnti, 1642, check)
      call createCurrent(P_Ha, P_Ha, P_Hh, 650, check)
      call createCurrent(P_WPlus, P_GMinus, P_Ha, P_Z, 3377, check)
      call createCurrent(P_uAnti, P_d, P_WPlus, 1575, check)
      call createCurrent(P_A, P_Z, P_g, P_g, 3633, check)
      call createCurrent(P_A, P_GMinus, P_Z, P_GPlus, 1956, check)
      call createCurrent(P_GMinus, P_WPlus, P_WMinus, P_GPlus, 1403, check)
      call createCurrent(P_WPlus, P_WMinus, P_GMinus, P_GPlus, 2383, check)
      call createCurrent(P_HPlus, P_HMinus, P_Ha, P_Hl, 3046, check)
      call createCurrent(P_Ha, P_G0, P_g, P_g, 3832, check)
      call createCurrent(P_G0, P_WMinus, P_WPlus, P_Ha, 2720, check)
      call createCurrent(P_Hl, P_Hh, P_WPlus, P_WMinus, 3126, check)
      call createCurrent(P_Ha, P_g, P_Ha, P_g, 3694, check)
      call createCurrent(P_WMinus, P_A, P_Hh, P_GPlus, 2389, check)
      call createCurrent(P_Ha, P_Z, P_Hh, 2141, check)
      call createCurrent(P_Hl, P_HMinus, P_GPlus, P_Hl, 734, check)
      call createCurrent(P_G0, P_g, P_g, P_Ha, 3706, check)
      call createCurrent(P_Hl, P_GPlus, P_WMinus, 2131, check)
      call createCurrent(P_HPlus, P_HMinus, P_A, P_Z, 1986, check)
      call createCurrent(P_A, P_GMinus, P_GPlus, 583, check)
      call createCurrent(P_A, P_dAnti, P_d, 1632, check)
      call createCurrent(P_HMinus, P_GPlus, P_WMinus, P_WPlus, 3111, check)
      call createCurrent(P_HPlus, P_Hl, P_Hl, P_HMinus, 108, check)
      call createCurrent(P_A, P_Z, P_HPlus, P_HMinus, 2619, check)
      call createCurrent(P_Hh, P_Hh, P_Hh, P_Hh, 1310, check)
      call createCurrent(P_Z, P_u, P_uAnti, 2456, check)
      call createCurrent(P_G0, P_WPlus, P_A, P_GMinus, 2561, check)
      call createCurrent(P_HPlus, P_ghA, P_ghWpAnti, 2925, check)
      call createCurrent(P_Hl, P_Z, P_WMinus, P_HPlus, 2529, check)
      call createCurrent(P_HPlus, P_ghZAnti, P_ghWm, 3344, check)
      call createCurrent(P_c, P_sAnti, P_GMinus, 1608, check)
      call createCurrent(P_Hl, P_Hl, P_G0, P_G0, 1206, check)
      call createCurrent(P_GPlus, P_GMinus, P_Hl, 736, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghA, 58, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_Hh, 282, check)
      call createCurrent(P_WMinus, P_WPlus, P_Z, P_Z, 1521, check)
      call createCurrent(P_GPlus, P_GPlus, P_GMinus, P_GMinus, 1174, check)
      call createCurrent(P_WMinus, P_Z, P_Hh, P_GPlus, 1759, check)
      call createCurrent(P_Z, P_Z, P_G0, P_G0, 1072, check)
      call createCurrent(P_Hh, P_G0, P_HMinus, P_HPlus, 3469, check)
      call createCurrent(P_G0, P_Hh, P_GPlus, P_HMinus, 1140, check)
      call createCurrent(P_A, P_Hl, P_Z, 3412, check)
      call createCurrent(P_HMinus, P_Z, P_G0, P_WPlus, 3073, check)
      call createCurrent(P_Z, P_Ha, P_Ha, P_A, 2864, check)
      call createCurrent(P_A, P_Z, P_GMinus, P_HPlus, 3217, check)
      call createCurrent(P_d, P_dAnti, P_Hl, 1535, check)
      call createCurrent(P_Z, P_Z, P_Hl, 97, check)
      call createCurrent(P_Hh, P_sAnti, P_s, 2585, check)
      call createCurrent(P_HMinus, P_Hl, P_GPlus, P_Hh, 374, check)
      call createCurrent(P_WPlus, P_GMinus, P_Ha, P_A, 3262, check)
      call createCurrent(P_A, P_WPlus, P_HMinus, P_Ha, 64, check)
      call createCurrent(P_Hh, P_ghZ, P_ghZAnti, 1348, check)
      call createCurrent(P_G0, P_GMinus, P_Hl, P_GPlus, 3169, check)
      call createCurrent(P_WPlus, P_GMinus, P_GPlus, P_WMinus, 1893, check)
      call createCurrent(P_G0, P_Ha, P_G0, P_Ha, 2668, check)
      call createCurrent(P_Ha, P_HMinus, P_WPlus, P_A, 93, check)
      call createCurrent(P_eMinus, P_HPlus, P_nu_eAnti, 1860, check)
      call createCurrent(P_u, P_uAnti, P_G0, 187, check)
      call createCurrent(P_HPlus, P_Ha, P_Hh, P_GMinus, 262, check)
      call createCurrent(P_Ha, P_G0, P_G0, P_Hh, 3768, check)
      call createCurrent(P_HPlus, P_GPlus, P_GMinus, P_HMinus, 1373, check)
      call createCurrent(P_Z, P_HMinus, P_HPlus, P_Z, 100, check)
      call createCurrent(P_WMinus, P_Hh, P_WPlus, P_Hl, 3232, check)
      call createCurrent(P_Hh, P_GMinus, P_Hl, P_GPlus, 2359, check)
      call createCurrent(P_dAnti, P_Hl, P_d, 868, check)
      call createCurrent(P_t, P_G0, P_tAnti, 1346, check)
      call createCurrent(P_WPlus, P_A, P_Ha, P_GMinus, 3051, check)
      call createCurrent(P_g, P_Hl, P_g, 3662, check)
      call createCurrent(P_d, P_Ha, P_dAnti, 1419, check)
      call createCurrent(P_GMinus, P_WPlus, P_Hh, P_Z, 1101, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, P_Hh, 2360, check)
      call createCurrent(P_WMinus, P_Hh, P_A, P_HPlus, 149, check)
      call createCurrent(P_HPlus, P_HMinus, 2976, check)
      call createCurrent(P_Hh, P_HMinus, P_GPlus, P_Hh, 2243, check)
      call createCurrent(P_WMinus, P_Ha, P_GPlus, P_Z, 2826, check)
      call createCurrent(P_WPlus, P_Z, P_WMinus, 513, check)
      call createCurrent(P_HMinus, P_G0, P_Hh, P_GPlus, 885, check)
      call createCurrent(P_GMinus, P_Hl, P_Hh, P_HPlus, 134, check)
      call createCurrent(P_Ha, P_Ha, P_HMinus, P_HPlus, 406, check)
      call createCurrent(P_WPlus, P_tauMinus, P_nu_tauAnti, 222, check)
      call createCurrent(P_WPlus, P_WMinus, P_HMinus, P_GPlus, 3121, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_HMinus, 3371, check)
      call createCurrent(P_HPlus, P_g, P_g, P_HMinus, 3635, check)
      call createCurrent(P_G0, P_Z, P_G0, P_A, 3233, check)
      call createCurrent(P_HMinus, P_Z, P_WPlus, P_Hl, 1708, check)
      call createCurrent(P_WMinus, P_WPlus, P_GMinus, P_HPlus, 2812, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_ghWm, 2220, check)
      call createCurrent(P_Z, P_A, P_Hh, 3158, check)
      call createCurrent(P_G0, P_HPlus, P_GMinus, P_Ha, 1938, check)
      call createCurrent(P_uAnti, P_HPlus, P_d, 1633, check)
      call createCurrent(P_HPlus, P_Hl, P_HMinus, 167, check)
      call createCurrent(P_HPlus, P_G0, P_G0, P_HMinus, 980, check)
      call createCurrent(P_HMinus, P_Ha, P_GPlus, P_Hl, 2213, check)
      call createCurrent(P_Ha, P_Z, P_Z, P_G0, 3268, check)
      call createCurrent(P_Ha, P_Ha, P_WMinus, P_WPlus, 533, check)
      call createCurrent(P_Ha, P_Hh, P_GMinus, P_GPlus, 2916, check)
      call createCurrent(P_GMinus, P_Hl, P_WPlus, P_A, 260, check)
      call createCurrent(P_A, P_Hh, P_Ha, 3586, check)
      call createCurrent(P_G0, P_WPlus, P_A, P_HMinus, 3007, check)
      call createCurrent(P_Hh, P_HPlus, P_G0, P_HMinus, 2971, check)
      call createCurrent(P_GMinus, P_HPlus, P_GPlus, P_HMinus, 1025, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, 345, check)
      call createCurrent(P_Z, P_WPlus, P_Hl, P_GMinus, 307, check)
      call createCurrent(P_G0, P_Ha, 3056, check)
      call createCurrent(P_WPlus, P_HMinus, P_Z, P_Ha, 2601, check)
      call createCurrent(P_WPlus, P_A, P_Hh, P_GMinus, 2244, check)
      call createCurrent(P_Z, P_Hl, P_A, P_Hl, 2828, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, P_Hh, 159, check)
      call createCurrent(P_WPlus, P_Hl, P_GMinus, P_A, 690, check)
      call createCurrent(P_A, P_GMinus, P_HPlus, P_Z, 3084, check)
      call createCurrent(P_GPlus, P_Ha, P_GMinus, 3451, check)
      call createCurrent(P_HMinus, P_Hh, P_HPlus, P_Ha, 3226, check)
      call createCurrent(P_GMinus, P_GPlus, P_Hl, P_G0, 3128, check)
      call createCurrent(P_GPlus, P_GMinus, P_Ha, P_Ha, 1185, check)
      call createCurrent(P_GMinus, P_GPlus, P_A, P_Z, 1927, check)
      call createCurrent(P_t, P_GMinus, P_bAnti, 1518, check)
      call createCurrent(P_GPlus, P_GMinus, P_HMinus, P_GPlus, 1543, check)
      call createCurrent(P_GMinus, P_Z, P_Z, P_GPlus, 1526, check)
      call createCurrent(P_WPlus, P_HMinus, P_G0, P_Z, 3154, check)
      call createCurrent(P_G0, P_HPlus, P_HMinus, P_Hl, 2959, check)
      call createCurrent(P_ghZ, P_WMinus, P_ghWmAnti, 281, check)
      call createCurrent(P_WPlus, P_GPlus, P_HMinus, P_WMinus, 3313, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, P_Hh, 2328, check)
      call createCurrent(P_GMinus, P_Ha, P_Z, P_WPlus, 3288, check)
      call createCurrent(P_Hh, P_WMinus, P_GPlus, 2413, check)
      call createCurrent(P_d, P_HPlus, P_uAnti, 1967, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghZAnti, 1082, check)
      call createCurrent(P_WPlus, P_Hh, P_WMinus, 1582, check)
      call createCurrent(P_HPlus, P_g, P_g, P_GMinus, 3736, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_GPlus, 547, check)
      call createCurrent(P_HMinus, P_Z, P_WPlus, P_Hh, 2060, check)
      call createCurrent(P_WPlus, P_G0, P_HMinus, P_A, 2822, check)
      call createCurrent(P_u, P_A, P_uAnti, 1173, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_WMinus, 763, check)
      call createCurrent(P_GMinus, P_Hh, P_Z, P_WPlus, 196, check)
      call createCurrent(P_Ha, P_WMinus, P_A, P_HPlus, 438, check)
      call createCurrent(P_G0, P_WMinus, P_Z, P_HPlus, 2905, check)
      call createCurrent(P_ghA, P_HMinus, P_ghWmAnti, 2794, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, P_Hh, 858, check)
      call createCurrent(P_Hh, P_b, P_bAnti, 2308, check)
      call createCurrent(P_A, P_u, P_uAnti, 1295, check)
      call createCurrent(P_Hl, P_Hh, P_Hh, P_Hh, 1030, check)
      call createCurrent(P_WMinus, P_HPlus, P_Z, P_Hh, 11, check)
      call createCurrent(P_Z, P_A, P_Hh, P_Hh, 2735, check)
      call createCurrent(P_G0, P_HPlus, P_HMinus, P_Hh, 2805, check)
      call createCurrent(P_WPlus, P_Hl, P_WMinus, P_Hh, 2815, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_WPlus, 881, check)
      call createCurrent(P_G0, P_Ha, P_Ha, P_Ha, 2028, check)
      call createCurrent(P_Hl, P_Z, P_Z, P_Hl, 576, check)
      call createCurrent(P_s, P_sAnti, P_Hh, 1606, check)
      call createCurrent(P_GPlus, P_GMinus, P_GPlus, P_HMinus, 1000, check)
      call createCurrent(P_HPlus, P_Hl, P_GMinus, P_G0, 457, check)
      call createCurrent(P_Hl, P_WPlus, P_WMinus, P_Hl, 1390, check)
      call createCurrent(P_HMinus, P_Hh, P_Hl, P_HPlus, 1853, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_GPlus, 190, check)
      call createCurrent(P_Z, P_GPlus, P_GMinus, 889, check)
      call createCurrent(P_Hl, P_GPlus, P_HMinus, P_Ha, 2263, check)
      call createCurrent(P_Ha, P_Ha, P_HMinus, P_GPlus, 2274, check)
      call createCurrent(P_HMinus, P_GPlus, 3010, check)
      call createCurrent(P_GMinus, P_Ha, P_Hh, P_HPlus, 2285, check)
      call createCurrent(P_G0, P_HMinus, P_HPlus, 3458, check)
      call createCurrent(P_G0, P_ghWm, P_ghWmAnti, 746, check)
      call createCurrent(P_G0, P_A, P_WPlus, P_GMinus, 2448, check)
      call createCurrent(P_GMinus, P_Hh, P_GPlus, P_Hl, 238, check)
      call createCurrent(P_dAnti, P_GMinus, P_u, 270, check)
      call createCurrent(P_bAnti, P_Hl, P_b, 1613, check)
      call createCurrent(P_HPlus, P_Ha, P_GMinus, P_Hh, 956, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, P_G0, 2091, check)
      call createCurrent(P_Hh, P_Hh, P_Ha, P_G0, 1617, check)
      call createCurrent(P_Ha, P_GMinus, P_WPlus, P_A, 2827, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_G0, 1537, check)
      call createCurrent(P_GMinus, P_Hh, P_WPlus, P_A, 1835, check)
      call createCurrent(P_Ha, P_muMinus, P_muPlus, 1731, check)
      call createCurrent(P_WPlus, P_Z, P_Z, P_WMinus, 616, check)
      call createCurrent(P_A, P_GPlus, P_GMinus, P_Z, 1226, check)
      call createCurrent(P_HMinus, P_HPlus, P_Hh, 470, check)
      call createCurrent(P_WPlus, P_Z, P_G0, P_HMinus, 3087, check)
      call createCurrent(P_muMinus, P_WPlus, P_nu_muAnti, 499, check)
      call createCurrent(P_g, P_Z, P_g, P_A, 3763, check)
      call createCurrent(P_Z, P_Hl, P_Hl, P_A, 2922, check)
      call createCurrent(P_HPlus, P_GPlus, P_GMinus, P_GMinus, 1991, check)
      call createCurrent(P_WMinus, P_Ha, P_WPlus, P_G0, 3435, check)
      call createCurrent(P_WPlus, P_HMinus, P_WMinus, P_GPlus, 3545, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, P_Hl, 1565, check)
      call createCurrent(P_GMinus, P_GPlus, P_G0, 2904, check)
      call createCurrent(P_HMinus, P_Hh, P_Hh, P_GPlus, 225, check)
      call createCurrent(P_WMinus, P_Z, P_WPlus, P_A, 2586, check)
      call createCurrent(P_G0, P_muMinus, P_muPlus, 2655, check)
      call createCurrent(P_A, P_A, P_HMinus, P_HPlus, 1208, check)
      call createCurrent(P_G0, P_GPlus, P_HMinus, P_G0, 1890, check)
      call createCurrent(P_GPlus, P_Ha, P_HMinus, P_G0, 2552, check)
      call createCurrent(P_nu_muAnti, P_nu_mu, P_A, 3323, check)
      call createCurrent(P_Hh, P_ePlus, P_eMinus, 542, check)
      call createCurrent(P_nu_mu, P_muPlus, P_WMinus, 1372, check)
      call createCurrent(P_Hh, P_HMinus, P_HPlus, 2481, check)
      call createCurrent(P_WMinus, P_WPlus, P_A, P_Z, 2251, check)
      call createCurrent(P_Ha, P_Ha, P_Z, P_A, 2713, check)
      call createCurrent(P_Hh, P_A, P_Hl, P_Z, 3742, check)
      call createCurrent(P_WMinus, P_WPlus, P_HMinus, P_HPlus, 853, check)
      call createCurrent(P_WPlus, P_GMinus, P_Ha, 2774, check)
      call createCurrent(P_HPlus, P_HMinus, P_g, P_g, 3872, check)
      call createCurrent(P_HPlus, P_ghWm, P_ghZAnti, 2909, check)
      call createCurrent(P_WPlus, P_Hh, P_GMinus, P_A, 514, check)
      call createCurrent(P_WPlus, P_Z, P_HMinus, P_Ha, 2222, check)
      call createCurrent(P_WPlus, P_Ha, P_GMinus, P_Z, 3485, check)
      call createCurrent(P_HPlus, P_Hh, P_GMinus, P_G0, 2472, check)
      call createCurrent(P_HMinus, P_HPlus, P_HMinus, P_GPlus, 1566, check)
      call createCurrent(P_GPlus, P_GPlus, P_HMinus, P_GMinus, 315, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, P_Hl, 1816, check)
      call createCurrent(P_GPlus, P_G0, P_G0, P_GMinus, 2463, check)
      call createCurrent(P_HPlus, P_Ha, P_HMinus, P_Hh, 3109, check)
      call createCurrent(P_Z, P_Z, P_A, P_A, 3793, check)
      call createCurrent(P_GMinus, P_GPlus, P_Ha, P_G0, 27, check)
      call createCurrent(P_Z, P_GPlus, P_Z, P_HMinus, 3355, check)
      call createCurrent(P_nu_muAnti, P_muMinus, P_WPlus, 430, check)
      call createCurrent(P_Z, P_Hl, P_GMinus, P_WPlus, 613, check)
      call createCurrent(P_Z, P_Z, P_WPlus, P_WMinus, 2459, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_A, 543, check)
      call createCurrent(P_g, P_WMinus, P_g, P_WPlus, 3720, check)
      call createCurrent(P_G0, P_A, P_Ha, P_A, 3860, check)
      call createCurrent(P_HMinus, P_A, P_Hl, P_WPlus, 2394, check)
      call createCurrent(P_Ha, P_G0, P_WMinus, P_WPlus, 3496, check)
      call createCurrent(P_GMinus, P_WPlus, P_Ha, P_A, 3512, check)
      call createCurrent(P_Hh, P_G0, P_A, 2991, check)
      call createCurrent(P_A, P_A, P_WPlus, P_WMinus, 590, check)
      call createCurrent(P_c, P_Hl, P_cAnti, 719, check)
      call createCurrent(P_GPlus, P_Hl, P_GMinus, P_Ha, 3504, check)
      call createCurrent(P_A, P_Hh, P_Hh, P_A, 3607, check)
      call createCurrent(P_g, P_Hh, P_g, P_Hl, 3804, check)
      call createCurrent(P_HPlus, P_Hl, P_HMinus, P_Hl, 2298, check)
      call createCurrent(P_Hh, P_WPlus, P_Z, P_HMinus, 959, check)
      call createCurrent(P_HPlus, P_WMinus, P_Z, P_Ha, 164, check)
      call createCurrent(P_Hh, P_Hl, P_Ha, P_Ha, 1574, check)
      call createCurrent(P_Hl, P_GPlus, P_Ha, P_HMinus, 2430, check)
      call createCurrent(P_Z, P_WPlus, P_Ha, P_GMinus, 3453, check)
      call createCurrent(P_ghWp, P_G0, P_ghWpAnti, 1355, check)
      call createCurrent(P_GMinus, P_Z, P_GPlus, 2434, check)
      call createCurrent(P_GPlus, P_muMinus, P_nu_muAnti, 834, check)
      call createCurrent(P_g, P_g, P_Z, P_g, 3729, check)
      call createCurrent(P_muMinus, P_A, P_muPlus, 38, check)
      call createCurrent(P_muPlus, P_WMinus, P_nu_mu, 751, check)
      call createCurrent(P_Ha, P_HPlus, P_HMinus, P_Hl, 3076, check)
      call createCurrent(P_Hh, P_HMinus, P_GPlus, P_Ha, 1765, check)
      call createCurrent(P_Z, P_GPlus, P_Hh, P_WMinus, 384, check)
      call createCurrent(P_GMinus, P_GPlus, P_Hh, P_G0, 3526, check)
      call createCurrent(P_muPlus, P_nu_mu, P_HMinus, 44, check)
      call createCurrent(P_Z, P_GMinus, P_HPlus, 3105, check)
      call createCurrent(P_G0, P_G0, P_A, P_A, 3637, check)
      call createCurrent(P_Hh, P_Hl, P_Z, P_Z, 2711, check)
      call createCurrent(P_g, P_g, P_HMinus, P_GPlus, 3859, check)
      call createCurrent(P_G0, P_A, P_WMinus, P_HPlus, 2967, check)
      call createCurrent(P_Z, P_GMinus, P_GPlus, 1591, check)
      call createCurrent(P_bAnti, P_t, P_HMinus, 1668, check)
      call createCurrent(P_A, P_WPlus, P_Ha, P_HMinus, 330, check)
      call createCurrent(P_A, P_A, P_HPlus, P_HMinus, 512, check)
      call createCurrent(P_HMinus, P_A, P_HPlus, 2543, check)
      call createCurrent(P_HPlus, P_Z, P_A, P_GMinus, 3228, check)
      call createCurrent(P_HPlus, P_G0, P_Z, P_WMinus, 2977, check)
      call createCurrent(P_GMinus, P_HMinus, P_GPlus, P_HPlus, 1897, check)
      call createCurrent(P_WMinus, P_HPlus, P_A, P_Hl, 1871, check)
      call createCurrent(P_GPlus, P_Hh, P_GMinus, P_Hl, 2234, check)
      call createCurrent(P_WMinus, P_Hl, P_Hl, P_WPlus, 745, check)
      call createCurrent(P_ePlus, P_WMinus, P_nu_e, 9, check)
      call createCurrent(P_uAnti, P_Hh, P_u, 2322, check)
      call createCurrent(P_g, P_HPlus, P_g, P_HMinus, 3746, check)
      call createCurrent(P_muMinus, P_Ha, P_muPlus, 1834, check)
      call createCurrent(P_g, P_HMinus, P_g, P_GPlus, 3598, check)
      call createCurrent(P_d, P_dAnti, P_g, 1914, check)
      call createCurrent(P_nu_tauAnti, P_HPlus, P_tauMinus, 1131, check)
      call createCurrent(P_g, P_A, P_g, P_g, 3684, check)
      call createCurrent(P_HMinus, P_Hl, P_WPlus, P_A, 1761, check)
      call createCurrent(P_Ha, P_g, P_g, P_G0, 3800, check)
      call createCurrent(P_WPlus, P_Hl, P_HMinus, P_A, 1254, check)
      call createCurrent(P_WMinus, P_WPlus, P_Hh, P_Hl, 3251, check)
      call createCurrent(P_GPlus, P_Hl, P_HMinus, P_Hh, 1073, check)
      call createCurrent(P_A, P_WMinus, P_WPlus, P_A, 2252, check)
      call createCurrent(P_GMinus, P_Hl, P_Hl, P_GPlus, 2435, check)
      call createCurrent(P_Hl, P_Hh, P_GMinus, P_HPlus, 2692, check)
      call createCurrent(P_d, P_uAnti, P_GPlus, 1989, check)
      call createCurrent(P_HPlus, P_Hl, P_GMinus, P_Ha, 872, check)
      call createCurrent(P_GMinus, P_GPlus, P_WMinus, P_WPlus, 844, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghA, 711, check)
      call createCurrent(P_GPlus, P_WPlus, P_WMinus, P_GMinus, 1027, check)
      call createCurrent(P_Ha, P_HMinus, P_HPlus, P_G0, 715, check)
      call createCurrent(P_g, P_A, P_Z, P_g, 3645, check)
      call createCurrent(P_GMinus, P_GPlus, P_WPlus, P_WMinus, 1837, check)
      call createCurrent(P_WMinus, P_Ha, P_HPlus, P_Z, 781, check)
      call createCurrent(P_Z, P_WMinus, P_G0, P_HPlus, 3138, check)
      call createCurrent(P_ePlus, P_eMinus, P_Z, 351, check)
      call createCurrent(P_ghWpAnti, P_Ha, P_ghWp, 2948, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_G0, 474, check)
      call createCurrent(P_HMinus, P_Z, P_A, P_HPlus, 901, check)
      call createCurrent(P_G0, P_HMinus, P_Ha, P_HPlus, 1702, check)
      call createCurrent(P_cAnti, P_Hh, P_c, 1319, check)
      call createCurrent(P_Hh, P_HMinus, P_HPlus, P_Ha, 2802, check)
      call createCurrent(P_GPlus, P_HMinus, P_HPlus, P_GMinus, 2247, check)
      call createCurrent(P_WMinus, P_WPlus, P_Ha, P_G0, 3418, check)
      call createCurrent(P_A, P_Hl, P_GPlus, P_WMinus, 250, check)
      call createCurrent(P_G0, P_Z, P_HPlus, P_WMinus, 3129, check)
      call createCurrent(P_HPlus, P_GMinus, P_G0, 2327, check)
      call createCurrent(P_Hl, P_Hl, P_WMinus, P_WPlus, 2356, check)
      call createCurrent(P_ghWp, P_Hl, P_ghWpAnti, 421, check)
      call createCurrent(P_GPlus, P_GMinus, 3479, check)
      call createCurrent(P_WPlus, P_Ha, P_G0, P_WMinus, 3083, check)
      call createCurrent(P_c, P_g, P_cAnti, 195, check)
      call createCurrent(P_A, P_Z, P_Z, P_Z, 3877, check)
      call createCurrent(P_Ha, P_WPlus, P_HMinus, P_Z, 1581, check)
      call createCurrent(P_Hl, P_G0, P_Hh, P_Ha, 799, check)
      call createCurrent(P_Ha, P_G0, P_G0, 3657, check)
      call createCurrent(P_HMinus, P_HPlus, P_G0, P_Ha, 39, check)
      call createCurrent(P_G0, P_Z, P_HMinus, P_WPlus, 3389, check)
      call createCurrent(P_c, P_cAnti, P_Z, 2018, check)
      call createCurrent(P_HMinus, P_HPlus, P_Hl, P_Hl, 126, check)
      call createCurrent(P_Hh, P_G0, P_Ha, P_Hl, 458, check)
      call createCurrent(P_WMinus, P_G0, P_Z, P_HPlus, 3588, check)
      call createCurrent(P_G0, P_WPlus, P_GMinus, 2065, check)
      call createCurrent(P_Hl, P_GMinus, P_HPlus, P_Hh, 1921, check)
      call createCurrent(P_GPlus, P_Hl, P_GMinus, P_Hh, 2487, check)
      call createCurrent(P_GPlus, P_GMinus, P_WMinus, P_WPlus, 1150, check)
      call createCurrent(P_Hl, P_Hl, P_Hl, 830, check)
      call createCurrent(P_WPlus, P_HMinus, P_G0, P_A, 2918, check)
      call createCurrent(P_HPlus, P_GMinus, P_Hh, P_Hl, 511, check)
      call createCurrent(P_Hl, P_Hl, P_Ha, P_Hl, 3710, check)
      call createCurrent(P_GMinus, P_Hl, P_Hh, P_GPlus, 473, check)
      call createCurrent(P_GMinus, P_Ha, P_WPlus, P_A, 2753, check)
      call createCurrent(P_GPlus, P_Hl, P_HMinus, P_Ha, 618, check)
      call createCurrent(P_u, P_Ha, P_uAnti, 1078, check)
      call createCurrent(P_HPlus, P_WMinus, P_Z, 163, check)
      call createCurrent(P_dAnti, P_Z, P_d, 1093, check)
      call createCurrent(P_GPlus, P_G0, P_WMinus, P_A, 2679, check)
      call createCurrent(P_muMinus, P_HPlus, P_nu_muAnti, 2581, check)
      call createCurrent(P_Z, P_Hh, P_A, P_Hl, 3727, check)
      call createCurrent(P_WMinus, P_Hh, P_Hl, P_WPlus, 3119, check)
      call createCurrent(P_HPlus, P_Ha, P_WMinus, P_Z, 2037, check)
      call createCurrent(P_Hl, P_Z, P_HPlus, P_WMinus, 656, check)
      call createCurrent(P_G0, P_tauPlus, P_tauMinus, 2259, check)
      call createCurrent(P_GPlus, P_HMinus, P_Ha, 172, check)
      call createCurrent(P_WPlus, P_WMinus, P_Ha, P_G0, 3021, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, 1130, check)
      call createCurrent(P_Z, P_A, P_HMinus, P_GPlus, 2744, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, P_G0, 2533, check)
      call createCurrent(P_Z, P_GPlus, P_GMinus, P_Z, 170, check)
      call createCurrent(P_sAnti, P_WMinus, P_c, 1602, check)
      call createCurrent(P_uAnti, P_u, P_G0, 2464, check)
      call createCurrent(P_GPlus, P_tAnti, P_b, 887, check)
      call createCurrent(P_s, P_HPlus, P_cAnti, 2200, check)
      call createCurrent(P_GPlus, P_Hl, P_HMinus, P_Hl, 1517, check)
      call createCurrent(P_Hl, P_HMinus, P_GPlus, 2537, check)
      call createCurrent(P_Hl, P_WPlus, P_HMinus, P_A, 1399, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, P_Hl, 2514, check)
      call createCurrent(P_Hh, P_GPlus, P_A, P_WMinus, 1700, check)
      call createCurrent(P_ghZ, P_WPlus, P_ghWpAnti, 778, check)
      call createCurrent(P_WMinus, P_HMinus, P_WPlus, P_GPlus, 3026, check)
      call createCurrent(P_GPlus, P_HMinus, P_A, 3532, check)
      call createCurrent(P_WMinus, P_GPlus, P_Hh, P_A, 2399, check)
      call createCurrent(P_G0, P_Hh, P_Z, 2437, check)
      call createCurrent(P_G0, P_GPlus, P_GMinus, 3308, check)
      call createCurrent(P_Z, P_GPlus, P_G0, P_WMinus, 2610, check)
      call createCurrent(P_g, P_g, P_HPlus, P_HMinus, 3783, check)
      call createCurrent(P_HPlus, P_Hh, P_GMinus, P_Hh, 2446, check)
      call createCurrent(P_Hl, P_b, P_bAnti, 2170, check)
      call createCurrent(P_HPlus, P_GMinus, P_GPlus, P_GMinus, 76, check)
      call createCurrent(P_Ha, P_GMinus, P_WPlus, P_Z, 3253, check)
      call createCurrent(P_G0, P_Z, P_WMinus, P_HPlus, 3287, check)
      call createCurrent(P_GMinus, P_HPlus, P_HPlus, P_GMinus, 894, check)
      call createCurrent(P_tAnti, P_t, P_Hl, 2161, check)
      call createCurrent(P_HPlus, P_HMinus, P_Hh, P_Hl, 2650, check)
      call createCurrent(P_G0, P_G0, P_Hh, P_Hl, 739, check)
      call createCurrent(P_nu_tauAnti, P_A, P_nu_tau, 2739, check)
      call createCurrent(P_GMinus, P_HPlus, P_A, P_Z, 2808, check)
      call createCurrent(P_Ha, P_G0, P_A, P_Z, 3757, check)
      call createCurrent(P_GPlus, P_HMinus, P_Z, P_A, 2741, check)
      call createCurrent(P_Hl, P_GMinus, P_G0, P_HPlus, 2432, check)
      call createCurrent(P_HMinus, P_Ha, P_Hl, P_HPlus, 2950, check)
      call createCurrent(P_Hl, P_A, P_Hh, P_A, 3758, check)
      call createCurrent(P_Ha, P_Ha, P_Hl, P_Hh, 903, check)
      call createCurrent(P_GPlus, P_Hh, P_Z, P_WMinus, 2132, check)
      call createCurrent(P_A, P_HPlus, P_GMinus, P_A, 2839, check)
      call createCurrent(P_A, P_Ha, P_WMinus, P_GPlus, 2773, check)
      call createCurrent(P_GMinus, P_GPlus, P_Z, P_A, 1640, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_Z, 2568, check)
      call createCurrent(P_ghWmAnti, P_HMinus, P_ghZ, 2770, check)
      call createCurrent(P_A, P_A, 3152, check)
      call createCurrent(P_Hh, P_WMinus, P_Z, P_GPlus, 243, check)
      call createCurrent(P_Hl, P_WMinus, P_HPlus, P_Z, 1338, check)
      call createCurrent(P_Hl, P_GMinus, P_Hh, P_HPlus, 2638, check)
      call createCurrent(P_WMinus, P_Z, P_Z, P_WPlus, 666, check)
      call createCurrent(P_eMinus, P_nu_eAnti, P_HPlus, 1545, check)
      call createCurrent(P_Hl, P_Hh, P_A, P_Z, 3690, check)
      call createCurrent(P_WPlus, P_g, P_g, P_WMinus, 3650, check)
      call createCurrent(P_Z, P_WMinus, P_HPlus, P_Ha, 1478, check)
      call createCurrent(P_HPlus, P_A, P_WMinus, P_Hh, 1077, check)
      call createCurrent(P_HPlus, P_Hh, P_Hl, P_HMinus, 263, check)
      call createCurrent(P_nu_mu, P_muPlus, P_HMinus, 726, check)
      call createCurrent(P_GMinus, P_Z, P_Ha, P_WPlus, 2776, check)
      call createCurrent(P_g, P_g, P_g, P_A, 3816, check)
      call createCurrent(P_Z, P_Ha, P_Ha, P_Z, 1395, check)
      call createCurrent(P_WMinus, P_Ha, P_A, P_HPlus, 1568, check)
      call createCurrent(P_b, P_bAnti, 2911, check)
      call createCurrent(P_Hh, P_Ha, P_Hl, P_G0, 769, check)
      call createCurrent(P_G0, P_Z, P_WPlus, P_HMinus, 2760, check)
      call createCurrent(P_WMinus, P_GMinus, P_WPlus, P_GPlus, 15, check)
      call createCurrent(P_HMinus, P_HMinus, P_HPlus, P_GPlus, 194, check)
      call createCurrent(P_Hh, P_A, P_GPlus, P_WMinus, 1562, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Hh, 191, check)
      call createCurrent(P_HMinus, P_Hl, P_Hh, P_HPlus, 1453, check)
      call createCurrent(P_Hh, P_GMinus, P_Hl, P_HPlus, 850, check)
      call createCurrent(P_GPlus, P_Hh, P_Hl, P_GMinus, 2186, check)
      call createCurrent(P_Z, P_HMinus, P_A, P_HPlus, 1232, check)
      call createCurrent(P_Z, P_Hh, P_WPlus, P_HMinus, 900, check)
      call createCurrent(P_Hh, P_GMinus, P_WPlus, P_Z, 557, check)
      call createCurrent(P_GMinus, P_GPlus, P_A, 18, check)
      call createCurrent(P_A, P_G0, P_G0, P_A, 3735, check)
      call createCurrent(P_b, P_bAnti, P_Z, 299, check)
      call createCurrent(P_GPlus, P_G0, P_Ha, P_GMinus, 399, check)
      call createCurrent(P_Hl, P_Hl, P_GMinus, P_HPlus, 218, check)
      call createCurrent(P_Hh, P_HMinus, P_Z, P_WPlus, 1863, check)
      call createCurrent(P_Hl, P_tAnti, P_t, 652, check)
      call createCurrent(P_nu_muAnti, P_GPlus, P_muMinus, 2272, check)
      call createCurrent(P_HPlus, P_HMinus, P_WMinus, P_WPlus, 217, check)
      call createCurrent(P_Z, P_G0, P_HPlus, P_WMinus, 2790, check)
      call createCurrent(P_Hl, P_Ha, P_Ha, P_Hh, 1501, check)
      call createCurrent(P_Ha, P_G0, P_Hh, P_Hh, 212, check)
      call createCurrent(P_WMinus, P_A, P_WPlus, 1977, check)
      call createCurrent(P_WPlus, P_A, P_Hh, P_HMinus, 51, check)
      call createCurrent(P_cAnti, P_HPlus, P_s, 913, check)
      call createCurrent(P_Hl, P_G0, P_HPlus, P_GMinus, 1588, check)
      call createCurrent(P_HPlus, P_GMinus, 3127, check)
      call createCurrent(P_WMinus, P_A, P_WPlus, P_A, 1002, check)
      call createCurrent(P_Hl, P_WPlus, P_A, P_HMinus, 777, check)
      call createCurrent(P_GPlus, P_HMinus, P_HMinus, P_GPlus, 25, check)
      call createCurrent(P_HMinus, P_HPlus, P_HPlus, P_GMinus, 1237, check)
      call createCurrent(P_Hl, P_HPlus, P_GMinus, 1283, check)
      call createCurrent(P_G0, P_GPlus, P_HMinus, 1479, check)
      call createCurrent(P_Hh, P_Z, P_WPlus, P_GMinus, 505, check)
      call createCurrent(P_GPlus, P_HMinus, P_Z, 3490, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghZ, 418, check)
      call createCurrent(P_WPlus, P_GMinus, P_Hl, P_A, 484, check)
      call createCurrent(P_GMinus, P_g, P_g, P_HPlus, 3835, check)
      call createCurrent(P_HPlus, P_WMinus, P_Ha, P_A, 2625, check)
      call createCurrent(P_Z, P_sAnti, P_s, 601, check)
      call createCurrent(P_A, P_ghWp, P_ghWpAnti, 1029, check)
      call createCurrent(P_nu_tau, P_tauPlus, P_HMinus, 7, check)
      call createCurrent(P_g, P_g, P_Hh, P_Hl, 3605, check)
      call createCurrent(P_HPlus, P_GMinus, P_HPlus, P_HMinus, 1692, check)
      call createCurrent(P_Hl, P_A, P_A, 3620, check)
      call createCurrent(P_GPlus, P_HMinus, P_GPlus, P_GMinus, 1132, check)
      call createCurrent(P_Hl, P_GMinus, P_Hh, P_GPlus, 300, check)
      call createCurrent(P_GPlus, P_Hh, P_GMinus, P_Ha, 2725, check)
      call createCurrent(P_Ha, P_HMinus, P_Hl, P_GPlus, 933, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_WPlus, 976, check)
      call createCurrent(P_Z, P_G0, P_G0, P_Z, 408, check)
      call createCurrent(P_GPlus, P_A, P_GMinus, P_Z, 1092, check)
      call createCurrent(P_GMinus, P_Ha, P_G0, P_GPlus, 21, check)
      call createCurrent(P_Hl, P_GPlus, P_HMinus, 279, check)
      call createCurrent(P_GMinus, P_Ha, P_GPlus, P_G0, 1823, check)
      call createCurrent(P_Ha, P_HPlus, P_GMinus, P_Hh, 2282, check)
      call createCurrent(P_HPlus, P_tauMinus, P_nu_tauAnti, 1412, check)
      call createCurrent(P_WMinus, P_ghA, P_ghWmAnti, 1670, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, P_Ha, 3240, check)
      call createCurrent(P_Hh, P_WPlus, P_WMinus, P_Hl, 3199, check)
      call createCurrent(P_Ha, P_WMinus, P_HPlus, P_A, 660, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, P_Hh, 1612, check)
      call createCurrent(P_G0, P_ghWmAnti, P_ghWm, 960, check)
      call createCurrent(P_GMinus, P_Hh, P_Ha, P_HPlus, 2078, check)
      call createCurrent(P_Z, P_WMinus, P_Ha, P_HPlus, 934, check)
      call createCurrent(P_Hl, P_eMinus, P_ePlus, 139, check)
      call createCurrent(P_Hl, P_Hl, P_GPlus, P_HMinus, 1747, check)
      call createCurrent(P_G0, P_HPlus, P_G0, P_GMinus, 2342, check)
      call createCurrent(P_A, P_Ha, P_Z, P_Ha, 3321, check)
      call createCurrent(P_HPlus, P_tAnti, P_b, 1928, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Ha, 3242, check)
      call createCurrent(P_Z, P_Ha, P_Hl, 2094, check)
      call createCurrent(P_Hl, P_Hh, P_HMinus, P_GPlus, 657, check)
      call createCurrent(P_WPlus, P_Hh, P_Z, P_HMinus, 1277, check)
      call createCurrent(P_WPlus, P_GMinus, P_G0, P_A, 14, check)
      call createCurrent(P_WPlus, P_HMinus, P_A, P_Ha, 2261, check)
      call createCurrent(P_nu_muAnti, P_Z, P_nu_mu, 560, check)
      call createCurrent(P_G0, P_G0, P_GMinus, P_GPlus, 2013, check)
      call createCurrent(P_g, P_g, P_HPlus, P_GMinus, 3708, check)
      call createCurrent(P_Hh, P_HMinus, P_G0, P_GPlus, 1540, check)
      call createCurrent(P_WPlus, P_WMinus, P_Hh, P_Hh, 37, check)
      call createCurrent(P_Hl, P_HMinus, P_GPlus, P_G0, 429, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, P_Hl, 1410, check)
      call createCurrent(P_WPlus, P_HMinus, P_Hh, 791, check)
      call createCurrent(P_GPlus, P_A, P_A, P_HMinus, 2978, check)
      call createCurrent(P_GPlus, P_nu_eAnti, P_eMinus, 2305, check)
      call createCurrent(P_HMinus, P_G0, P_Z, P_WPlus, 2920, check)
      call createCurrent(P_Ha, P_Ha, P_Hl, 313, check)
      call createCurrent(P_WPlus, P_HMinus, P_Hh, P_A, 2082, check)
      call createCurrent(P_A, P_Hh, P_WPlus, P_GMinus, 89, check)
      call createCurrent(P_WMinus, P_g, P_g, P_WPlus, 3739, check)
      call createCurrent(P_WMinus, P_G0, P_GPlus, P_A, 2108, check)
      call createCurrent(P_HMinus, P_A, P_GPlus, P_Z, 3048, check)
      call createCurrent(P_A, P_Z, P_G0, P_G0, 2907, check)
      call createCurrent(P_HPlus, P_A, P_A, P_HMinus, 2587, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_A, 465, check)
      call createCurrent(P_WMinus, P_Z, P_WPlus, P_Z, 1227, check)
      call createCurrent(P_HPlus, P_GMinus, P_Hl, P_Hl, 2204, check)
      call createCurrent(P_Ha, P_GMinus, P_GPlus, P_G0, 2607, check)
      call createCurrent(P_Ha, P_Hl, P_Hl, P_G0, 1714, check)
      call createCurrent(P_A, P_WMinus, P_HPlus, P_Ha, 1675, check)
      call createCurrent(P_WMinus, P_Z, P_G0, P_GPlus, 2289, check)
      call createCurrent(P_cAnti, P_G0, P_c, 1826, check)
      call createCurrent(P_HPlus, P_HMinus, P_Z, 2453, check)
      call createCurrent(P_Z, P_HPlus, P_HMinus, P_Z, 931, check)
      call createCurrent(P_G0, P_A, P_HPlus, P_WMinus, 3120, check)
      call createCurrent(P_HMinus, P_GPlus, P_g, P_g, 3869, check)
      call createCurrent(P_G0, P_g, P_Ha, P_g, 3716, check)
      call createCurrent(P_WMinus, P_GPlus, P_WPlus, P_HMinus, 3172, check)
      call createCurrent(P_A, P_HMinus, P_GPlus, P_Z, 3464, check)
      call createCurrent(P_c, P_GMinus, P_sAnti, 2127, check)
      call createCurrent(P_A, P_A, P_g, P_g, 3596, check)
      call createCurrent(P_sAnti, P_Hl, P_s, 2227, check)
      call createCurrent(P_Hh, P_WPlus, P_HMinus, P_A, 2192, check)
      call createCurrent(P_Hh, P_GPlus, P_Z, P_WMinus, 357, check)
      call createCurrent(P_Hh, P_Z, P_HMinus, P_WPlus, 1275, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, P_Ha, 3585, check)
      call createCurrent(P_WPlus, P_s, P_cAnti, 2183, check)
      call createCurrent(P_A, P_HMinus, P_GPlus, P_A, 2845, check)
      call createCurrent(P_Z, P_GPlus, P_HMinus, P_Z, 2893, check)
      call createCurrent(P_HPlus, P_WMinus, P_GMinus, P_WPlus, 3096, check)
      call createCurrent(P_Z, P_Hh, P_HPlus, P_WMinus, 570, check)
      call createCurrent(P_Ha, P_GMinus, P_WPlus, 3359, check)
      call createCurrent(P_Z, P_ghWp, P_ghWpAnti, 1014, check)
      call createCurrent(P_GMinus, P_G0, P_WPlus, 528, check)
      call createCurrent(P_A, P_WMinus, P_Ha, P_HPlus, 2112, check)
      call createCurrent(P_Hh, P_GMinus, P_G0, P_GPlus, 3352, check)
      call createCurrent(P_G0, P_Hl, P_Z, 2333, check)
      call createCurrent(P_Z, P_HMinus, P_Z, P_HPlus, 574, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_Hl, 607, check)
      call createCurrent(P_A, P_HPlus, P_WMinus, P_Hh, 1767, check)
      call createCurrent(P_HPlus, P_Hh, P_GMinus, P_Ha, 1783, check)
      call createCurrent(P_HPlus, P_uAnti, P_d, 483, check)
      call createCurrent(P_HMinus, P_WMinus, P_WPlus, P_GPlus, 3551, check)
      call createCurrent(P_WPlus, P_HPlus, P_GMinus, P_WMinus, 2764, check)
      call createCurrent(P_Ha, P_G0, P_GPlus, P_GMinus, 283, check)
      call createCurrent(P_WMinus, P_HPlus, P_A, 2651, check)
      call createCurrent(P_HMinus, P_Hh, P_GPlus, P_Ha, 2696, check)
      call createCurrent(P_Ha, P_A, P_Ha, P_A, 3738, check)
      call createCurrent(P_WPlus, P_A, P_HMinus, P_Ha, 2526, check)
      call createCurrent(P_A, P_GPlus, P_HMinus, P_A, 3003, check)
      call createCurrent(P_WPlus, P_GMinus, P_Hl, 2309, check)
      call createCurrent(P_d, P_dAnti, P_Hh, 1488, check)
      call createCurrent(P_Hl, P_WPlus, P_GMinus, P_A, 1730, check)
      call createCurrent(P_g, P_s, P_sAnti, 400, check)
      call createCurrent(P_G0, P_GPlus, P_GMinus, P_G0, 333, check)
      call createCurrent(P_GMinus, P_HPlus, P_WPlus, P_WMinus, 3187, check)
      call createCurrent(P_WMinus, P_A, P_HPlus, P_Hl, 1748, check)
      call createCurrent(P_Ha, P_A, P_HPlus, P_WMinus, 492, check)
      call createCurrent(P_eMinus, P_G0, P_ePlus, 2508, check)
      call createCurrent(P_G0, P_HMinus, P_GPlus, P_Hh, 111, check)
      call createCurrent(P_GPlus, P_WMinus, P_GMinus, P_WPlus, 316, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, P_Ha, 2968, check)
      call createCurrent(P_HPlus, P_Z, P_WMinus, P_Hl, 649, check)
      call createCurrent(P_HPlus, P_Z, P_HMinus, P_A, 1704, check)
      call createCurrent(P_Z, P_Hh, P_Hl, P_Z, 3086, check)
      call createCurrent(P_c, P_A, P_cAnti, 1360, check)
      call createCurrent(P_Hl, P_Ha, P_Hl, P_Ha, 2563, check)
      call createCurrent(P_ghWmAnti, P_A, P_ghWm, 1922, check)
      call createCurrent(P_GPlus, P_Z, P_G0, P_WMinus, 85, check)
      call createCurrent(P_muPlus, P_Hh, P_muMinus, 2539, check)
      call createCurrent(P_WMinus, P_WPlus, P_Z, P_A, 766, check)
      call createCurrent(P_G0, P_Z, 3218, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_HPlus, 3459, check)
      call createCurrent(P_tauPlus, P_Z, P_tauMinus, 2241, check)
      call createCurrent(P_G0, P_WPlus, P_HMinus, P_A, 2723, check)
      call createCurrent(P_Ha, P_G0, P_Hl, 615, check)
      call createCurrent(P_GPlus, P_GMinus, P_G0, P_G0, 1218, check)
      call createCurrent(P_Z, P_WMinus, P_HPlus, P_Hh, 1111, check)
      call createCurrent(P_c, P_Hh, P_cAnti, 509, check)
      call createCurrent(P_A, P_G0, P_GPlus, P_WMinus, 1627, check)
      call createCurrent(P_Z, P_WMinus, P_A, P_WPlus, 2173, check)
      call createCurrent(P_Hh, P_g, P_Hh, P_g, 3655, check)
      call createCurrent(P_bAnti, P_b, 2883, check)
      call createCurrent(P_A, P_GPlus, P_A, P_GMinus, 756, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_GPlus, 811, check)
      call createCurrent(P_Ha, P_Hl, P_HPlus, P_GMinus, 1267, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_WMinus, 276, check)
      call createCurrent(P_A, P_Z, P_GPlus, P_HMinus, 3264, check)
      call createCurrent(P_GMinus, P_HPlus, P_Hl, P_Hl, 1621, check)
      call createCurrent(P_GMinus, P_g, P_g, P_GPlus, 3862, check)
      call createCurrent(P_Hl, P_G0, P_GMinus, P_GPlus, 3554, check)
      call createCurrent(P_A, P_WPlus, P_Ha, P_GMinus, 3000, check)
      call createCurrent(P_Hh, P_HMinus, P_WPlus, P_Z, 1201, check)
      call createCurrent(P_Hl, P_WMinus, P_A, P_HPlus, 906, check)
      call createCurrent(P_HMinus, P_GPlus, P_G0, 722, check)
      call createCurrent(P_HMinus, P_HPlus, P_GMinus, P_HPlus, 877, check)
      call createCurrent(P_Ha, P_GMinus, P_GPlus, P_Hh, 3557, check)
      call createCurrent(P_G0, P_A, P_Z, P_G0, 2877, check)
      call createCurrent(P_A, P_G0, P_HMinus, P_WPlus, 2941, check)
      call createCurrent(P_t, P_tAnti, P_Z, 948, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghWmAnti, 922, check)
      call createCurrent(P_Ha, P_Z, P_G0, P_A, 3773, check)
      call createCurrent(P_g, P_g, P_G0, P_G0, 3875, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, P_Ha, 3166, check)
      call createCurrent(P_Ha, P_ghWp, P_ghWpAnti, 3500, check)
      call createCurrent(P_WPlus, P_HMinus, P_Ha, P_Z, 1392, check)
      call createCurrent(P_nu_tau, P_tauPlus, P_WMinus, 472, check)
      call createCurrent(P_Hl, P_Hl, P_HPlus, P_HMinus, 2134, check)
      call createCurrent(P_HMinus, P_Ha, P_Z, P_WPlus, 2097, check)
      call createCurrent(P_Ha, P_G0, P_Z, P_A, 3853, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, P_G0, 431, check)
      call createCurrent(P_Ha, P_WPlus, P_A, P_HMinus, 1738, check)
      call createCurrent(P_muPlus, P_A, P_muMinus, 1791, check)
      call createCurrent(P_GPlus, P_GMinus, P_G0, P_Hl, 3332, check)
      call createCurrent(P_GPlus, P_Z, P_Hl, P_WMinus, 1555, check)
      call createCurrent(P_GMinus, P_WPlus, P_WMinus, P_HPlus, 2738, check)
      call createCurrent(P_HMinus, P_g, P_g, P_GPlus, 3640, check)
      call createCurrent(P_Hl, P_GPlus, P_WMinus, P_A, 2331, check)
      call createCurrent(P_Hh, P_g, P_Hl, P_g, 3760, check)
      call createCurrent(P_WPlus, P_WMinus, P_A, 1788, check)
      call createCurrent(P_tAnti, P_Hh, P_t, 1081, check)
      call createCurrent(P_GPlus, P_G0, P_HMinus, P_G0, 55, check)
      call createCurrent(P_A, P_muMinus, P_muPlus, 928, check)
      call createCurrent(P_g, P_Ha, P_g, P_G0, 3834, check)
      call createCurrent(P_WMinus, P_A, P_HPlus, P_G0, 2745, check)
      call createCurrent(P_g, P_g, P_HMinus, P_HPlus, 3639, check)
      call createCurrent(P_GMinus, P_WMinus, P_GPlus, P_WPlus, 2630, check)
      call createCurrent(P_GMinus, P_GPlus, P_g, P_g, 3864, check)
      call createCurrent(P_WMinus, P_A, P_Hl, P_HPlus, 595, check)
      call createCurrent(P_HPlus, P_Z, P_HMinus, P_Z, 2182, check)
      call createCurrent(P_Ha, P_Ha, P_G0, P_G0, 1751, check)
      call createCurrent(P_G0, P_Hh, P_HMinus, P_HPlus, 3502, check)
      call createCurrent(P_Hh, P_A, P_A, P_Hl, 3836, check)
      call createCurrent(P_WMinus, P_Z, P_WPlus, 1282, check)
      call createCurrent(P_G0, P_WMinus, P_HPlus, P_A, 3203, check)
      call createCurrent(P_Hh, P_Hh, P_Hh, 66, check)
      call createCurrent(P_HPlus, P_HMinus, P_Ha, 2833, check)
      call createCurrent(P_GMinus, P_Hh, P_Ha, P_GPlus, 3540, check)
      call createCurrent(P_ghWpAnti, P_Hl, P_ghWp, 1068, check)
      call createCurrent(P_HMinus, P_Hl, P_HPlus, P_Hl, 32, check)
      call createCurrent(P_HMinus, P_Ha, P_G0, P_HPlus, 691, check)
      call createCurrent(P_ePlus, P_Z, P_eMinus, 246, check)
      call createCurrent(P_Hh, P_G0, P_Hh, P_Ha, 2233, check)
      call createCurrent(P_HMinus, P_HPlus, P_GPlus, P_HMinus, 2624, check)
      call createCurrent(P_Z, P_ghWmAnti, P_ghWm, 2118, check)
      call createCurrent(P_Ha, P_tAnti, P_t, 644, check)
      call createCurrent(P_G0, P_GPlus, P_HMinus, P_Hl, 1614, check)
      call createCurrent(P_GPlus, P_WMinus, P_Ha, 3296, check)
      call createCurrent(P_Ha, P_GPlus, P_G0, P_HMinus, 1118, check)
      call createCurrent(P_GMinus, P_WPlus, 3402, check)
      call createCurrent(P_A, P_Z, P_GMinus, P_GPlus, 42, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, P_Ha, 3194, check)
      call createCurrent(P_GMinus, P_ghZ, P_ghWmAnti, 1210, check)
      call createCurrent(P_HMinus, P_GMinus, P_GPlus, P_GPlus, 2517, check)
      call createCurrent(P_nu_e, P_Z, P_nu_eAnti, 534, check)
      call createCurrent(P_GPlus, P_Hl, P_HMinus, P_G0, 1917, check)
      call createCurrent(P_Ha, P_GMinus, P_Ha, P_GPlus, 1272, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_HMinus, 3289, check)
      call createCurrent(P_dAnti, P_u, P_WMinus, 981, check)
      call createCurrent(P_Hl, P_GPlus, P_Hl, P_HMinus, 2570, check)
      call createCurrent(P_uAnti, P_d, P_GPlus, 1357, check)
      call createCurrent(P_s, P_sAnti, P_G0, 41, check)
      call createCurrent(P_Hl, P_Z, P_GPlus, P_WMinus, 653, check)
      call createCurrent(P_g, P_g, P_GPlus, P_GMinus, 3709, check)
      call createCurrent(P_u, P_uAnti, P_Hl, 1818, check)
      call createCurrent(P_Ha, P_HMinus, P_Z, P_WPlus, 423, check)
      call createCurrent(P_c, P_Ha, P_cAnti, 2419, check)
      call createCurrent(P_A, P_A, P_G0, P_G0, 3751, check)
      call createCurrent(P_HMinus, P_Hl, P_Hh, P_GPlus, 1039, check)
      call createCurrent(P_ghWp, P_Z, P_ghWpAnti, 2235, check)
      call createCurrent(P_HPlus, P_HMinus, P_WPlus, P_WMinus, 2658, check)
      call createCurrent(P_G0, P_GPlus, P_Ha, P_GMinus, 2418, check)
      call createCurrent(P_eMinus, P_nu_eAnti, P_GPlus, 1233, check)
      call createCurrent(P_Ha, P_WPlus, P_WMinus, P_G0, 3117, check)
      call createCurrent(P_Hh, P_A, P_Ha, 3361, check)
      call createCurrent(P_nu_muAnti, P_WPlus, P_muMinus, 2039, check)
      call createCurrent(P_Ha, P_Hh, P_GPlus, P_GMinus, 3106, check)
      call createCurrent(P_WPlus, P_A, P_WMinus, P_Z, 94, check)
      call createCurrent(P_Z, P_g, P_g, P_Z, 3820, check)
      call createCurrent(P_Hl, P_HMinus, P_GPlus, P_Hh, 2198, check)
      call createCurrent(P_HMinus, P_Hh, P_G0, P_GPlus, 598, check)
      call createCurrent(P_HMinus, P_WMinus, P_WPlus, P_HPlus, 1756, check)
      call createCurrent(P_HMinus, P_HPlus, P_Hl, P_Ha, 3041, check)
      call createCurrent(P_WPlus, P_WMinus, P_HPlus, P_HMinus, 1667, check)
      call createCurrent(P_nu_e, P_ePlus, P_GMinus, 813, check)
      call createCurrent(P_Hl, P_Hl, P_Hh, P_Hl, 2023, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_Hh, 2512, check)
      call createCurrent(P_A, P_GMinus, P_Ha, P_WPlus, 2929, check)
      call createCurrent(P_Ha, P_tauPlus, P_tauMinus, 1243, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, P_Hh, 2672, check)
      call createCurrent(P_sAnti, P_Ha, P_s, 2179, check)
      call createCurrent(P_Hl, P_HMinus, P_WPlus, 87, check)
      call createCurrent(P_Hl, P_Hh, 2787, check)
      call createCurrent(P_Hh, P_Hl, P_WMinus, P_WPlus, 3278, check)
      call createCurrent(P_GMinus, P_Ha, P_Ha, P_GPlus, 537, check)
      call createCurrent(P_Hh, P_Ha, P_Hh, P_Ha, 2469, check)
      call createCurrent(P_cAnti, P_c, P_Ha, 562, check)
      call createCurrent(P_tAnti, P_b, P_GPlus, 184, check)
      call createCurrent(P_A, P_HMinus, P_Hh, P_WPlus, 673, check)
      call createCurrent(P_muPlus, P_Hl, P_muMinus, 2583, check)
      call createCurrent(P_g, P_g, P_Ha, P_Ha, 3627, check)
      call createCurrent(P_Hh, P_HMinus, P_GPlus, P_G0, 1496, check)
      call createCurrent(P_G0, P_A, P_Hl, 3068, check)
      call createCurrent(P_HPlus, P_GMinus, P_HMinus, P_GPlus, 1987, check)
      call createCurrent(P_Ha, P_HMinus, P_G0, P_GPlus, 2035, check)
      call createCurrent(P_Hl, P_Hl, P_Hh, P_Hh, 1656, check)
      call createCurrent(P_HPlus, P_Hl, P_WMinus, 1603, check)
      call createCurrent(P_d, P_dAnti, P_Ha, 1219, check)
      call createCurrent(P_Ha, P_GPlus, P_Ha, P_GMinus, 2019, check)
      call createCurrent(P_HMinus, P_GPlus, P_Hh, 741, check)
      call createCurrent(P_G0, P_Ha, P_HPlus, P_GMinus, 1898, check)
      call createCurrent(P_tauPlus, P_nu_tau, P_GMinus, 414, check)
      call createCurrent(P_HMinus, P_Hl, P_GPlus, P_Hl, 812, check)
      call createCurrent(P_Hh, P_GPlus, P_GMinus, P_G0, 3456, check)
      call createCurrent(P_HPlus, P_Hl, P_Hh, P_GMinus, 214, check)
      call createCurrent(P_Ha, P_HMinus, P_Hh, P_GPlus, 2402, check)
      call createCurrent(P_A, P_HPlus, P_WMinus, P_Ha, 1278, check)
      call createCurrent(P_ghA, P_GMinus, P_ghWmAnti, 1710, check)
      call createCurrent(P_HPlus, P_b, P_tAnti, 1276, check)
      call createCurrent(P_ePlus, P_G0, P_eMinus, 2689, check)
      call createCurrent(P_HMinus, P_GPlus, P_HPlus, P_GMinus, 852, check)
      call createCurrent(P_GPlus, P_HMinus, P_Z, P_Z, 3425, check)
      call createCurrent(P_GMinus, P_G0, P_HPlus, P_Hh, 1843, check)
      call createCurrent(P_WPlus, P_A, P_HMinus, P_Hl, 1682, check)
      call createCurrent(P_WMinus, P_WPlus, P_Hh, 622, check)
      call createCurrent(P_GMinus, P_GPlus, P_Hh, P_Ha, 2813, check)
      call createCurrent(P_Hh, P_WMinus, P_HPlus, 1637, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Z, 724, check)
      call createCurrent(P_HPlus, P_Hh, P_HMinus, P_Ha, 3145, check)
      call createCurrent(P_g, P_Hh, P_Hl, P_g, 3749, check)
      call createCurrent(P_WPlus, P_Ha, P_HMinus, P_Z, 939, check)
      call createCurrent(P_HMinus, P_HPlus, P_WMinus, P_WPlus, 1727, check)
      call createCurrent(P_WMinus, P_tauPlus, P_nu_tau, 2554, check)
      call createCurrent(P_GPlus, P_HPlus, P_HMinus, P_HMinus, 1895, check)
      call createCurrent(P_WPlus, P_nu_tauAnti, P_tauMinus, 2553, check)
      call createCurrent(P_HMinus, P_GPlus, P_GPlus, P_GMinus, 1929, check)
      call createCurrent(P_G0, P_GMinus, P_HPlus, 1593, check)
      call createCurrent(P_WMinus, P_G0, P_HPlus, 2784, check)
      call createCurrent(P_ePlus, P_GMinus, P_nu_e, 696, check)
      call createCurrent(P_Hh, P_HMinus, P_GPlus, P_Hl, 2256, check)
      call createCurrent(P_Hl, P_Hl, P_WPlus, P_WMinus, 2158, check)
      call createCurrent(P_HMinus, P_G0, P_GPlus, P_Hl, 663, check)
      call createCurrent(P_t, P_HMinus, P_bAnti, 2688, check)
      call createCurrent(P_GMinus, P_A, P_Z, P_GPlus, 2197, check)
      call createCurrent(P_g, P_g, P_Hl, P_Hl, 3714, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghZ, 143, check)
      call createCurrent(P_GMinus, P_HPlus, P_Hh, P_Hh, 2207, check)
      call createCurrent(P_HPlus, P_WMinus, P_WPlus, P_GMinus, 3209, check)
      call createCurrent(P_WPlus, P_G0, P_WMinus, P_G0, 2352, check)
      call createCurrent(P_GMinus, P_Z, P_Z, P_HPlus, 3085, check)
      call createCurrent(P_Hh, P_Ha, P_Ha, 2618, check)
      call createCurrent(P_Ha, P_Hl, P_Hh, P_Ha, 2104, check)
      call createCurrent(P_HMinus, P_WPlus, P_Z, P_Ha, 2021, check)
      call createCurrent(P_HMinus, P_WPlus, P_A, P_G0, 2785, check)
      call createCurrent(P_GMinus, P_Hl, P_WPlus, P_Z, 584, check)
      call createCurrent(P_WPlus, P_WMinus, P_HMinus, P_HPlus, 1423, check)
      call createCurrent(P_GPlus, P_Hh, P_HMinus, P_Hl, 1525, check)
      call createCurrent(P_Ha, P_GMinus, P_HPlus, P_Ha, 2160, check)
      call createCurrent(P_HMinus, P_g, P_g, P_HPlus, 3883, check)
      call createCurrent(P_GPlus, P_G0, P_Hh, P_GMinus, 3257, check)
      call createCurrent(P_WPlus, P_G0, P_GMinus, P_A, 360, check)
      call createCurrent(P_s, P_sAnti, P_Ha, 1910, check)
      call createCurrent(P_Z, P_Hl, P_Z, P_Hl, 2604, check)
      call createCurrent(P_GPlus, P_GMinus, P_G0, 3123, check)
      call createCurrent(P_Hh, P_GMinus, P_GPlus, P_Ha, 2995, check)
      call createCurrent(P_Z, P_G0, P_WPlus, P_HMinus, 3529, check)
      call createCurrent(P_Ha, P_Ha, P_A, P_A, 3786, check)
      call createCurrent(P_Ha, P_A, P_A, P_G0, 3740, check)
      call createCurrent(P_G0, P_Hl, P_HMinus, P_GPlus, 144, check)
      call createCurrent(P_HPlus, P_Ha, P_Z, P_WMinus, 970, check)
      call createCurrent(P_Hl, P_GPlus, P_Z, P_WMinus, 1972, check)
      call createCurrent(P_A, P_WMinus, P_HPlus, 958, check)
      call createCurrent(P_HPlus, P_WMinus, P_A, P_Ha, 1034, check)
      call createCurrent(P_A, P_WPlus, P_Hl, P_HMinus, 2417, check)
      call createCurrent(P_Ha, P_HMinus, P_G0, P_HPlus, 2102, check)
      call createCurrent(P_HMinus, P_WPlus, P_WMinus, P_GPlus, 2951, check)
      call createCurrent(P_tauPlus, P_Ha, P_tauMinus, 2705, check)
      call createCurrent(P_WMinus, P_HPlus, P_A, P_Hh, 2345, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, P_Hl, 627, check)
      call createCurrent(P_Z, P_Z, P_Hl, P_Hh, 3270, check)
      call createCurrent(P_muPlus, P_muMinus, P_Z, 1180, check)
      call createCurrent(P_ghWpAnti, P_G0, P_ghWp, 1782, check)
      call createCurrent(P_Z, P_Ha, P_WPlus, P_HMinus, 2465, check)
      call createCurrent(P_Z, P_WMinus, P_HPlus, P_G0, 3324, check)
      call createCurrent(P_HPlus, P_HMinus, P_Hh, 2017, check)
      call createCurrent(P_Ha, P_HMinus, P_HPlus, P_Hh, 2766, check)
      call createCurrent(P_g, P_dAnti, P_d, 2357, check)
      call createCurrent(P_Hl, P_HPlus, P_GMinus, P_Hl, 1007, check)
      call createCurrent(P_GMinus, P_t, P_bAnti, 1436, check)
      call createCurrent(P_HPlus, P_GMinus, P_Hh, P_G0, 129, check)
      call createCurrent(P_G0, P_Ha, P_Ha, P_G0, 2491, check)
      call createCurrent(P_A, P_GPlus, P_HMinus, 2846, check)
      call createCurrent(P_d, P_Z, P_dAnti, 679, check)
      call createCurrent(P_ghWm, P_A, P_ghWmAnti, 1114, check)
      call createCurrent(P_Ha, P_G0, P_GPlus, P_HMinus, 2596, check)
      call createCurrent(P_Z, P_Z, P_WMinus, P_WPlus, 1645, check)
      call createCurrent(P_G0, P_ghWp, P_ghWpAnti, 1284, check)
      call createCurrent(P_t, P_A, P_tAnti, 2109, check)
      call createCurrent(P_WMinus, P_Ha, P_HPlus, 1821, check)
      call createCurrent(P_HPlus, P_A, P_Z, P_GMinus, 3001, check)
      call createCurrent(P_HPlus, P_A, P_Hh, P_WMinus, 1273, check)
      call createCurrent(P_G0, P_Hh, P_GPlus, P_GMinus, 2771, check)
      call createCurrent(P_GPlus, P_GMinus, P_Hl, P_Hh, 1471, check)
      call createCurrent(P_A, P_Hl, P_G0, 2961, check)
      call createCurrent(P_GMinus, P_GPlus, P_Hh, 1337, check)
      call createCurrent(P_GPlus, P_WPlus, P_WMinus, P_HMinus, 3176, check)
      call createCurrent(P_Ha, P_Ha, 3200, check)
      call createCurrent(P_GMinus, P_Hl, P_G0, P_HPlus, 495, check)
      call createCurrent(P_GMinus, P_sAnti, P_c, 185, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, P_Hl, 2513, check)
      call createCurrent(P_Hl, P_Hh, P_Hh, P_Hl, 131, check)
      call createCurrent(P_HMinus, P_Hl, P_HPlus, P_Hh, 1084, check)
      call createCurrent(P_Hl, P_ePlus, P_eMinus, 2620, check)
      call createCurrent(P_HMinus, P_GPlus, P_G0, P_Hl, 2015, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, P_Ha, 3510, check)
      call createCurrent(P_WPlus, P_Hl, P_WMinus, P_Hl, 2057, check)
      call createCurrent(P_WPlus, P_HMinus, P_Z, P_Hh, 2617, check)
      call createCurrent(P_GPlus, P_A, P_HMinus, P_A, 3212, check)
      call createCurrent(P_HPlus, P_HMinus, P_Ha, P_Ha, 1473, check)
      call createCurrent(P_Hl, P_WPlus, P_WMinus, P_Hh, 3316, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, P_Hh, 1116, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, P_G0, 1123, check)
      call createCurrent(P_GPlus, P_WMinus, P_Hl, P_A, 2535, check)
      call createCurrent(P_WMinus, P_GPlus, P_G0, 91, check)
      call createCurrent(P_A, P_G0, P_GMinus, P_WPlus, 2303, check)
      call createCurrent(P_A, P_HMinus, P_G0, P_WPlus, 2868, check)
      call createCurrent(P_Z, P_Hh, P_GMinus, P_WPlus, 2157, check)
      call createCurrent(P_GPlus, P_Hh, P_HMinus, P_Ha, 2016, check)
      call createCurrent(P_Ha, P_ghWpAnti, P_ghWp, 3431, check)
      call createCurrent(P_HPlus, P_Ha, P_GMinus, P_Hl, 612, check)
      call createCurrent(P_G0, P_Z, P_A, P_G0, 2848, check)
      call createCurrent(P_GPlus, P_Ha, P_HMinus, P_Hh, 749, check)
      call createCurrent(P_GPlus, P_WMinus, P_WPlus, P_HMinus, 3559, check)
      call createCurrent(P_HPlus, P_HMinus, P_A, P_A, 1570, check)
      call createCurrent(P_HMinus, P_Hl, P_A, P_WPlus, 2076, check)
      call createCurrent(P_Z, P_Hl, P_A, P_Hh, 3636, check)
      call createCurrent(P_GMinus, P_HPlus, P_Hl, 628, check)
      call createCurrent(P_Hl, P_Hh, P_GMinus, P_GPlus, 2292, check)
      call createCurrent(P_Ha, P_WMinus, P_HPlus, 88, check)
      call createCurrent(P_Z, P_GPlus, P_A, P_GMinus, 1055, check)
      call createCurrent(P_WMinus, P_G0, P_GPlus, P_Z, 856, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_WMinus, 1454, check)
      call createCurrent(P_Ha, P_GMinus, P_Hh, P_HPlus, 1519, check)
      call createCurrent(P_g, P_WPlus, P_g, P_WMinus, 3882, check)
      call createCurrent(P_HPlus, P_Hh, P_HMinus, P_G0, 2721, check)
      call createCurrent(P_GMinus, P_Hh, P_A, P_WPlus, 286, check)
      call createCurrent(P_A, P_HMinus, P_HPlus, P_A, 240, check)
      call createCurrent(P_Hl, P_Z, P_Hl, P_A, 3122, check)
      call createCurrent(P_GMinus, P_Hl, P_GPlus, P_Ha, 2795, check)
      call createCurrent(P_Hl, P_Hl, P_HMinus, P_HPlus, 119, check)
      call createCurrent(P_dAnti, P_G0, P_d, 1106, check)
      call createCurrent(P_Hl, P_HMinus, P_HPlus, P_Hl, 1578, check)
      call createCurrent(P_Z, P_WPlus, P_Ha, P_HMinus, 1018, check)
      call createCurrent(P_WMinus, P_Hh, P_WPlus, 197, check)
      call createCurrent(P_A, P_Ha, P_G0, P_Z, 3811, check)
      call createCurrent(P_g, P_ghGAnti, P_ghG, 132, check)
      call createCurrent(P_HPlus, P_Hl, P_G0, P_GMinus, 911, check)
      call createCurrent(P_ghWm, P_G0, P_ghWmAnti, 318, check)
      call createCurrent(P_muMinus, P_muPlus, P_Z, 2497, check)
      call createCurrent(P_eMinus, P_Z, P_ePlus, 2107, check)
      call createCurrent(P_HMinus, P_GPlus, P_Ha, 2498, check)
      call createCurrent(P_G0, P_G0, P_HMinus, P_HPlus, 1891, check)
      call createCurrent(P_HPlus, P_Z, P_Ha, P_WMinus, 2119, check)
      call createCurrent(P_WMinus, P_u, P_dAnti, 647, check)
      call createCurrent(P_WPlus, P_cAnti, P_s, 519, check)
      call createCurrent(P_G0, P_Hl, P_Ha, 780, check)
      call createCurrent(P_G0, P_HPlus, P_WMinus, P_A, 2850, check)
      call createCurrent(P_Hh, P_WMinus, P_A, P_HPlus, 718, check)
      call createCurrent(P_WPlus, P_Z, P_A, P_WMinus, 1512, check)
      call createCurrent(P_Hl, P_tauMinus, P_tauPlus, 1950, check)
      call createCurrent(P_GPlus, P_Z, P_HMinus, P_A, 3177, check)
      call createCurrent(P_Hh, P_G0, P_HPlus, P_HMinus, 3541, check)
      call createCurrent(P_Hh, P_t, P_tAnti, 2257, check)
      call createCurrent(P_Hh, P_Hh, P_A, P_Z, 3189, check)
      call createCurrent(P_tAnti, P_g, P_t, 1415, check)
      call createCurrent(P_GMinus, P_Z, P_G0, P_WPlus, 1671, check)
      call createCurrent(P_GMinus, P_A, P_HPlus, 3115, check)
      call createCurrent(P_Hh, P_GMinus, P_Hh, P_HPlus, 2063, check)
      call createCurrent(P_HPlus, P_A, P_GMinus, P_A, 3234, check)
      call createCurrent(P_g, P_g, P_Hl, 3838, check)
      call createCurrent(P_GMinus, P_HPlus, P_HMinus, P_GPlus, 2409, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghWpAnti, 527, check)
      call createCurrent(P_WMinus, P_WMinus, P_WPlus, P_WPlus, 1108, check)
      call createCurrent(P_muPlus, P_muMinus, P_Ha, 174, check)
      call createCurrent(P_G0, P_HPlus, P_Hh, P_HMinus, 2881, check)
      call createCurrent(P_G0, P_WMinus, P_Ha, P_WPlus, 3368, check)
      call createCurrent(P_tAnti, P_t, P_Hh, 662, check)
      call createCurrent(P_cAnti, P_s, P_HPlus, 633, check)
      call createCurrent(P_Z, P_Ha, P_A, P_G0, 3805, check)
      call createCurrent(P_WPlus, P_G0, P_Ha, P_WMinus, 3524, check)
      call createCurrent(P_Hl, P_HMinus, P_HPlus, P_G0, 2763, check)
      call createCurrent(P_G0, P_HMinus, P_Hh, P_HPlus, 3497, check)
      call createCurrent(P_u, P_uAnti, P_A, 135, check)
      call createCurrent(P_u, P_Z, P_uAnti, 341, check)
      call createCurrent(P_A, P_Z, P_Ha, P_Ha, 3009, check)
      call createCurrent(P_GMinus, P_GPlus, P_Hh, P_Hh, 883, check)
      call createCurrent(P_GPlus, P_GMinus, P_Z, P_A, 802, check)
      call createCurrent(P_tAnti, P_HPlus, P_b, 1019, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Hl, 974, check)
      call createCurrent(P_Ha, P_GPlus, P_WMinus, P_Z, 3315, check)
      call createCurrent(P_Ha, P_Ha, P_A, P_Z, 3416, check)
      call createCurrent(P_GPlus, P_GMinus, P_GMinus, P_GPlus, 1806, check)
      call createCurrent(P_GPlus, P_WMinus, P_G0, P_Z, 2136, check)
      call createCurrent(P_Hh, P_Hl, P_G0, P_G0, 2130, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, P_Hh, 2667, check)
      call createCurrent(P_Hl, P_A, P_GPlus, P_WMinus, 82, check)
      call createCurrent(P_A, P_WPlus, P_A, P_WMinus, 70, check)
      call createCurrent(P_G0, P_Hl, P_GPlus, P_HMinus, 2397, check)
      call createCurrent(P_WPlus, P_Hh, P_A, P_HMinus, 1635, check)
      call createCurrent(P_Z, P_GPlus, P_A, P_HMinus, 2938, check)
      call createCurrent(P_nu_eAnti, P_eMinus, P_HPlus, 1531, check)
      call createCurrent(P_Hl, P_WPlus, P_GMinus, 2255, check)
      call createCurrent(P_GMinus, P_HPlus, P_Hh, P_Ha, 1732, check)
      call createCurrent(P_GMinus, P_Hl, P_Hl, P_HPlus, 1789, check)
      call createCurrent(P_g, P_Hh, P_Hh, P_g, 3870, check)
      call createCurrent(P_WMinus, P_Hl, P_GPlus, P_Z, 2363, check)
      call createCurrent(P_WMinus, P_Hl, P_A, P_HPlus, 1306, check)
      call createCurrent(P_g, P_HMinus, P_GPlus, P_g, 3771, check)
      call createCurrent(P_Ha, P_GMinus, P_HPlus, P_Hh, 1709, check)
      call createCurrent(P_GPlus, P_GMinus, P_Hl, P_Hl, 1028, check)
      call createCurrent(P_G0, P_ePlus, P_eMinus, 1378, check)
      call createCurrent(P_HMinus, P_Hh, P_HPlus, P_Hl, 1601, check)
      call createCurrent(P_WMinus, P_Ha, P_G0, P_WPlus, 2799, check)
      call createCurrent(P_WPlus, P_A, P_Hl, P_HMinus, 797, check)
      call createCurrent(P_G0, P_G0, P_g, P_g, 3628, check)
      call createCurrent(P_WPlus, P_ghZAnti, P_ghWm, 2515, check)
      call createCurrent(P_HPlus, P_Ha, P_HMinus, P_Hl, 2987, check)
      call createCurrent(P_Ha, P_HPlus, P_HMinus, P_G0, 1402, check)
      call createCurrent(P_GPlus, P_Z, P_HMinus, P_Z, 2708, check)
      call createCurrent(P_GMinus, P_HPlus, P_G0, P_Hh, 2634, check)
      call createCurrent(P_GPlus, P_Hh, P_GMinus, P_Hh, 1773, check)
      call createCurrent(P_HMinus, P_G0, P_HPlus, P_Ha, 1047, check)
      call createCurrent(P_Hl, P_muPlus, P_muMinus, 2172, check)
      call createCurrent(P_Hh, P_Z, P_A, P_Hl, 3642, check)
      call createCurrent(P_Hh, P_Hh, P_WMinus, P_WPlus, 445, check)
      call createCurrent(P_GPlus, P_WMinus, P_Hl, P_Z, 2001, check)
      call createCurrent(P_g, P_g, P_A, P_A, 3718, check)
      call createCurrent(P_WMinus, P_WPlus, P_GMinus, P_GPlus, 2595, check)
      call createCurrent(P_GMinus, P_WPlus, P_GPlus, P_WMinus, 392, check)
      call createCurrent(P_WPlus, P_HPlus, P_WMinus, P_HMinus, 2545, check)
    end subroutine createCurrents

    subroutine check_vertices_mdl()
      call createCurrents(.true.)
    end subroutine check_vertices_mdl

    subroutine get_vertex_lorentz_rank_mdl(ty,cc,mr)
      integer, intent(in) :: ty
      logical, intent(in) :: cc(0:)
      integer, intent(out) :: mr
      select case(ty)
      case(9)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(13)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(17)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(18)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(19)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(20)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(21)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(22)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(24)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(25)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(26)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(28)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(29)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(44)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(45)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(46)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(47)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(48)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(49)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(50)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(52)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(53)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(54)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(55)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(59)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(68)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(72)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(75)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(76)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(78)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case default
        mr = 0
      end select 
    end subroutine get_vertex_lorentz_rank_mdl
end module class_vertices
